@@ -64,6 +64,7 @@ static void process_COM (const uchar * Data, int length)
     }
 
     strcpy(ImageInfo.Comments,Comment);
+    ImageInfo.CommentWidchars = 0;
 }
 
  
@@ -133,11 +134,11 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
 
         CheckSectionsAllocated();
 
-        for (a=0;a<7;a++){
+        for (a=0;a<=16;a++){
             marker = fgetc(infile);
             if (marker != 0xff) break;
 
-            if (a >= 32){
+            if (a >= 16){
                 fprintf(stderr,"too many padding bytes\n");
                 return FALSE;
             }
@@ -153,7 +154,6 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
 
         if (itemlen < 2){
             ErrFatal("invalid marker");
-            return FALSE;
         }
 
         Sections[SectionsRead].Size = itemlen;
@@ -161,7 +161,6 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         Data = (uchar *)malloc(itemlen);
         if (Data == NULL){
             ErrFatal("Could not allocate memory");
-            return FALSE;
         }
         Sections[SectionsRead].Data = Data;
 
@@ -172,7 +171,6 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
         got = fread(Data+2, 1, itemlen-2, infile); // Read the whole section.
         if (got != itemlen-2){
             ErrFatal("Premature end of file?");
-            return FALSE;
         }
         SectionsRead += 1;
 
@@ -192,13 +190,11 @@ int ReadJpegSections (FILE * infile, ReadMode_t ReadMode)
                     Data = (uchar *)malloc(size);
                     if (Data == NULL){
                         ErrFatal("could not allocate data for entire image");
-                        return FALSE;
                     }
 
                     got = fread(Data, 1, size, infile);
                     if (got != size){
                         ErrFatal("could not read the rest of the image");
-                        return FALSE;
                     }
 
                     CheckSectionsAllocated();
@@ -325,7 +321,7 @@ int ReadJpegFile(const char * FileName, ReadMode_t ReadMode)
     // Scan the JPEG headers.
     ret = ReadJpegSections(infile, ReadMode);
     if (!ret){
-//        fprintf(stderr,"Not JPEG: %s\n",FileName);
+        fprintf(stderr,"Not JPEG: %s\n",FileName);
     }
 
     fclose(infile);
@@ -363,7 +359,7 @@ int SaveThumbnail(char * ThumbFileName)
         ExifSection = FindSection(M_EXIF);
         ThumbnailPointer = ExifSection->Data+ImageInfo.ThumbnailOffset+8;
 
-        fwrite(ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile);
+        int iRet = fwrite(ThumbnailPointer, ImageInfo.ThumbnailSize ,1, ThumbnailFile); iRet=iRet;
         fclose(ThumbnailFile);
         return TRUE;
     }else{
@@ -429,7 +425,7 @@ int ReplaceThumbnail(const char * ThumbFileName)
     ThumbnailPointer = ExifSection->Data+ImageInfo.ThumbnailOffset+8;
 
     if (ThumbnailFile){
-        fread(ThumbnailPointer, ThumbLen, 1, ThumbnailFile);
+        int iRet = fread(ThumbnailPointer, ThumbLen, 1, ThumbnailFile); iRet=iRet;
         fclose(ThumbnailFile);
     }
 
@@ -522,18 +518,18 @@ void WriteJpegFile(const char * FileName)
             0x00, 0x10, 'J' , 'F' , 'I' , 'F' , 0x00, 0x01, 
             0x01, 0x01, 0x01, 0x2C, 0x01, 0x2C, 0x00, 0x00 
         };
-        fwrite(JfifHead, 18, 1, outfile);
+        int iRet = fwrite(JfifHead, 18, 1, outfile); iRet=iRet;
     }
 
     // Write all the misc sections
     for (a=0;a<SectionsRead-1;a++){
         fputc(0xff,outfile);
         fputc((unsigned char)Sections[a].Type, outfile);
-        fwrite(Sections[a].Data, Sections[a].Size, 1, outfile);
+        int iRet = fwrite(Sections[a].Data, Sections[a].Size, 1, outfile); iRet=iRet;
     }
 
     // Write the remaining image data.
-    fwrite(Sections[a].Data, Sections[a].Size, 1, outfile);
+    int iRet = fwrite(Sections[a].Data, Sections[a].Size, 1, outfile); iRet=iRet;
        
     fclose(outfile);
 }
@@ -667,7 +663,7 @@ void ResetJpgfile(void)
         Sections = (Section_t *)malloc(sizeof(Section_t)*5);
         SectionsAllocated = 5;
     }
+
     SectionsRead = 0;
     HaveAll = 0;
 }
-
