@@ -6,8 +6,10 @@ then
 	exit
 fi
 
+rm Created_*
+
 theDate=`date +"Created_%Y%m%d_%H%M%S"`
 touch "$theDate"
-tar -czf ../tar/qdvdauthor-$1.tar.gz `find . -type f | grep -v "\.svn"`
+tar -czf ../tar/qdvdauthor-$1.tar.gz `find . -type f | grep -v "\CVS"`
 rm "$theDate"
 
