@@ -51,7 +51,7 @@ cd ../qdvdauthor/; make clean
 rm Makefile *~
 rm i18n/*.qm
 rm CONFIG.h
-rm core*
+rm -f core*
 
 if [ -e tools ];
 then
@@ -88,7 +88,14 @@ rm core*
 
 cd ../qrender/; make clean
 rm -rf Makefile *~ .obj .ui .moc 
-rm core* ffmpeg ffmpeg-export-snapshot.tar ffmpeg
+if [[ -e ffmpeg && -L ffmpeg ]]; then
+  rm -f ffmpeg
+else
+  if [ -e ffmpeg ]; then
+    rm -rf ffmpeg
+  fi;
+fi;
+rm -f core* ffmpeg*.tar* ffmpeg_location.txt*
 
 ffmpegDir=`ls -d ffmpeg-* 2>/dev/null`
 if [ "$ffmpegDir" != "" ]; then
