@@ -43,7 +43,7 @@ void Configurator::initMe ( QApplication *pApp )
 	qsLib = QString ( "mplayer" );
 	QString qsTempFile;
 	qsTempFile = QString ( "/tmp/%1_out.txt" ).arg ( getlogin ( ) );
-	iRet = system ( (const char *)QString ( "which %1 > %2 2>/dev/null").arg(qsLib).arg ( qsTempFile ) );
+	iRet = system ( (const char *)QString ( "which %1 > %2 2>/dev/null").arg(qsLib).arg ( qsTempFile ) ); iRet = iRet;
 	QFileInfo fileInfo ( qsTempFile );
 	// Okay we can not find it, so we wont bother asking the user ...
 	if ( fileInfo.size ( ) < 5 )
@@ -80,6 +80,8 @@ void Configurator::initMe ( QApplication *pApp )
 	editQtDir4->setText         ( QString ( getenv ( "QTDIR4" ) ) );
 	editLDLibraryPath->setText  ( QString ( getenv ( "LD_LIBRARY_PATH" ) ) );
 	editIncludePath->setText    ( QString ( qsIncludePath ) );
+	if ( getenv ( "CORES" ) )
+		editMakeOptions->setText ( QString ( "-j %1" ).arg ( getenv ( "CORES" ) ) );
 	// Here we check if an executable exists already ...
 	QFileInfo theFile ( "../bin/qdvdauthor" );
 	if ( ( theFile.exists ( ) ) && ( theFile.size ( ) > 1 ) )
@@ -106,7 +108,7 @@ QString Configurator::findGuiSU()
 	QFileInfo fileInfo( qsFileName );
 	for (t=0;t<3;t++)	{
 		// the next check is to see if we can find kdesu
-		iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg(arraySUs[t]).arg ( qsFileName ) );
+		iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg(arraySUs[t]).arg ( qsFileName ) ); iRet = iRet;
 		fileInfo.setFile( qsFileName );
 		// Okay we cna not find it, so we wont bother asking the user ...
 		if (fileInfo.size() > 4)	{
@@ -249,7 +251,7 @@ void Configurator::slotCompile ( )
 //		putenv ( (char *)( (const char *)listEnv [t] ) );
 
 	// qdvdauthor.pro needs those files to physically be there ... Go figure !
-	iRet = system ( "touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer ../bin/qrender" );
+	iRet = system ( "touch ../bin/qdvdauthor ../bin/qslideshow ../bin/qplayer ../bin/qrender" ); iRet = iRet;
 	// Next we should remove the Makefile's so we build with new media engine - support.
 	if ( hasMediaEngineSelectionChanged ( ) )
 		iRet = system ( "rm Makefile ../qrender/Makefile ../qdvdauthor/Makefile ../qdvdauthor/qplayer/Makefile ../qdvdauthor/qslideshow/Makefile" );
@@ -440,10 +442,26 @@ void Configurator::slotProcessExited ( )
 		listEnv.clear  ( );
 		qsPath = m_qsUsersPath;
 		qsPath = "PATH=" + qsQtDir + "/bin:" + qsPath.right ( qsPath.length ( ) - 5 );
+		QString qsPrefix;
+		if ( editInstallDir->text  ( ).isEmpty ( ) )
+			qsPrefix = QString ( "PREFIX=/usr" );
+		else
+			qsPrefix = QString ( "PREFIX=%1" ).arg ( editInstallDir->text ( ) );
+		listEnv.append ( qsPrefix );
+
+		if ( editSystemPath->text ( ).isEmpty ( ) )  {
+			qsPrefix.replace  ( "PREFIX", "SYSTEM_PATH" );
+			listEnv.append    ( qsPrefix );
+		}
+		else
+			listEnv.append ( QString ( "SYSTEM_PATH=%1" ).arg ( editSystemPath->text ( ) ) );
 
 		listEnv.append ( qsPath );
  		listEnv.append ( QString ( "QTDIR=%1" ).arg ( qsQtDir ) );
-		listEnv.append ( "STATIC_FFMPEG=1" );
+		if ( m_pCheckLocalFFMpeg->isChecked ( ) )
+			listEnv.append ( "STATIC_FFMPEG=1" );
+		else
+			listEnv.append ( "SYSTEM_FFMPEG=1" );
 	}
 	if ( m_iCompileStep == 3 )  {
 		// qrender will be built as part of the local_=ffmpeg.sh - script.
@@ -646,7 +664,7 @@ void Configurator::slotMakeClean()
 	iRet = system ( "rm ../bin/qdvdautor; rm ../bin/qslideshow; rm ../bin/qplayer; rm ../bin/configurator; rm ../bin/qrender; rm ../bin/core*");
 	iRet = system ( "rm ../qdvdauthor/i18n/*.qm ../qdvdauthor/CONFIG.h ../qdvdauthor/qplayer/MEDIA_CONFIG.h 2>&1 > /dev/null" );
 	iRet = system ( "../addons/make.sh clean" );
-	iRet = system ( "../qdvdauthor/plugins/make.sh clean" );
+	iRet = system ( "../qdvdauthor/plugins/make.sh clean" ); iRet = iRet;
 	buttonExecute->setEnabled( false );
 	buttonInstall->setEnabled( false );
 }
@@ -654,7 +672,7 @@ void Configurator::slotMakeClean()
 void Configurator::slotExecute ( )
 {
 	int iRet = 0;
-	iRet = system ( "../bin/qdvdauthor &" );
+	iRet = system ( "../bin/qdvdauthor &" ); iRet = iRet;
 }
 
 void Configurator::slotInstall ( )
