@@ -24,6 +24,8 @@ echo "qdvdauthor.spec version is   :  $version"
 xml_version=`grep QDVDAUTHOR_VERSION_NUMBER qdvdauthor/xml_dvd.h | awk '{ print $3 }'`;
 echo "XML version ( xml_dvd.h ) is : $xml_version"
 
+echo "Please make sure that the version in ServerVersion is also updated"
+
 # now we create the directory
 CURRENT_PATH=`pwd`
 cd ..
@@ -33,4 +35,20 @@ cp -R $CURRENT_PATH/* qdvdauthor-$version/
 # Finally we create the tarball
 tar -czf qdvdauthor-$version.tar.gz qdvdauthor-$version
 
+cat <<EOF
+Now go to 
+http://www.SourceForge.net
+Log in as QDVDAuthor
+Click on Files
+Click on [Add Folder]
+Click on newly created Folder
+Click on [Add FIle]
+Add the source + the CHANGELOG files
+Then IMPORTANT click on (i) icon
+ - Define Donload Button ( E.g. Release 2.2.0 )
+ - Check all OS
+Click [Save]
+
+EOF
+
 
