@@ -7,7 +7,7 @@ fi;
 
 pass=$1
 
-cd $HOME/projects/
+cd $HOME/projects/old
 
 echo "cd htdocs/nightly/
 put qdvdauthor.tar.bz2
