@@ -54,11 +54,69 @@ class QListViewItem;
 
 class SourceFileEntry;
 class SourceFileInfo;
+class CXmlSlideshow;
 class MenuPreview;
+class DVDMenu;
+
+class ButtonTransition  {
+  // Container to define the transition
+  // from a menu to another menu
+  // or
+  // from a menu to a movie
+  // or
+  // from the end of a movie to a menu
+public:
+   ButtonTransition ( );
+  ~ButtonTransition ( );
+
+  ButtonTransition &operator  = ( const ButtonTransition & );
+  bool              operator == ( const ButtonTransition & );
+
+  CXmlSlideshow *createSlideshow ( );
+
+  void initMe           ( );
+  bool readProjectFile  ( QDomNode    & );
+  bool writeProjectFile ( QDomElement & );
+
+  bool    bUserFile;
+  float   fDuration; // ( in seconds )
+  QString qsName;    // <MenuName>/<ButtonName>
+  QString qsTransitionVideoFileName;  // temp file name ( under $TEMP/<MenuName>/<ButtonName>.vob )
+  int     iFormat;
+  int     iTransitionType;     // Either cross_fade or alpha_fade.
+  QString qsTransitionName;    // The full path to the alpha-transition file
+  bool    bFinishedRendering;  // flags if rendering has finished.
+};
 
 class ButtonObject : public MenuObject
 {
 	Q_OBJECT
+
+	class ButtonData : public MenuObject::Data
+	{
+	public:
+	           ButtonData ( );
+	  virtual ~ButtonData ( );
+	  virtual  Data &operator  = ( Data & );
+	  virtual  bool  operator == ( Data & );
+	  virtual  Data *clone ( );
+
+	  QString m_qsAction;     // the action to take ...
+	  QString m_qsPreAction;  // ';' separated commands before the jump - action.
+	  QString m_qsUp;
+	  QString m_qsDown;
+	  QString m_qsRight;
+	  QString m_qsLeft;
+	  ButtonTransition *m_pTransition;
+	  QString m_qsSourceDisplayName;
+	  // The following lists hold the information for the different button states.
+	  QValueList<MenuObject *> m_listNormalState;      // Image or Movie, Frame, Text, Background
+	  QValueList<MenuObject *> m_listSelectedState;    // Frame, Text, Background
+	  QValueList<MenuObject *> m_listHighlightedState; // Frame, Text, Background
+
+	  QStringList              m_listPlayMultiple;     // If the user selected multiple files to be played
+	  bool                     m_bLoopMultiple;        // Loop after playing all files in the Multiple list.
+	};
 public:
 	ButtonObject (QWidget *pParent = 0); //, const char * name = 0, WFlags f = 0 );
 	virtual ~ButtonObject();
@@ -71,11 +129,10 @@ public:
 	virtual bool mouseDoubleClickEvent( QMouseEvent *       );
 	virtual MenuObject *clone         ( QWidget *p1=NULL, MenuObject *p2=NULL );
 	virtual ButtonObject &operator =  ( ButtonObject &      );
-
 	virtual MenuObject *shadow        ( );
 	virtual void updateShadow         ( );
 	virtual void setShadow            ( MenuObject * );
-
+	virtual void resetStructureItem   ( );
 	virtual bool readProjectFile      ( QDomNode    &  );
 	virtual bool writeProjectFile     ( QDomElement &  );
 	virtual StructureItem *createStructure ( StructureItem * );
@@ -83,9 +140,12 @@ public:
 	virtual void setRect              ( QRect &        );
 	virtual QRect &rect               ( );
 	virtual QRect &boundingRect       ( );
+//	virtual void  setData             ( Data * );
 	void createMask                   ( Rgba *         );
 	void setPlayMultipleList          ( QStringList &  );
 	void setLoopMultiple              ( bool );
+	void setTransition                ( ButtonTransition * );
+	void reParentChildren             ( );
 
 	void appendNormal                 ( MenuObject  *  );
 	void appendSelected               ( MenuObject  *  );
@@ -111,7 +171,9 @@ public:
 	bool setMaskColor                 ( Rgba, bool, int i=0 );
 	QStringList &getPlayMultipleList  ( );
 	bool         getLoopMultiple      ( );
+	ButtonTransition *getTransition   ( );
 
+	long getOffset                    ( );
 	int  chapter                      ( bool );
 	void setAction                    ( QString & );
 	void setPreAction                 ( QString & );
@@ -120,6 +182,7 @@ public:
 	QString &action                   ( );
 	QString &preAction                ( );
 
+	DVDMenu         *dvdMenu          ( );
 	SourceFileInfo  *sourceFileInfo   ( );
 	SourceFileEntry *sourceFileEntry  ( );
 	void setSourceFileEntry           ( SourceFileEntry *);
@@ -131,16 +194,19 @@ public:
 	void replaceColor                 ( Rgba, Rgba );
 
 protected:
-	void clear ();
-	virtual AnimationAttribute *getSpecificAttributes (long, QString);
-
+	void clear    ( );
+	void reParent ( MenuObject * );
+	ButtonData *buttonData ( );
+	virtual AnimationAttribute *getSpecificAttributes ( long, QString );
 
 signals:
-	void signalUnbuttonMe             (ButtonObject *);
-	void signalCreateButtonDialog     (ButtonObject *);
+	void signalUnbuttonMe             ( ButtonObject * );
+	void signalCreateButtonDialog     ( ButtonObject * );
 
 public slots:
 	virtual void slotEdit             ( );
+	virtual void slotEditShadow       ( );
+	virtual void slotEditMask         ( );
 	virtual void slotEditObject       ( );
 	virtual void slotObjectProperties ( );
 	virtual void slotUnbutton         ( );
@@ -154,22 +220,8 @@ public slots:
 protected:
 	int     m_iButtonState;
 	bool    m_bMoveable;
-	QString m_qsAction;	// the action to take ...
-	QString m_qsPreAction;  // ';' separated commands before the jump - action.
-	QString m_qsUp;
-	QString m_qsDown;
-	QString m_qsRight;
-	QString m_qsLeft;
-	SourceFileEntry *m_pSourceFileEntry;
-	QString m_qsSourceDisplayName;
-	// The following lists hold the information for the different button states.
-	QValueList<MenuObject *> m_listNormalState;      // Image or Movie, Frame, Text, Background
-	QValueList<MenuObject *> m_listSelectedState;    // Frame, Text, Background
-	QValueList<MenuObject *> m_listHighlightedState; // Frame, Text, Background
-
-	QStringList              m_listPlayMultiple;     // If the user selected multiple files to be played
-	bool                     m_bLoopMultiple;        // Loop after playing all files in the Multiple list.
+	SourceFileEntry  *m_pSourceFileEntry;
 };
 
-#endif	// BUTTONOBJECT_H
+#endif // BUTTONOBJECT_H
 
