@@ -104,8 +104,10 @@ Thumbs::Entry::Entry ( Thumbs *pParent )
   iStarRating     = 0;
   iScanStatus     = 0;
   iFileSize       = 0;
+  fRotate         = 0.0f;
   bStoreData      = true;
   bSourceExists   = true;
+  bIsVideo        = true;
   arrayOfThumbs   = NULL;
   pCache          = pParent;
   dateCreated     = QDateTime::currentDateTime ( );
@@ -124,6 +126,8 @@ bool Thumbs::Entry::readXml ( QDomElement *pSource )
   iFileSize        = a.value ( ).toUInt ( );
   a = pSource->attributeNode ( CACHE_RATING );
   iStarRating      = a.value ( ).toUInt( );
+  a = pSource->attributeNode ( CACHE_ROTATE );
+  fRotate          = a.value ( ).toFloat( );
   a = pSource->attributeNode ( CACHE_NR_OF_THUMBS );
   iNumberOfThumbs  = a.value ( ).toUInt( );
   a = pSource->attributeNode ( CACHE_COMMENT );
@@ -174,16 +178,18 @@ bool Thumbs::Entry::writeXml ( QDomElement *pCacheElement )
   qsVirtualFolder = listVirtualFolders.join ( ";" );
 
   // Here we set the attributes of the <Source> tag
-  entryNode.setAttribute ( CACHE_FILE_SIZE,    QString ( "%1" ).arg ( iFileSize       ) );
-  entryNode.setAttribute ( CACHE_RATING,       QString ( "%1" ).arg ( iStarRating     ) );
-  entryNode.setAttribute ( CACHE_NR_OF_THUMBS, QString ( "%1" ).arg ( iNumberOfThumbs ) );
-  entryNode.setAttribute ( CACHE_VIRTUAL,   qsVirtualFolder           );
-  entryNode.setAttribute ( CACHE_COMMENT,   qsComment                 );
-  entryNode.setAttribute ( CACHE_CREATED,   dateCreated.toString  ( ) );
-  entryNode.setAttribute ( CACHE_LENGTH,    qsLength                  );
-  entryNode.setAttribute ( CACHE_FILE_NAME, qsFileName.utf8       ( ) );
-  entryNode.setAttribute ( CACHE_LAST_USED, dateLastUsed.toString ( ) );
-  entryNode.appendChild  ( entryText );
+  entryNode.setAttribute  ( CACHE_FILE_SIZE,    QString ( "%1" ).arg ( iFileSize       ) );
+  entryNode.setAttribute  ( CACHE_RATING,       QString ( "%1" ).arg ( iStarRating     ) );
+  if ( fRotate != 0.0f )
+    entryNode.setAttribute( CACHE_ROTATE,     QString ( "%1" ).arg ( fRotate      ) );
+  entryNode.setAttribute  ( CACHE_NR_OF_THUMBS, QString ( "%1" ).arg ( iNumberOfThumbs ) );
+  entryNode.setAttribute  ( CACHE_VIRTUAL,   qsVirtualFolder           );
+  entryNode.setAttribute  ( CACHE_COMMENT,   qsComment                 );
+  entryNode.setAttribute  ( CACHE_CREATED,   dateCreated.toString  ( ) );
+  entryNode.setAttribute  ( CACHE_LENGTH,    qsLength                  );
+  entryNode.setAttribute  ( CACHE_FILE_NAME, qsFileName.utf8       ( ) );
+  entryNode.setAttribute  ( CACHE_LAST_USED, dateLastUsed.toString ( ) );
+  entryNode.appendChild   ( entryText );
 
   pCacheElement->appendChild (  entryNode );
   return true;
@@ -283,8 +289,8 @@ Thumbs::ImageEntry::ImageEntry ( Thumbs *pParent )
   : Entry ( pParent )
 {
   bSaveImage   = true;
-  fRotate      = 0.0f;
   iOrientation = 0;
+  bIsVideo     = false;
   pMatrix      = NULL;
 }
 
@@ -332,7 +338,7 @@ bool Thumbs::ImageEntry::readXml ( QDomElement *pSource )
   dateLastUsed = QDateTime::fromString ( qsDateLastUsed, Qt::ISODate );
   listVirtualFolders = QStringList::split ( ";", qsVirtualFolder );
 
-  QStringList listSize = QStringList::split ( qsDimension, "x" );
+  QStringList listSize = QStringList::split ( "x", qsDimension );
   bSaveImage = true;
   if ( listSize.count ( ) > 1 )  {
     int iWidth  = listSize[0].toInt ( );
@@ -340,13 +346,12 @@ bool Thumbs::ImageEntry::readXml ( QDomElement *pSource )
     bSaveImage  = ( ( iWidth > 640 ) || ( iHeight > 480 ) || ( iWidth == 0 ) || ( iHeight == 0 ) );
   }
   // At this point we have all bu the thumbnails
-  //iHashValue = pCache->hashFromFile ( qsFileName );
   bool bOkay = true;
   iHashValue = qsHashValue.toULongLong ( &bOkay, 16 );
   if ( ! bOkay )
     iHashValue = pCache->hashFromFile ( qsFileName );
   //printf ( "Thumbs::Entry::readXml <0x%016llX> <%s> <%s>\n", iHashValue, pSource->text ( ).ascii ( ), qsFileName.ascii ( ) );
-  bSaveImage = false;
+
   initMatrix ( ); // maybe needed ...
   if ( iHashValue == 0LL ) {
     // File does not exist anymore. We want to keep the record around
@@ -454,7 +459,7 @@ bool Thumbs::ImageEntry::loadImages ( ) // load images from cache or from the fi
         arrayOfThumbs[0]  = pInfo->pThumbnail;
         pInfo->pThumbnail = NULL;
         bSaveImage        = false;  // Set to false if the image size is < 641 x 481
-        bStoreData        = false;  // no need to keep the record in the cache
+//      bStoreData        = false;  // no need to keep the record in the cache
         iScanStatus       = 2;      // 0=undef, 1=scanning, 2=scanning done.
       }
       else
@@ -503,7 +508,7 @@ void Thumbs::ImageEntry::scanImages ( QObject * ) // load images from cache
   if ( pPlugin )  {
     jhead::JHead::Info *pInfo = pPlugin->getFileInfo ( qsFileName );
     if ( pInfo && pInfo->pThumbnail )  {
-//printf ( "%s::%s : %d > imgDate<%s> vs created<%s>\n", __FILE__, __FUNCTION__, __LINE__, pInfo->imageDate.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ), dateCreated.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ) );
+// printf ( "%s::%s : %d > imgDate<%s> vs created<%s>\n", __FILE__, __FUNCTION__, __LINE__, pInfo->imageDate.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ), dateCreated.toString  ( "yyyy-MM-dd hh:mm:ss" ).ascii ( ) );
       if ( pInfo->imageDate.isValid ( ) )
         dateCreated = pInfo->imageDate;
 
@@ -1283,7 +1288,9 @@ Thumbs::Entry *Thumbs::append ( QString &qsFile, QImage *pImage )
   else
     pEntry->scanImages ( );
 
-  saveImageDB ( );  // save only if no Exif preview was found because now we have to generate the thumb
+  // Now done at the calling function, outside the loop for the images.
+  // otherwise we woulds write the XML file for every image.
+  //  saveImageDB ( );  // save only if no Exif preview was found because now we have to generate the thumb
 
   //  printf ( "Cache::Thumbs::append <%s> = <%016llX>\n", pEntry->qsFileName.ascii(), pEntry->iHashValue );
   return pEntry; 
