@@ -44,6 +44,7 @@
 #include "messagebox.h"
 #include "dialogselect.h"
 #include "buttonobject.h"
+#include "imageobject.h"
 #include "buttonpreview.h"
 #include "sourcefileentry.h"
 #include "dialogbuttontrans.h"
@@ -162,11 +163,20 @@ void DialogButton::initMe ( ButtonObject *pButton, MenuPreview *pView )
 	m_pRadioSelectedFrame->setChecked ( !bChecked ); 
 	m_pSelectedMask[bChecked] = pMenuObject;
 
-	pMenuObject = m_pClonedButton->getNormal ( 0 );
+	bool bEnable = false;
+	pMenuObject  = m_pClonedButton->getNormal ( 0 );
 	if ( pMenuObject->objectType ( ) == FRAME_OBJECT ) {
 	  m_pGroupHighlighted->setEnabled ( false );
 	  m_pGroupSelected   ->setEnabled ( false );
 	}
+	else if ( ( pMenuObject->objectType ( ) == IMAGE_OBJECT ) ||
+	          ( pMenuObject->objectType ( ) == MOVIE_OBJECT ) )  {
+		bEnable = true;
+		ImageObject *pImage = (ImageObject *)pMenuObject;
+		m_pCheckHide->setChecked ( pImage->hidden ( ) );
+	}
+	if ( ! bEnable )
+		m_pCheckHide->hide ( );
 
 	// Now we proceed to initialize the GUI objects (LineEdits, ComboBoxes etc.)
 	initNext       ( );
@@ -208,7 +218,7 @@ void DialogButton::initMe ( ButtonObject *pButton, MenuPreview *pView )
 	connect (m_pEditAction,       SIGNAL ( textChanged(const QString &)), this, SLOT(slotEditActionChanged(const QString &)));
 
 	// Next are the slots related to the color buttons in the Highlighted / Selected - tab.
-	connect (m_pRadioHColor1,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotUseColor ( bool ) ) );
+        connect (m_pRadioHColor1,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotUseColor ( bool ) ) );
 	connect (m_pRadioHColor2,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotUseColor ( bool ) ) );
 	connect (m_pRadioHColor3,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotUseColor ( bool ) ) );
 	connect (m_pRadioHColor4,     SIGNAL ( toggled ( bool ) ), this, SLOT ( slotUseColor ( bool ) ) );
@@ -1085,7 +1095,7 @@ void DialogButton::slotChangeColor ( )
   iIdx = t%4;
 
   MenuObject **pMasks      = m_pSelectedMask;
-  MenuObject **pOtherMasks = m_pHighlightedMask;
+//  MenuObject **pOtherMasks = m_pHighlightedMask;
   bool bHighlighted   = ( t  ==  iIdx );
   Rgba oldColor = m_pgcColors[iIdx];
   QRgb rgba;
@@ -1109,7 +1119,7 @@ void DialogButton::slotChangeColor ( )
   if ( bHighlighted ) {
     m_iColorIdx[1] = iIdx;
     pMasks      = m_pHighlightedMask;
-    pOtherMasks = m_pSelectedMask;
+//    pOtherMasks = m_pSelectedMask;
   }
   else 
     m_iColorIdx[0] = iIdx;
@@ -1428,6 +1438,28 @@ void DialogButton::slotOkay ( )
 
   // And last but not least we equalize the original with the cloned brother ...
   *m_pButtonObject = *m_pClonedButton;
+/*
+  pObject = m_pButtonObject->getNormal ( 0 );
+  if ( ( list.count ( ) > 0 ) && ( list[0]->objectType ( ) == pObject->objectType ( ) ) )  {
+    if ( ( pObject->objectType ( ) == IMAGE_OBJECT ) ||
+         ( pObject->objectType ( ) == MOVIE_OBJECT ) )  {
+      // The only object parameter that can be changed here.
+      ImageObject *pImageObject1 = (ImageObject *)pObject;
+      ImageObject *pImageObject2 = (ImageObject *)list[0];
+
+      pImageObject2->setHidden ( m_pCheckHide->isOn ( ) );
+    }
+  }
+*/
+  if ( list.count ( ) > 0 )  {
+    pObject = list[0];
+    if ( ( pObject->objectType ( ) == IMAGE_OBJECT ) ||
+         ( pObject->objectType ( ) == MOVIE_OBJECT ) )  {
+      // The only object parameter that can be changed here.
+      ImageObject *pImageObject = (ImageObject *)pObject;
+      pImageObject->setHidden ( m_pCheckHide->isOn ( ) );
+    }
+  }
 
   for ( t=0; t<m_pButtonObject->getNormalCount ( ); t++ )  {
     pObject =  m_pButtonObject->getNormal ( t );
@@ -1457,6 +1489,15 @@ void DialogButton::slotOkay ( )
     m_pButtonObject->appendNormal   ( list[t] );
   m_pButtonObject->reParentChildren ( );
 
+/*  VAROL
+  pObject = m_pButtonObject->getNormal ( 0 );
+    if ( ( pObject->objectType ( ) == IMAGE_OBJECT ) ||
+         ( pObject->objectType ( ) == MOVIE_OBJECT ) )  {
+      // The only object parameter that can be changed here.
+      ImageObject *pImageObject1 = (ImageObject *)pObject;
+    }
+*/
+
   m_pFramePreviewNormal->clearObjectList ( );
   m_pFrameHighlighted->clearObjectList   ( );
   m_pFrameSelected->clearObjectList      ( );
@@ -1492,3 +1533,17 @@ void DialogButton::slotOkay ( )
 
   accept ( );
 }
+
+/*
+void DialogButton::slotHideNormal ( bool bOn )
+{
+  // Called when the user does not want to display the ImageObject but insread is only interested in the
+  // Created Highlighted / Selected masks for button.
+  MenuObject *pNormal = m_pClonedButton->getNormal ( 0 );
+  if ( ( pNormal->objectType ( ) == IMAGE_OBJECT ) ||
+       ( pNormal->objectType ( ) == MOVIE_OBJECT ) )  {
+    ImageObject *pImageObject = (ImageObject *)pNormal;
+    pImageObject->setHidden ( bOn );
+  }
+}
+*/
