@@ -513,7 +513,7 @@ QString DialogCreateTemplate::findGuiSU ( )
   QFileInfo fileInfo( qsTmpOut );
   for (t=0;t<3;t++)	{
     // the next check is to see if we can find kdesu
-    iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg( arraySUs[t] ).arg ( qsTmpOut ) );
+    iRet = system ((const char *)QString ("which %1 > %2 2>/dev/null").arg( arraySUs[t] ).arg ( qsTmpOut ) ); iRet = iRet;
     fileInfo.setFile( qsTmpOut );
     // Okay we cna not find it, so we wont bother asking the user ...
     if (fileInfo.size() > 4)	{
@@ -637,7 +637,7 @@ QString DialogCreateTemplate::createTemplate ( )
 
   qsTemplatePath = QString ( "%2%3").arg ( getTypePath ( ) ).arg ( qsFileName );
   qsCommand = QString ( "cd %1; tar -czf %2.tar.gz %3" ).arg ( qsTempPath ).arg ( qsFileName ).arg( qsTemplatePath );
-  iRet = system ( qsCommand.ascii ( ) );
+  iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;
 
   // These two functions are for convenience ... 
   // And need to get executed AFTER the creation of the Template package file
@@ -816,7 +816,7 @@ void DialogCreateTemplate::handleMenuAudio ( QString &qsMenuXml, QString &qsTemp
 	qsFileName = QFile::encodeName ( fileInfo.fileName ( ) );
 	qsTemplateFileName = QString ( "+PREFIX_DIRECTORY+/%1%2/%3" ).arg ( getTypePath ( ) ).arg ( m_pEditFileName->text ( ) ).arg ( qsFileName );
 	qsCommand = QString ( "cp \"%1\" \"%2/%3\"" ).arg ( listSoundFiles[t] ).arg ( qsTemplatePath ).arg ( qsFileName );
-	iRet = system ( qsCommand.ascii ( ) );
+	iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;
 	qsSoundEntries += "   <MenuSound>" + qsTemplateFileName + "</MenuSound>\n";
       }
     }
@@ -903,7 +903,7 @@ void DialogCreateTemplate::handleMenuImages ( QString &qsMenuXml, QString &qsTem
 	qsFileName = QFile::encodeName ( fileInfo.fileName ( ) );
 	// Next we should copy the file over ...
 	qsCommand = QString ( "cp \"%1\" \"%2\"" ).arg ( listTemp[1] ).arg ( qsTemplatePath );
-	iRet = system ( qsCommand.ascii ( ) );
+	iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;
       }
       else // Not found .. Oooops ...
 	qsFileName = QString ( "dummy.png" );
@@ -1050,8 +1050,7 @@ bool DialogCreateTemplate::createBackground ( QString &qsTemplatePath )
     QFileInfo fileInfo ( qsMenuPath + "/menu.m2v" );
     if ( fileInfo.exists ( ) )    {
       QString qsCommand = QString ( "ffmpeg -i \"%1\" -t 10 -s 200x134 -y \"%2\" >/dev/null 2>&1" ).arg ( qsMenuPath + "/menu.m2v" ).arg ( qsTemplatePath + "/thumbnail.mpg" );
-      int iRet = system ( qsCommand );
-      iRet = iRet;
+      iRet = system ( qsCommand ); iRet = iRet;
     }
   }
 
