@@ -34,6 +34,7 @@
 #include "global.h"
 #include "previewer.h"
 #include "qdvdauthor.h"
+#include "messagebox.h"
 #include "dialogimages.h"
 #include "xml_slideshow.h"
 #include "slidedefaults.h"
@@ -88,8 +89,11 @@ DialogImages::~DialogImages ( )
   unlockDialog    ( );
 }
 
-void DialogImages::initMe ( )
+void DialogImages::initMe ( SourceFileEntry *pEntry )
 {
+  if ( pEntry )
+    m_listOfGroups.append ( pEntry );
+
   DialogFiles::initMe ( );
   m_pContextMenu = NULL;
   m_pPreviewer   = new Previewer ( m_pFramePreview, m_pPreview );
@@ -123,8 +127,11 @@ void DialogImages::slotEditGroup ( )
     pSlideshow = new CXmlSlideshow;
     pSlideshow->slideshow_name = qsLabel;
     Global::pSlideDefaults->initSlideshow ( pSlideshow );
+//    populateFromGroup ( pSlideshow, pGroupView );
     pGroupView->setSlideshow ( pSlideshow );
   }
+
+  populateFromGroup ( pSlideshow, pGroupView );
   DialogSlideshow theDialog ( this );
   theDialog.initMe    ( pSlideshow );
 
@@ -142,6 +149,7 @@ void DialogImages::slotEditGroup ( )
     pSlideshow->xres             = 720;
     pSlideshow->aspect           = ( ( iFormat == 0 ) || ( iFormat == 1 ) ) ? 0 : 1;  // 4:3 or 16:9
     pSlideshow->setImgBkgImg ( theDialog.m_pRadioImgBkgImg->isChecked ( ) );
+    pSlideshow->setKenBurns  ( theDialog.m_pCheckKenBurns ->isChecked ( ) );
   }
 }
 
@@ -171,6 +179,22 @@ void DialogImages::playFromGroup ( Cache::Thumbs::Entry *pCache )
   Global::pThumbsCache->saveImageDB ( );
 }
 
+void DialogImages::initGroups ( )
+{
+  if ( m_listOfGroups.size ( ) < 1 )  {
+    DialogFiles::initGroups    ( );
+    return;
+  }
+  // We are coming from the context menu of a slideshow and do only want to handle this single one
+  m_pButtonNew->hide    ( );
+  m_pButtonDelete->hide ( );
+  connect ( m_pButtonEdit,   SIGNAL ( clicked ( ) ), this, SLOT ( slotEditGroup   ( ) ) );
+  
+  SourceFileEntry *pEntry = m_listOfGroups[0];
+  m_listOfGroups.clear ( );
+  addGroup ( pEntry );
+}
+
 GroupView *DialogImages::addGroup ( SourceFileEntry *pEntry )
 {
   // DialogImages is only interested in Slideshow Entries.
@@ -227,6 +251,12 @@ GroupView *DialogImages::addGroup ( SourceFileEntry *pEntry )
                theImage = pCache->arrayOfThumbs[0]->xForm ( *pCache->getMatrix ( ) );
                theImage = theImage.smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
           }
+          else if ( ( pCache->fRotate != 0.0 ) && ( pCache->bIsVideo ) )  {
+               QWMatrix matrix;
+               matrix.rotate ( pCache->fRotate );
+               theImage = pCache->arrayOfThumbs[0]->xForm ( matrix );
+               theImage = theImage.smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
+          }
           else
             theImage = pCache->arrayOfThumbs[0]->smoothScale ( GroupView::m_iSize, GroupView::m_iSize, QImage::ScaleMin );
 
@@ -239,6 +269,7 @@ GroupView *DialogImages::addGroup ( SourceFileEntry *pEntry )
     else
       pItem->setPixmap ( 0, errorPixmap );
   }
+  Global::pThumbsCache->saveImageDB ( );
 
   connect  ( pGroupView, SIGNAL ( contextMenuRequested ( QListViewItem *, const QPoint &, int ) ), this, SLOT ( slotGroupContextMenu ( QListViewItem *, const QPoint &, int ) ) );
 
@@ -333,14 +364,14 @@ void DialogImages::slotCheckWorker ( )
     m_pPreview->arrangeItemsInGrid ( TRUE );
   qApp->processEvents ( 100 );
 
-  lock   ( );
+  lock ( );
   if ( m_listOfImageScansToDo.count ( ) + m_listOfImageScansDone.count ( ) > 0 )  {
     QTimer::singleShot ( 100, this,  SLOT ( slotCheckWorker ( ) ) );
     // sanity check. Sometimes the worker get eliminated before the whole work s done.
     if ( ( m_listOfWorker.count  ( ) == 0 ) && ( m_listOfImageScansToDo.count ( ) > 0 ) )
            m_listOfWorker.append ( new  Worker ( this ) );
   }
-  else
+  else 
     m_pProgressBar->setProgress ( 0 );
   unlock ( );
 }
@@ -473,6 +504,12 @@ void ImageScan::createPix ( )
       QImage tempImage = pEntry->pCache->arrayOfThumbs[0]->xForm ( *pEntry->pCache->getMatrix ( ) );
       pDialog->createPix ( &pEntry->thePixmap,  &tempImage,  0.0f,  pEntry->pCache->iStarRating );
     }
+    else if ( ( pEntry->pCache->fRotate != 0.0 ) && ( pEntry->pCache->bIsVideo ) )  {
+      QWMatrix matrix;
+      matrix.rotate     ( pEntry->pCache->fRotate );
+      QImage tempImage  = pEntry->pCache->arrayOfThumbs[0]->xForm (  matrix );
+      pDialog->createPix(&pEntry->thePixmap,   &tempImage,  0.0f,  pEntry->pCache->iStarRating );
+    }
     else
       pDialog->createPix ( &pEntry->thePixmap, pEntry->pCache->arrayOfThumbs[0], 0.0f, pEntry->pCache->iStarRating );
 
@@ -657,7 +694,7 @@ void DialogImages::showBasicMenu ( const QPoint &pos )
   stopThumbing ( );
   if ( iID ==  1 ) // All to Virtual Folder
     toVirtualFolder( 2 );
-  else if ( iID  ==  2 ) // All to Source Group
+  else if ( iID  ==  2 )  // All to Source Group
     toSourceGroup  ( 2 );
   else if ( iID  ==  3 )  // Auto Group
     slotAutoGroup  (   );
@@ -710,23 +747,23 @@ void DialogImages::showContextMenu ( const QPoint &pos, QIconViewItem * )
   }
 
   // We first create the menu on the right, non blocking.
-  QPopupMenu *pStackMenu  =  new  QPopupMenu     (  this  );
-  pStackMenu->insertItem ( tr ( "R&emove" ),        this, SLOT ( slotRemove     ( ) ) );
-  iID     = pStackMenu->insertItem ( tr ( "&View ..." ),      this, SLOT ( slotView       ( ) ) );
+  QPopupMenu *pStackMenu = new QPopupMenu (  this  );
+  pStackMenu->insertItem ( tr ( "R&emove" ), this, SLOT ( slotRemove ( ) ) );
+  iID     = pStackMenu->insertItem ( tr ( "&View ..." ),    this, SLOT ( slotView       ( ) ) );
   pStackMenu->insertSeparator ( );
-  iIDs[1] = pStackMenu->insertItem ( tr ( "Rotate &90"  ),    this, SLOT ( slotRotate90   ( ) ) );
-  iIDs[2] = pStackMenu->insertItem ( tr ( "Rotate &180" ),    this, SLOT ( slotRotate180  ( ) ) );
-  iIDs[3] = pStackMenu->insertItem ( tr ( "Rotate &270" ),    this, SLOT ( slotRotate270  ( ) ) );
-  iIDs[4] = pStackMenu->insertItem ( tr ( "Rotate &Free" ),   this, SLOT ( slotRotateFree ( ) ) );
+  iIDs[1] = pStackMenu->insertItem ( tr ( "Rotate &90"  ),  this, SLOT ( slotRotate90   ( ) ) );
+  iIDs[2] = pStackMenu->insertItem ( tr ( "Rotate &180" ),  this, SLOT ( slotRotate180  ( ) ) );
+  iIDs[3] = pStackMenu->insertItem ( tr ( "Rotate &270" ),  this, SLOT ( slotRotate270  ( ) ) );
+  iIDs[4] = pStackMenu->insertItem ( tr ( "Rotate &Free" ), this, SLOT ( slotRotateFree ( ) ) );
   if (  listIcons.count  ( ) > 1 )
     pStackMenu->setItemEnabled ( iID, false );
 
-  if ( bVidsSelected )  {
-    pStackMenu->setItemEnabled ( iIDs[1], false );
-    pStackMenu->setItemEnabled ( iIDs[2], false );
-    pStackMenu->setItemEnabled ( iIDs[3], false );
+//  pStackMenu->setItemEnabled ( iIDs[1], false );
+//  pStackMenu->setItemEnabled ( iIDs[2], false );
+//  pStackMenu->setItemEnabled ( iIDs[3], false );
+  if ( bVidsSelected )
     pStackMenu->setItemEnabled ( iIDs[4], false );
-  }
+
   //globalPos.setY    ( globalPos.y ( ) - 25 );
   globalPos.setX    ( globalPos.x ( ) - pStackMenu->sizeHint ( ).width ( ) - 4 );
   pStackMenu->popup ( globalPos, 3 );
@@ -762,7 +799,10 @@ void DialogImages::showContextMenu ( const QPoint &pos, QIconViewItem * )
         pThumbs->pCache->iStarRating = iID - 1;
         recreateThumbs  ( pThumbs );
       }
-      Global::pThumbsCache->saveImageDB ( );
+      if ( bVidsSelected )
+        Global::pThumbsCache->saveCacheDB ( );
+      else
+        Global::pThumbsCache->saveImageDB ( );
       unlockDialog ( );
     }
     else if  (  iID ==  8 )
@@ -898,10 +938,11 @@ void DialogImages::rotate ( double fRotate )
 
   // rotate thumb[0] and Pix[0]
   bool bSaveCache = false;
+  bool bIsImage   = false;
   Thumbs *pThumbs;
   QValueList<Thumbs *>listTemp;
   QValueList<Thumbs *>::iterator it;
-  Cache::Thumbs::ImageEntry *pCache;
+  Cache::Thumbs::Entry *pCache = NULL;
 
   // Going through the list of images and rotate them according to the iOrientation value
   lock ( );
@@ -919,12 +960,20 @@ void DialogImages::rotate ( double fRotate )
   it = listTemp.begin ( );
   while ( it != listTemp.end ( ) ) {
     pThumbs = *it++;
-    pCache  = (Cache::Thumbs::ImageEntry *)pThumbs->pCache;
+//    pCache  = (Cache::Thumbs::ImageEntry *)pThumbs->pCache;
+    pCache  = (Cache::Thumbs::Entry *)pThumbs->pCache;
+    bIsImage = isImageDialog ( pCache->qsFileName );
+
     // And finally if we modified the thumb we should save it.
     if ( pCache->arrayOfThumbs )  {
          pCache->bStoreData = true;
          pCache->fRotate   += (float)fRotate;
-         pCache->initMatrix ( );
+         while ( pCache->fRotate >=  360.0 )
+                 pCache->fRotate -=  360.0;
+         while ( pCache->fRotate <= -360.0 )
+                 pCache->fRotate +=  360.0;
+         if ( bIsImage )
+            ((Cache::Thumbs::ImageEntry *)pCache)->initMatrix ( );
          bSaveCache = true;
     }
     recreateThumbs ( pThumbs );
@@ -961,7 +1010,7 @@ void DialogImages::clearWorker ( )
 }
 
 //void DialogImages::rescueImageAttributes ( CXmlSlideshow::img_struct *pXmlImg, CXmlSlideshow *pTemp )
-void DialogImages::rescueImageAttributes (  void *pVoidImg, CXmlSlideshow *pSlideshow )
+bool DialogImages::rescueImageAttributes (  void *pVoidImg, CXmlSlideshow *pSlideshow )
 {
   CXmlSlideshow::img_struct *p, *pXmlImg = (CXmlSlideshow::img_struct *)pVoidImg;
   uint t, iCount;
@@ -974,33 +1023,54 @@ void DialogImages::rescueImageAttributes (  void *pVoidImg, CXmlSlideshow *pSlid
        pXmlImg->fEndTime   =  p->fEndTime;
        pXmlImg->width      =  p->width;
        pXmlImg->height     =  p->height;
-//       pXmlImg->rotate     =  p->rotate;
+//     pXmlImg->rotate     =  p->rotate;
        pXmlImg->effect[0]  =  p->effect[0];
        pXmlImg->effect[1]  =  p->effect[1];
-      return;
+       return true;
     }
   }
+  return false;
 }
 
 void DialogImages::accept ( )
 {
   // Here we build the SourceFileEntries from the information in m_pToolbox
   int t;
-  Utils theUtils;
   GroupView       *pGroupView = NULL;
   GroupView::Item *pGroupItem = NULL;
   CXmlSlideshow   *pSlideshow = NULL;
-  CXmlSlideshow    tempSlideshow;
-  CXmlSlideshow::img_struct *pXmlImg = NULL;
-  CXmlSlideshow::vid_struct *pXmlVid = NULL;
 
   if ( ! m_bCanClose ) {
-    if ( QMessageBox::warning ( this, tr ( "Can't close." ), tr ( "Can not close dialog while waiting for MediaScanner to finish.\nDo you want to force Quit ?" ), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
+    if ( MessageBox::warning ( this, tr ( "Can't close." ), tr ( "Can not close dialog while waiting for MediaScanner to finish.\nDo you want to force Quit ?" ), QMessageBox::Yes, QMessageBox::No ) == QMessageBox::No )
       return;
   }
 
   clearSlideshows ( );
 
+  // Check if the default group has not been filled with anything but the Preview holds images, 
+  // then we should move them into the group. The user probably assumed that the Preview is a Slideshow group.
+  if ( m_pToolbox->count ( ) == 1 )  {
+    pGroupView = (GroupView *)m_pToolbox->item ( 0 );
+    if ( pGroupView && pGroupView->childCount ( ) == 0 )  {
+      int iRes = MessageBox::question ( this, tr ( "No Files in Group." ), 
+            tr ( "There were no files added to the group \"%1\".\nDo you want to add all files in the preview to this group ?" ).arg ( m_pToolbox->itemLabel ( 0 ) ),
+            QMessageBox::Yes, QMessageBox::No, QMessageBox::Cancel );
+      if ( iRes == QMessageBox::Yes )  {
+        QFileInfo fileInfo;
+        Thumbs *pThumbs;
+        QValueList<Thumbs *>::iterator it = m_listOfThumbs.begin ( );
+        while ( it != m_listOfThumbs.end ( ) ) {
+          pThumbs = *it++;
+          fileInfo.setFile ( pThumbs->pCache->qsFileName );
+          GroupView::Item *pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), true );
+          pItem->pCache  =  pThumbs->pCache;
+        }
+      }
+      else if ( iRes == QMessageBox::Cancel )
+        return;
+    }
+  }
+
   for ( t=0; t<m_pToolbox->count ( ); t++ ) {
     pSlideshow = NULL;
     pGroupView = (GroupView *)m_pToolbox->item ( t );
@@ -1016,54 +1086,82 @@ void DialogImages::accept ( )
         // We need to take the slideshow object away from the GroupView object
         pGroupView->setSlideshow ( NULL );
       }
-//      else if ( pSlideshow )  {
-//        // delete pSlideshow; deleted in ~GroupView() 
-//        pSlideshow = NULL;
-//      }
       // We need to clear the objects and re-add them based on what is in the GroupView.
       // For this we create a temp copy to preserve the other image attributes
       if ( pSlideshow )  {
-        Cache::Thumbs::Entry      *pVidCache;
-        Cache::Thumbs::ImageEntry *pImgCache;
-        tempSlideshow = *pSlideshow;
-        pSlideshow->clearObjects ( );
-        pSlideshow->audio_list       = tempSlideshow.audio_list;
-        pSlideshow->validFilterNames = tempSlideshow.validFilterNames;
-        while ( pGroupItem &&   pGroupItem->pCache )  {
-          if  ( isImageDialog ( pGroupItem->pCache->qsFileName ) )  {
-            pXmlImg       = pSlideshow->addImg ( );
-            pXmlImg->src  = pGroupItem->pCache->qsFileName;
-            pXmlImg->text = pGroupItem->text ( 0 );
-            rescueImageAttributes ( pXmlImg, &tempSlideshow );
-            pImgCache = (Cache::Thumbs::ImageEntry *)Global::pThumbsCache->find ( pXmlImg->src, true );
-            if ( pImgCache && pImgCache->getMatrix ( ) )  {
-              pXmlImg->rotate  = pImgCache->fRotate;
-              pXmlImg->pMatrix = new QWMatrix ( *pImgCache->getMatrix ( ) );
-            }
-          }
-          else  {
-            pXmlVid       = pSlideshow->addVid ( );
-            pXmlVid->src  = pGroupItem->pCache->qsFileName;
-            pXmlVid->text = pGroupItem->text ( 0 );
-            pVidCache     = Global::pThumbsCache->find ( pXmlVid->src, false );
-            if ( pVidCache )  {
-                 pXmlVid->length = theUtils.getMsFromString ( pVidCache->qsLength );
-                 pXmlVid->fDuration = (float)pXmlVid->length / 1000.0f;
-            }
-            rescueImageAttributes ( pXmlVid, &tempSlideshow );
-          }
-          // pXmlImg has the following vars ...
-          // float fDuration; float fStartTime; float fEndTime; QString text;
-          // int width; int height; float rotate; effect_struct effect[2]; // start / end
-
-          pGroupItem = (GroupView::Item *)pGroupItem->nextSibling ( );
-        }
+        populateFromGroup ( pSlideshow, pGroupView );
         m_listOfSlideshows.append ( pSlideshow );
       }
     }
   }
 
+  Global::pThumbsCache->saveImageDB ( );
+  Global::pThumbsCache->saveCacheDB ( );
   QDialog::accept ( );
 }
 
+void DialogImages::populateFromGroup ( CXmlSlideshow *pSlideshow, GroupView *pGroupView )
+{
+  if ( ! pSlideshow || ! pGroupView )
+    return;
+
+  Utils theUtils;
+  Cache::Thumbs::Entry      *pVidCache = NULL;
+  Cache::Thumbs::ImageEntry *pImgCache = NULL;
+  CXmlSlideshow::img_struct *pXmlImg   = NULL;
+  CXmlSlideshow::vid_struct *pXmlVid   = NULL;
+  CXmlSlideshow tempSlideshow;
+  bool bRescued = false;
+
+  GroupView::Item *pGroupItem  = (GroupView::Item *)pGroupView->firstChild ( );
+  tempSlideshow = *pSlideshow;
+  pSlideshow->clearObjects ( );
+  pSlideshow->audio_list       = tempSlideshow.audio_list;
+  pSlideshow->validFilterNames = tempSlideshow.validFilterNames;
+  while ( pGroupItem &&   pGroupItem->pCache )  {
+    if  ( isImageDialog ( pGroupItem->pCache->qsFileName ) )  {
+      pXmlImg       = pSlideshow->addImg ( );
+      pXmlImg->src  = pGroupItem->pCache->qsFileName;
+      pXmlImg->text = pGroupItem->text ( 0 );
+      bRescued  = rescueImageAttributes ( pXmlImg, &tempSlideshow );
+      pImgCache = (Cache::Thumbs::ImageEntry *)Global::pThumbsCache->find ( pXmlImg->src, true );
+      if ( pImgCache )  {
+        if ( pImgCache->getMatrix ( ) )  {
+          pXmlImg->rotate  = pImgCache->fRotate;
+          pXmlImg->pMatrix = new QWMatrix ( *pImgCache->getMatrix ( ) );
+        }
+        else if ( ( pImgCache->fRotate != 0.0 ) && ( pImgCache->bIsVideo ) )  {
+          QWMatrix matrix;
+          matrix.rotate    ( pImgCache->fRotate );
+          pXmlImg->rotate  = pImgCache->fRotate;
+          pXmlImg->pMatrix = new QWMatrix ( matrix );
+        }
+        theUtils.getWidthHeight ( pImgCache->qsDimension, pXmlImg->width, pXmlImg->height );
+      }
+      if ( ! bRescued && pSlideshow->kenBurns ( ) )  {
+        // Did not find the image in the original Slideshow So we can add KenBurns effects
+        pXmlImg->effect[0].randomKenBurns ( 0.5, pXmlImg->width, pXmlImg->height, false );
+      }
+    }
+    else  {
+      pXmlVid         = pSlideshow->addVid ( );
+      pXmlVid->src    = pGroupItem->pCache->qsFileName;
+      pXmlVid->rotate = pGroupItem->pCache->fRotate;
+      pXmlVid->text   = pGroupItem->text ( 0 );
+      pVidCache       = Global::pThumbsCache->find ( pXmlVid->src, false );
+      if ( pVidCache )  {
+           pXmlVid->length = theUtils.getMsFromString ( pVidCache->qsLength );
+           pXmlVid->fDuration = (float)pXmlVid->length / 1000.0f;
+      }
+      rescueImageAttributes ( pXmlVid, &tempSlideshow );
+    }
+    // pXmlImg has the following vars ...
+    // float fDuration; float fStartTime; float fEndTime; QString text;
+    // int width; int height; float rotate; effect_struct effect[2]; // start / end
+
+    pGroupItem = (GroupView::Item *)pGroupItem->nextSibling ( );
+  }
+}
+
 }; // end namespace Input
+
