@@ -69,7 +69,7 @@ public:
   virtual ~DialogImages ( );
 
   QValueList<CXmlSlideshow *> &getSlideshows ( );
-  void initMe ( );
+  void initMe ( SourceFileEntry *p=NULL );
 
 protected slots:
   virtual void slotEditGroup      ( );
@@ -85,14 +85,13 @@ protected slots:
   virtual void slotRotate270  ( );
   virtual void slotRotateFree ( );
 
-
 protected:
   void rotate  (  double );
   void clearSlideshows ( );
   void clearWorker     ( );
 
-//  void rescueImageAttributes ( CXmlSlideshow::img_struct *, CXmlSlideshow * );
-  void rescueImageAttributes (  void *, CXmlSlideshow * );
+  bool rescueImageAttributes ( void *, CXmlSlideshow * );
+  void populateFromGroup     ( CXmlSlideshow *, GroupView * );
 
   ImageScan *takeNextScanObject   ( ImageScan *p=NULL );
   virtual QString getDirFilter    ( );
@@ -102,6 +101,7 @@ protected:
   virtual void showBasicMenu      ( const QPoint &  );
   virtual void showContextMenu    ( const QPoint &, QIconViewItem * );
   virtual void playFromGroup      ( Cache::Thumbs::Entry * );
+  virtual void initGroups         ( );
   virtual GroupView *addGroup     ( SourceFileEntry * );
   virtual void timerEvent         ( QTimerEvent * );
   virtual void accept             ( );
