@@ -602,6 +602,7 @@ void DialogMovie::slotInitMediaInterface ( )
 {
   m_pMediaInterface->openMRL ( m_qsFileName );
   m_pMediaInterface->getScreenshot ( );
+  m_pMediaInterface->setScreenshot ( 1.0f );
 
   QFileInfo fileInfo ( m_qsFileName );
   MediaInfo *pMediaInfo = NULL;  
@@ -851,7 +852,7 @@ void DialogMovie::slotAddAudio ( )
   // made in DialogAudio.
 
   /*
-  { // VAROL
+  { // DEBUG output.
     SourceFileEntry *p = m_pParentSourceFileEntry;
     printf ( "%s::%s : %d > iSelected<%d> ORIG > ", __FILE__, __FUNCTION__, __LINE__, iSelectedValue );
     for ( int e=0;e<MAX_AUDIO;e++ )
