@@ -8,6 +8,8 @@
 **
 *****************************************************************************/
 
+#include <unistd.h>
+
 #include <qlabel.h>
 #include <qimage.h>
 #include <qtimer.h>
@@ -33,6 +35,7 @@
 #include "messagebox.h"
 #include "xml_slideshow.h"
 #include "render_client.h"
+#include "dialogkenburns.h"
 #include "dialogslideshow.h"
 #include "dialogalphatrans.h"
 #include "filepreviewdialog.h"
@@ -64,7 +67,9 @@ DialogSlideshow::DialogSlideshow ( QWidget *pParent )
   connect ( m_pButtonAll,       SIGNAL ( clicked ( ) ), this, SLOT ( slotAll         ( ) ) );
   connect ( m_pButtonClear,     SIGNAL ( clicked ( ) ), this, SLOT ( slotClear       ( ) ) );
   connect ( m_pButtonAnim,      SIGNAL ( clicked ( ) ), this, SLOT ( slotAnim        ( ) ) );
+  connect ( m_pButtonKBParams,  SIGNAL ( clicked ( ) ), this, SLOT ( slotKBParams    ( ) ) );
   connect ( m_pCheckIntroPage,  SIGNAL ( toggled     ( bool ) ), this, SLOT ( slotIntroPage   ( bool ) ) );
+  connect ( m_pCheckKenBurns,   SIGNAL ( toggled     ( bool ) ), this, SLOT ( slotKenBurns    ( bool ) ) );
   connect ( m_pSpinImageDelay,  SIGNAL ( valueChanged ( int ) ), this, SLOT ( slotValueChanged ( int ) ) );
   connect ( m_pSpinFilterDelay, SIGNAL ( valueChanged ( int ) ), this, SLOT ( slotValueChanged ( int ) ) );
   connect ( m_pListViewTransitions,  SIGNAL  ( selectionChanged ( QListViewItem * ) ), this, SLOT ( slotSelectionChanged ( QListViewItem * ) ) );
@@ -149,7 +154,9 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
   m_pSpinFilterDelay->setValue  ( (int)pSlideshow->filter_delay );
   m_pEditName->setText          ( pSlideshow->slideshow_name    );
   m_pEditName->setEnabled       ( bEnableName                   );
-
+  m_pCheckKenBurns->setChecked  ( pSlideshow->bKenBurns         );
+  m_pButtonKBParams->setEnabled ( pSlideshow->bKenBurns         );
+ 
   int iFormat = 0;
   if ( theUtils.getFormat ( pSlideshow->xres, pSlideshow->yres ) > FORMAT_NTSC4 )  // set to PAL
     iFormat = ( pSlideshow->aspect == 0 ) ? 1 : 3;
@@ -197,11 +204,14 @@ void DialogSlideshow::initMe ( CXmlSlideshow *pSlideshow, bool bEnableName )
     m_pLabelBackground->setPaletteBackgroundColor ( theColor );
   }
 
-  initTransitions   ( );
-  QTimer::singleShot ( 10,   this, SLOT ( createVidsLength  ( ) ) );
-  QTimer::singleShot ( 1000, this, SLOT ( createAudioLength ( ) ) );
-//  createVidsLength  ( );
-//  createAudioLength ( );
+  QString qsTitle = "Slideshow [";
+  qsTitle += m_pSlideshow->slideshow_name + "] <";
+  qsTitle += QString ( "%1 Imgs+ %2 Vids>" ).arg ( m_pSlideshow->countImg ( ) ).arg ( m_pSlideshow->countVid ( ) );
+
+  setCaption ( qsTitle );
+
+  // init Transitions will also call createVidsLength, and createAudioLength
+  initTransitions ( );
 }
 
 void DialogSlideshow::initTransitions ( )
@@ -239,7 +249,8 @@ void DialogSlideshow::initTransitions ( )
 
     qsTransitionPath = Global::qsSystemPath + QString ( "/share/qdvdauthor/" );
     qsText += tr ( "cd /tmp; wget http://qdvdauthor.sourceforge.net/data/alpha_trans.tar.bz2\n" );
-    qsText += tr ( "cd %1; sudo tar -xjf /tmp/alpha_trans.tar.bz2\n" ).arg ( qsTransitionPath );
+    qsText += tr ( "cd %1; sudo tar -xjf /tmp/alpha_trans.tar.bz2\n\n" ).arg ( qsTransitionPath );
+    qsText += tr ( "The filter will be available after restarting QDVDAuthor.\n" );
 
     QSize theSize    ( 600, 300 );
     MessageBox::html ( this, tr ( "Warning" ), qsText, theSize );
@@ -272,17 +283,23 @@ void DialogSlideshow::initTransitions ( )
   m_pRadioImgImg   ->setChecked ( !bChecked );
   m_pRadioImgBkgImg->setChecked (  bChecked );
 
+//  bChecked = m_pSlideshow->kenBurns ( );
+//  m_pCheckKenBurns->setChecked  (  bChecked );
+
   QTimer::singleShot ( 1000, this, SLOT ( slotCreateListViewPix ( ) ) );
 }
 
 void DialogSlideshow::slotCreateListViewPix ( )
 {
   QCheckListItem *pItem = (QCheckListItem *)m_pListViewTransitions->firstChild ( );
+
   while ( pItem )  {
     pItem->setPixmap    ( 0, getListViewPix ( pItem->text ( ) ) );
     qApp->processEvents ( 500 );
     pItem = (QCheckListItem *)pItem->nextSibling ( );
   }
+  // After we initialized the pixies, we need to ge vids, and audio lengths
+  QTimer::singleShot ( 10,   this, SLOT ( createVidsLength  ( ) ) );
 }
 
 QPixmap DialogSlideshow::getListViewPix ( QString qsFilterName )
@@ -342,6 +359,8 @@ void DialogSlideshow::createVidsLength ( )
       pVid->length = pMediaInfo->getLength ( );
     }
   }
+  // Lastly we create the audio length
+  QTimer::singleShot ( 10, this, SLOT ( createAudioLength ( ) ) );
 }
 
 void DialogSlideshow::createAudioLength ( )
@@ -372,8 +391,8 @@ void DialogSlideshow::createAudioLength ( )
         m_pSlideshow->total_audio_length += (uint)( pMediaInfo->getLength ( ) / 1000.0 );
       }
     }
+    m_pButtonKBParams->setEnabled ( m_pSlideshow->bKenBurns );
   }
-
   displayLength ( );
   bBusy = false;
 }
@@ -389,6 +408,70 @@ void DialogSlideshow::displayLength ( )
   m_pGroupAudio->setTitle   ( QString ( "Audio files ( " ) + qsLength + QString ( " )" )  );
 }
 
+void DialogSlideshow::slotKBParams ( )
+{
+  DialogKenBurns dialog;
+  dialog.setSlideshow ( m_pSlideshow );
+  if ( dialog.exec ( ) == QDialog::Accepted )   {
+    if ( m_pSlideshow  && dialog.getSlideshow ( ) )
+        *m_pSlideshow  = *dialog.getSlideshow ( );
+         QString qsTitle = "Slideshow [";
+         qsTitle += m_pSlideshow->slideshow_name + "] <";
+         qsTitle += QString ( "%1 Imgs+ %2 Vids>" ).arg ( m_pSlideshow->countImg ( ) ).arg ( m_pSlideshow->countVid ( ) );
+         setCaption ( qsTitle );
+  }
+}
+
+void DialogSlideshow::slotKenBurns ( bool bChecked )
+{
+  if ( m_pSlideshow ) {
+    // At this point we need the width / height information of the images,
+    // which has not yet been generated.
+    if ( bChecked && ! m_pSlideshow->bKenBurns )  {
+      uint iImgCount = m_pSlideshow->countImg( );
+      uint t;
+      Utils theUtils;
+      QCursor myCursor ( QCursor::WaitCursor );
+      QApplication::setOverrideCursor ( myCursor );
+      Cache::Thumbs::ImageEntry *pCache = NULL;
+      for ( t=0; t<iImgCount; t++ )  {
+        CXmlSlideshow::img_struct *pImg = m_pSlideshow->getImg ( t );
+        if ( ! pImg )
+          continue;
+        if ( ( pImg->width == 0 ) || ( pImg->height == 0 ) ) {
+          pCache = (Cache::Thumbs::ImageEntry *)Global::pThumbsCache->find ( pImg->src, true );
+          if ( pCache )  {
+            if ( theUtils.getWidthHeight ( pCache->qsDimension, pImg->width, pImg->height ) )  {
+              // Trying to figure out when we rotated the image by 90deg.
+              if ( ( ( pCache->iOrientation != 6 && pCache->iOrientation != 8 ) && ( pCache->fRotate == 90.0 || pCache->fRotate == 270.0 ) ) || 
+                   ( ( pCache->iOrientation == 6 || pCache->iOrientation == 8 ) && ( pCache->fRotate ==  0.0 || pCache->fRotate == 360.0 ) ) ) {
+                int w = pImg->width;
+                pImg->width  = pImg->height;
+                pImg->height = w;
+              }
+            }
+          }
+          else  {
+            QImage img ( pImg->src );
+            pImg->width  = img.width  ( );
+            pImg->height = img.height ( );
+            if ( pImg->pMatrix )  {
+              img = img.xForm ( *pImg->pMatrix );
+              pImg->width  = img.width  ( );
+              pImg->height = img.height ( );
+            }
+          }
+        }
+        if ( t%10 == 9 )
+          qApp->processEvents ( );
+      }
+    }
+    m_pSlideshow->setKenBurns     ( bChecked );
+    m_pButtonKBParams->setEnabled ( bChecked );
+    QApplication::restoreOverrideCursor ();
+  }
+}
+
 void DialogSlideshow::slotIntroPage ( bool )
 {
   slotValueChanged ( 0 );
@@ -507,10 +590,8 @@ void DialogSlideshow::recreatePix ( )
     QImage background ( start.copy ( ) ); // init the size
     if ( bImgBkgImg ) {
       QFileInfo fileInfo    ( m_qsBackground );
-      if ( fileInfo.exists  ( ) )  {
+      if ( fileInfo.exists  ( ) )
         background = QImage ( m_qsBackground );
-        background = background.smoothScale ( m_pLabelPreview->size ( ) );
-      }
       else  {
         QColor theColor;
         theColor.setNamedColor ( m_qsBackground );
@@ -518,10 +599,12 @@ void DialogSlideshow::recreatePix ( )
       }
       iDiff = 15;
     }
+    background = background.smoothScale ( m_pLabelPreview->size ( ) );
 
     filter = filter.smoothScale ( m_pLabelPreview->size ( ) );
     start  = start.smoothScale  ( m_pLabelPreview->size ( ) );
     stop   = stop.smoothScale   ( m_pLabelPreview->size ( ) );
+    result = result.smoothScale ( m_pLabelPreview->size ( ) );
     fDelta = 512.0f / ( THUMBNAIL_COUNT - iDiff - 1 );
 
     for ( t=0; t<THUMBNAIL_COUNT; t++ )  {
@@ -532,7 +615,6 @@ void DialogSlideshow::recreatePix ( )
 
       array[t]->convertFromImage ( result );
     }
-
     for ( t=0; t<THUMBNAIL_COUNT; t++ )  {
       if ( m_arrayPix[t] )
         delete m_arrayPix[t];
