@@ -45,18 +45,20 @@ protected slots:
   virtual void slotClear       ( );
   virtual void slotColor       ( );
   virtual void slotSelect      ( );
+  virtual void slotKBParams    ( );
   virtual void slotAddAudio    ( );
   virtual void slotAnimatePix  ( );
   virtual void slotDeleteAudio ( );
   virtual void slotValueChanged(  int );
+  virtual void slotKenBurns    ( bool );
   virtual void slotIntroPage   ( bool );
   virtual void slotSelectionChanged  ( QListViewItem * );
   virtual void slotCreateListViewPix ( );
+  virtual void initTransitions   ( );
   virtual void createVidsLength  ( );
   virtual void createAudioLength ( );
 
 private:
-  void initTransitions   ( );
   void createTransitions ( );
   void displayLength     ( );
   void recreatePix       ( );
