@@ -28,6 +28,9 @@
 #include "dialogtextfont.h"
 #include "dialoganimation.h"
 
+#include "textobject.h"
+#include "buttonpreview.h"
+
 // Here we initialize the static member variables ...
 QFont   DialogTextFont::m_previousFont       = QFont   ( );
 QString DialogTextFont::m_previousText       = QString ( );
@@ -35,12 +38,40 @@ QPoint  DialogTextFont::m_previousTextAlign  = QPoint  ( Qt::AlignHCenter, Qt::A
 Rgba    DialogTextFont::m_previousBackground = Rgba    ( TRANSPARENT_COLOR, 0xff );
 Rgba    DialogTextFont::m_previousForeground = Rgba    ( 20, 20, 255, 255 );
 
-DialogTextFont::DialogTextFont ( QWidget *pParent, const char *pName, WFlags f)
-	: uiDialogTextFont ( pParent, pName, f )
+DialogTextFont::DialogTextFont ( QWidget *pParent, TextObject *pTextObject )
+  : uiDialogTextFont ( pParent )
 {
   initMe ( );
+
+  if ( pTextObject ) {
+    setTextAlign       ( pTextObject->getTextAlign       ( ) );
+    setBackgroundColor ( pTextObject->getBackgroundColor ( ) );
+    setForegroundColor ( pTextObject->getForegroundColor ( ) );
+    setFont            ( pTextObject->getFont   ( ) );
+    setText            ( pTextObject->getText   ( ) );
+    setTransparency    ( pTextObject->modifiers ( )->fTransparency );
+    setAnimation       ( pTextObject->animation ( ) );
+    setRect            ( pTextObject->rect      ( ) );
+
+    ButtonPreview *pPreview = (ButtonPreview *)pParent;
+    QPixmap thePix, pix;
+    pPreview->drawBackground   (     thePix, pTextObject );
+    pix.resize ( thePix.width  ( ) - pTextObject->rect ( ).left ( ), 
+		 thePix.height ( ) - pTextObject->rect ( ).top  ( ) );
+    copyBlt  ( &pix, 0, 0, &thePix,  pTextObject->rect ( ).left ( ),  pTextObject->rect ( ).top ( ) );
+
+    m_pTextEdit->setPaletteBackgroundPixmap ( pix ); //thePix );
+    //m_pTextEdit->setResizePolicy ( QScrollView::Manual );
+    //m_pTextEdit->resizeContents  ( thePix.width ( ), thePix.height ( ) );
+    //m_pTextEdit->scrollBy ( -pTextObject->rect   ( ).left ( ), -pTextObject->rect ( ).top ( ) );
+  }
+
   if ( pParent )
     connect ( this, SIGNAL ( signalAnimate ( QString &, int, QString ) ), pParent, SLOT ( slotAnimateObject ( QString &, int, QString ) ) );
+
+  //const QPixmap *pPix = pParent->paletteBackgroundPixmap ( );
+  //if ( pPix )
+  //     pPix->save ( "/tmp/pix.png", "PNG", 100 );
 }
 
 DialogTextFont::~DialogTextFont ( )
