@@ -5,16 +5,22 @@
 // This class is only a container class to encapsulate the 
 // variables needed for Drag'n drop support
 //
+//   Created : 
+//        by : Varol Okan
+// Copyright : (c) Varol Okan
+//   License : GPL v 2.0
+//
 ////////////////////////////////////////////////////////////////
 
 #ifndef DRAGNDROPCONTAINER_H
 #define DRAGNDROPCONTAINER_H
 
 #include <qdatetime.h>
-#include <qcolor.h>
 #include <qsize.h>
 #include <qfont.h>
 
+#include "rgba.h"
+
 class DragNDropContainer
 {
 public:
@@ -35,7 +41,7 @@ public:
 	QTime  timeStartOffset;
 	QTime  timeDuration;
 	QFont  font;
-	QColor colorForeground;
+	Rgba   colorForeground;
 };
 
 #endif// DRAGNDROPCONTAINER_H
