@@ -443,7 +443,7 @@ void Area::Container::drawConnection ( QPainter &thePainter, Container::Connecti
 {
   // Target / Source from the point of view of the Connection, not the Container
   Container *pSource, *pTarget;
-  QValueList<Container::Connection *>::iterator it = m_listSources.begin ( );
+//  QValueList<Container::Connection *>::iterator it = m_listSources.begin ( );
   Area *pArea = (Area *)object ( )->parent ( );
 
   SimplePainter *pPainter = pArea->getPainter ( );
@@ -1024,7 +1024,7 @@ void Area::createConnections ( Container *pContainer )
   Container::Connection* pConnection = NULL;
   QValueList<Container *> listContainer;
   QValueList<Container *>::iterator it2;
-  QValueList<Container *>::iterator itCon = m_listOfContainer.begin ( );
+//  QValueList<Container *>::iterator itCon = m_listOfContainer.begin ( );
 
   listContainer = pContainer->container ( );
   int iPosX     = pContainer->object    ( )->pos ( ).x ( );
@@ -1161,7 +1161,7 @@ void Area::findMenuTargets ( Container *pContainer )
   Container    *pCurrentTarget = NULL;
   DVDMenu      *pOtherMenu     = NULL;
   ButtonObject *pButton        = NULL;
-  int         iSelfCounter;
+//  int         iSelfCounter;
   QString     strMultiple;
   QStringList listMultiple;
   QStringList::iterator itMultiple;
@@ -1172,7 +1172,7 @@ void Area::findMenuTargets ( Container *pContainer )
     listMultiple   = pButton->getPlayMultipleList ( );
     itMultiple     = listMultiple.begin ( );
     pCurrentTarget = NULL;
-    iSelfCounter   = 0;
+//    iSelfCounter   = 0;
     while ( itMultiple != listMultiple.end ( ) )  {
       strMultiple  = *itMultiple++;
       pTarget = findContainerFromAction ( strMultiple );
