@@ -18,6 +18,7 @@
 #include <qcombobox.h>
 #include <qfileinfo.h>
 #include <qlineedit.h>
+#include <qpopupmenu.h>
 #include <qpushbutton.h>
 
 #include "global.h"
@@ -222,8 +223,8 @@ Object::enType Object::type ( )
 void Object::resizeHeader ( )
 {
   float fButtonSize = BUTTON_SIZE * m_fZoom;
-  m_pHeader->setMaximumSize  ( QSize ( 32767, fButtonSize ) );
-  m_pButtonInfo->setFixedSize( QSize ( fButtonSize, fButtonSize ) );
+  m_pHeader->setMaximumSize  ( QSize ( 32767, (int)fButtonSize ) );
+  m_pButtonInfo->setFixedSize( QSize ( (int)fButtonSize, (int)fButtonSize ) );
   if ( m_fZoom < 0.5f )    {
     m_pHeader->displayText ( false );
     m_pButtonInfo->setText ( trUtf8 ( "" ) );
@@ -248,12 +249,58 @@ void Object::setThumbnail ( )
   m_pInsideWidget->setPixmap (   thePix );
 }
 
+void Object::keyPressEvent ( QKeyEvent *pKey )
+{
+  if ( pKey->key ( ) == Qt::Key_Left )  {
+    move ( pos ( ).x ( ) - 1, pos ( ).y ( ) );
+    slotRedrawAll   ( );
+  }
+  if ( pKey->key ( ) == Qt::Key_Right )  {
+    move ( pos ( ).x ( ) + 1, pos ( ).y ( ) );
+    slotRedrawAll   ( );
+  }
+  if ( pKey->key ( ) == Qt::Key_Up )  {
+    move ( pos ( ).x ( ), pos ( ).y ( ) - 1 );
+    slotRedrawAll   ( );
+  }
+  if ( pKey->key ( ) == Qt::Key_Down )  {
+    move ( pos ( ).x ( ), pos ( ).y ( ) + 1 );
+    slotRedrawAll   ( );
+  }
+}
+
+void Object::enterEvent ( QEvent * )
+{
+  grabKeyboard ( );
+}
+
+void Object::leaveEvent ( QEvent * )
+{
+  releaseKeyboard ( );
+}
+
 void Object::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-  m_bMousePressed = true;
-  m_pointInitial  = pMouseEvent->pos ( );
-  raise ( );
-  setActiveObject ( this );
+  if ( pMouseEvent->button ( ) == LeftButton )  {
+    m_bMousePressed = true;
+    m_pointInitial  = pMouseEvent->pos ( );
+    raise ( );
+    setActiveObject ( this );
+  }
+  else  { // Right click, Sow context menu
+    if ( type ( ) == TYPE_MOVIE )  {
+      SourceFileEntry *pEntry = (SourceFileEntry *)getObject ( );
+      QPoint  pos    = pMouseEvent->globalPos (     );
+      Global::pApp->createContextMenu ( pEntry, pos );
+    }
+    else if ( type ( ) == TYPE_MENU )  {
+      QPoint      pos   = pMouseEvent->globalPos ( );
+      DVDMenu    *pMenu = (DVDMenu *)getObject   ( );
+      QPopupMenu popuMenu ( NULL );
+      popuMenu.insertItem ( tr ( "Proprties ..." ), pMenu, SLOT ( slotEditTimeline ( ) ) );
+      popuMenu.exec ( pos, 2 );
+    }
+  }
 }
 
 void Object::mouseReleaseEvent( QMouseEvent * )
@@ -266,9 +313,8 @@ void Object::mouseReleaseEvent( QMouseEvent * )
 void Object::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 {
   if ( m_bMousePressed )  {
-    QWidget   *pParent = this; //parentWidget ( )->parentWidget ( );
-    QPoint parentPoint = pParent->mapToParent ( pMouseEvent->pos ( ) - m_pointInitial );
-    pParent->move ( parentPoint );
+    QPoint parentPoint = mapToParent ( pMouseEvent->pos ( ) - m_pointInitial );
+    move ( parentPoint );
     moveActiveObject ( );
   }
 }
@@ -339,14 +385,16 @@ void MovieObject::createThumb ( )
     return;
 
   QImage theImage;
-  Cache::Thumbs::Entry *pCache = Global::pThumbsCache->find ( pInfo->qsFileName );
-  if ( pCache && ! pCache->arrayOfThumbs )
-       pCache->loadImages  ( );
-
-  if ( pCache && pCache->arrayOfThumbs && pCache->arrayOfThumbs[0] )
-    theImage = *pCache->arrayOfThumbs[0];
-  else if ( pInfo->pPreview )
+  if ( pInfo->pPreview && ! pInfo->pPreview->isNull ( ) )
     theImage = *pInfo->pPreview;
+  else  {
+    Cache::Thumbs::Entry *pCache = Global::pThumbsCache->find ( pInfo->qsFileName );
+    if ( pCache && ! pCache->arrayOfThumbs )
+         pCache->loadImages  ( );
+
+    if ( pCache && pCache->arrayOfThumbs && pCache->arrayOfThumbs[0] )
+         theImage = *pCache->arrayOfThumbs[0];
+  }
 
   if ( theImage.isNull ( ) )
     return;
@@ -525,12 +573,16 @@ void Gui::slotPostRead ( )
 
 void Gui::slotRecreateThumb ( )
 {
-  if ( m_listRecreateThumbs.size ( ) > 0 )  {
-    Object *pObject = m_listRecreateThumbs[0];
+  QValueList<Object *>::iterator it = m_listRecreateThumbs.begin ( );
+  while ( it != m_listRecreateThumbs.end ( ) )  {
+    Object *pObject = *it++;
     m_listRecreateThumbs.remove ( pObject );
-    pObject->createThumb  ( );
-    pObject->setThumbnail ( );
-    QTimer::singleShot ( 100, this, SLOT ( slotRecreateThumb ( ) ) );
+    if ( m_listOfMenus.contains ( pObject ) > 0 )  {
+      pObject->createThumb  ( );
+      pObject->setThumbnail ( );
+      QTimer::singleShot ( 100, this, SLOT ( slotRecreateThumb ( ) ) );
+      return;
+    }
   }
 }
 
@@ -564,9 +616,10 @@ void Gui::refresh ( )
   SourceFileEntry *pEntry = NULL;
   uint t, iEntries = Global::pApp->sourceFileCount ( );
   for ( t=0; t<iEntries; t++ )  {
-    pEntry = Global::pApp->sourceFileEntry ( t );
-    if ( ! pEntry )
+    pEntry = Global::pApp->sourceFileEntry  ( t );
+    if ( ( ! pEntry ) || ( pEntry->bSoundSource ) )
       continue;
+
     pObject = checkEntry ( pEntry );
     if ( pObject )
       listTemp.remove ( pObject );
@@ -680,11 +733,25 @@ Object *Gui::findObject ( void *pRealObject )
   return NULL;
 }
 
-void Gui::createEntry ( SourceFileEntry *pEntry )
+void Gui::updateEntry ( SourceFileEntry *pEntry )
 {
   if ( ! pEntry )
     return;
 
+  Object *pObject = findObject ( pEntry );
+  if ( !  pObject )
+    return;
+
+  pObject->createThumb  ( );
+  pObject->setThumbnail ( );
+  pObject->setZoom ( m_pArea->getZoom ( ) + 0.00001 );
+}
+
+void Gui::createEntry ( SourceFileEntry *pEntry )
+{
+  if ( ( ! pEntry ) || ( pEntry->bSoundSource ) )
+    return;
+
   QPoint pos = initialPos ( false );
   MovieObject *pMovie = NULL;
   pMovie = new MovieObject ( m_pArea, pEntry );
@@ -707,7 +774,8 @@ void Gui::createMenu ( DVDMenu *pDVDMenu )
 
   MenuObject *pMenu = NULL;
   pMenu = new MenuObject ( m_pArea, pDVDMenu );
-  pMenu->move ( pos.x ( ), pos.y ( ) );
+  pMenu->move ( pos.x ( ),     pos.y ( ) );
+  pMenu->setFixedSize ( pMenu->size  ( ) );
   pMenu->show ( );
 
   // Finally we can add it to the propper lists
@@ -721,13 +789,14 @@ QPoint Gui::initialPos ( bool bMenu )
 {
   // We need to put some brains in here to offer a nice looking initial display.
   const int iMARGIN   = 20; // Objects distance from border and each other.
-  const int iMAX_COLS = 10; // Max objects in one row before we add a new row
+  const int iMAX_COLS =  5; // Max objects in one row before we add a new row
 
+//  slotAdjustZoom ( );
   float fZoom = m_pArea->getZoom ( );
   float fAdjustedWidth = Object::INITIAL_SIZE * fZoom;
   float fAdjustedPos   = iMARGIN * fZoom;
   float fAdjustedSize  = fAdjustedWidth + fAdjustedPos;
-  float fMaxWidth      = iMAX_COLS * fAdjustedWidth * fAdjustedPos;
+  float fMaxWidth      = iMAX_COLS * ( fAdjustedWidth + fAdjustedPos );
 
   QPoint newPos  ( (int)fAdjustedPos, (int)fAdjustedPos );
   QRect  objRect ( (int)fAdjustedPos, (int)fAdjustedPos, (int)fAdjustedWidth, (int)fAdjustedWidth );
@@ -735,7 +804,7 @@ QPoint Gui::initialPos ( bool bMenu )
   // Since there is no perfect logic for all cases lets follow this approach:         //
   // o Menus on the top and videos on the bottom.                                     //
   // o Add videos MARGIN below the lowest Menu.                                       //
-  // o Add a max of 10 objects in a row, and adjust scale to display all in one view  //
+  // o Add a max of  5 objects in a row, and adjust scale to display all in one view  //
   // o If a New Menu will create a new row of menus ( E.g. Menu # 11 ),               //
   //   then shift all videos one row lower.                                           //
   // o When adding new Object, make sure we won't overlay existing Object             //
@@ -769,7 +838,7 @@ QPoint Gui::initialPos ( bool bMenu )
       if ( objRect.intersects ( rect ) )  {
         // First we make sure we don't exceed the max width
         if ( rect.left ( ) + fAdjustedSize > fMaxWidth )
-          objRect = QRect ( (int)fAdjustedPos, (int)( fAdjustedSize ) + objRect.height ( ), (int)fAdjustedWidth, (int)fAdjustedWidth );
+          objRect = QRect ( (int)fAdjustedPos, (int)( fAdjustedSize ) + objRect.top ( ), (int)fAdjustedWidth, (int)fAdjustedWidth );
         else
           objRect = QRect ( rect.right ( ) + (int)( fAdjustedPos ), objRect.top ( ), objRect.width ( ), objRect.height ( ) );
 
@@ -811,7 +880,7 @@ QPoint Gui::initialPos ( bool bMenu )
       if ( objRect.intersects ( rect ) )  {
         // First we make sure we don't exceed the max width
         if ( objRect.left ( ) + fAdjustedSize > fMaxWidth )
-          objRect = QRect ( (int)fAdjustedPos, (int)( fAdjustedSize ) + objRect.height ( ), (int)fAdjustedWidth, (int)fAdjustedWidth );
+          objRect = QRect ( (int)fAdjustedPos, (int)( fAdjustedSize ) + objRect.top ( ), (int)fAdjustedWidth, (int)fAdjustedWidth );
         else
           objRect = QRect ( objRect.left ( ) + (int)( fAdjustedSize ), objRect.top ( ), objRect.width ( ), objRect.height ( ) );
         it = m_listOfObjects.begin ( );
@@ -823,11 +892,6 @@ QPoint Gui::initialPos ( bool bMenu )
   return newPos;
 }
 
-void Gui::slotPan ( )
-{
-  MessageBox::information ( this, tr ( "Under construction" ), tr ( "Not yet implemented" ) );
-}
-
 void Gui::slotPrinter ( )
 {
   m_pArea->print ( );
@@ -855,8 +919,6 @@ void Gui::slotZoomChanged ( )
     fValue = 100.0;
   }
 
-printf ( "%s::%d > \n", __FILE__, __LINE__ );
-
   qsValue.sprintf ( "%0.2f%%", fValue );
   m_pEditZoom->setText ( qsValue );
   setZoom ( fValue / 100.0f );
@@ -918,8 +980,8 @@ void Gui::slotAdjustZoom ( )
          iMaxPosY = pObject->pos ( ).y ( ) + pObject->height ( ) ;
   }
   float fAreaZoom = m_pArea->getZoom ( );
-  iMaxPosX += 20 * fAreaZoom;
-  iMaxPosY += 20 * fAreaZoom;
+  iMaxPosX += (int)( 20.0 * fAreaZoom );
+  iMaxPosY += (int)( 20.0 * fAreaZoom );
 
   if ( ( iMaxPosX > m_pArea->width ( ) ) || ( iMaxPosY > m_pArea->height ( ) ) )  {
     // Okay here we need to adjust the Zoom factor
@@ -943,7 +1005,7 @@ void Gui::slotAdjustZoom ( )
 
     // Set the slider pos.
     if  ( fAreaZoom < 1.0f )
-      iZoom = (int)( ( fAreaZoom - 1.0f ) * 1000.0f ) / 0.9f; // range [ 0 .. -1000 ]
+      iZoom = (int)( ( ( fAreaZoom - 1.0f ) * 1000.0f ) / 0.9f ); // range [ 0 .. -1000 ]
     else
       iZoom = (int)( ( fAreaZoom - 1.0f ) * 1000.0f / 900.0f );
 
