@@ -168,7 +168,8 @@ QPoint OthogonalRouter::routeBottomBelowTarget ( QPoint startPos, QPoint endPos,
 {
   QPoint pos[2];
   int iDelta = pConnection->m_iConNr[1] * iDELTA + iSPACE;
-  int iCenterXPos, iObjectXPos  = startPos.x ( );
+//  int iCenterXPos;
+//  int iObjectXPos  = startPos.x ( );
   if ( ! pConnection )
     return endPos;
 
@@ -180,8 +181,8 @@ QPoint OthogonalRouter::routeBottomBelowTarget ( QPoint startPos, QPoint endPos,
   // Lets get the propper xPos of the Target Object.
   Object *pTargetObject = pConnection->target ( )->object ( );
   Object *pSourceObject = pConnection->source ( )->object ( );
-  iObjectXPos = pTargetObject->pos ( ).x ( );
-  iCenterXPos = iObjectXPos + (int)( (float)pTargetObject->width ( ) / 2.0 );
+//  iObjectXPos = pTargetObject->pos ( ).x ( );
+//  iCenterXPos = iObjectXPos + (int)( (float)pTargetObject->width ( ) / 2.0 );
   int iSourceRight = pSourceObject->pos ( ).x ( ) + pSourceObject->width ( );
 
   if ( endPos.x ( ) > pSourceObject->pos ( ).x ( ) + pSourceObject->width ( ) + iSPACE )  {
