@@ -391,7 +391,7 @@ bool DVDAuthor::createJumpTable ( )
       pTitleset       = NULL;
       // store the active button number
       qsCurrentButton = QString ( "g4=%1; "  ).arg ( ( t + 1 ) * 1024 );
-      qsAction        = QString ( " { %1%1 " ).arg ( qsCurrentButton ).arg ( getPreAction ( pButton ) );
+      qsAction        = QString ( " { %1%2 " ).arg ( qsCurrentButton ).arg ( getPreAction ( pButton ) );
       // replace the button name in qsAction with the associated number.
       getButtonNumberFromName ( listButtons, qsAction ); 
 
@@ -795,7 +795,7 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
   pPgc->post.value    = QString (" { g4=button; g2=0; " );
   if ( pInterface->qsPost.isEmpty ( ) )
     pPgc->post.value += QString ( "jump vmgm menu 1;" );
-  else if ( pInterface->qsPost = "Loop" ) // This is for the VMGMenu only ...
+  else if ( pInterface->qsPost == "Loop" ) // This is for the VMGMenu only ...
     pPgc->post.value += QString ( "jump vmgm menu 1;" );
   else
     pPgc->post.value += pInterface->qsPost;
@@ -850,6 +850,8 @@ bool DVDAuthor::createDVDAuthorXml ( QString &qsFileName )
     // Found out the hard way that a Titleset also ought to possess at least one menu - pgc - entry.
     if ( ! pXMLTitleset->ppArrayMenus )   {
       pXMLMenu = pXMLTitleset->addMenus ( );
+      QString qsRatio ( "4:3" );
+      addToVideo ( &pXMLMenu->video, 720, 480, qsRatio );
       pXMLMenu->addPgc ( );
     }
   }
@@ -996,7 +998,8 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titles_struct *pTitle, SourceFile
   uint i;
   for (i=0;i<pEntry->listFileInfos.count();i++) {
     pPgc = pTitle->addPgc ( );
-    addToTitleset ( pPgc, pEntry->listFileInfos[i] );
+    if ( addToTitleset ( pPgc, pEntry->listFileInfos[i] ) )
+         pPgc->post.value += "\n\t" + jumpToSubMenu ( pEntry );
 
     // just in case to ensure something is happening afterwards.
     if ( pPgc->post.value.isEmpty ( ) )
@@ -1049,6 +1052,7 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileEntry
 
 bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileInfo *pInfo )
 {
+  bool bReturn = false;
   // This function assigns the Video files to the <titles> part of the TitleSet
   CXmlDVDAuthor::vob_struct *pVob = NULL;
   pPgc->pre.value  = pInfo->qsPreCommand;
@@ -1056,6 +1060,10 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileInfo
   pPgc->post.value = "";
   if ( pMultiple )
     pPgc->post.value = pMultiple->getPostCommand ( );
+  // signal the calling function that we still need the
+  // standard post commands behind the PlayMultiple commands.
+  if ( ! pPgc->post.value.isEmpty ( ) )
+    bReturn = true;
 
   pPgc->post.value  += pInfo->qsPostCommand;
 
@@ -1079,7 +1087,7 @@ bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::pgc_struct *pPgc, SourceFileInfo
   else
     pVob->pause  = QString ( "%1" ).arg ( pInfo->iPause );
 
-  return true;
+  return bReturn;
 }
 
 bool DVDAuthor::addToTitleset ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, ButtonTransition *pTransition )
@@ -1144,7 +1152,7 @@ QString DVDAuthor::jumpToSubMenu ( SourceFileEntry *pEntry )
 {
   // This function will generate the jump command to the DVDMenu 
   // which is associated to the SourceFileEntry.
-  int             iMenu;
+//  int             iMenu;
   DVDMenu        *pDVDMenu;
   JumpTable      *pJumpTableEntry;
   ExportTitleset *pMenuTitleset, *pEntryTitleset;
@@ -1163,7 +1171,7 @@ QString DVDAuthor::jumpToSubMenu ( SourceFileEntry *pEntry )
   if ( ! pJumpTableEntry )
     return qsJump;
 
-  iMenu  = pMenuTitleset->findMenu ( pDVDMenu );
+//  iMenu  = pMenuTitleset->findMenu ( pDVDMenu );
   if ( pMenuTitleset == pEntryTitleset ) {
     if ( pJumpTableEntry->iMenu == 0 )
       qsJump = QString (" { g3=0; call menu entry root; } ");
@@ -1194,16 +1202,44 @@ bool DVDAuthor::addToMenu ( CXmlDVDAuthor::titleset_struct *pXMLTitleset, Export
     if ( ! pXMLTitleset->ppArrayMenus )
            pXMLTitleset->addMenus   ( );
     pXMLMenu = pXMLTitleset->ppArrayMenus[0];
-
     return addToMenu ( pXMLMenu, pExpTitleset );
   }
   return true;
 }
 
+QString DVDAuthor::getFromFormat ( QString &qsFormat, int iWhich )
+{
+  // Input is expected to be "720x480x16:9x29.97"
+  QStringList list = QStringList::split ( qsFormat, "x" );
+  QString qsReturn = "720";
+  switch ( iWhich )  {
+  case 0: qsReturn = "720";   break;
+  case 1: qsReturn = "480";   break;
+  case 2: qsReturn = "16:9";  break;
+  case 3: qsReturn = "29.97"; break;
+  };
+  if ( list.size ( ) >= 4 )  {
+    switch ( iWhich )  {
+    case 0: qsReturn = list[0]; break;
+    case 1: qsReturn = list[1]; break;
+    case 2: qsReturn = list[2]; break;
+    case 3: qsReturn = list[3]; break;
+    } 
+  }
+  return qsReturn;
+}
+
 bool DVDAuthor::addToMenu ( CXmlDVDAuthor::menus_struct *pXMLMenu, ExportTitleset *pExpTitleset )
 {
   CXmlDVDAuthor::pgc_struct *pPgc;
 
+  QString qsWidth  = getFromFormat ( pExpTitleset->qsFormat, 0 );
+  QString qsHeight = getFromFormat ( pExpTitleset->qsFormat, 1 );
+  QString qsRatio  = getFromFormat ( pExpTitleset->qsFormat, 2 );
+  if ( ( qsWidth.length ( ) > 0 ) && ( qsHeight.length ( ) > 0 ) && ( qsRatio.length ( ) > 0 ) )  {
+    QString qsRes = qsWidth + "x" + qsHeight;
+    addToVideo ( &pXMLMenu->video, qsRes, qsRatio );
+  }
   pPgc = pXMLMenu->addPgc ( );
   return addToMenu ( pPgc, pExpTitleset );
 }
@@ -1649,7 +1685,7 @@ void DVDAuthor::getButtonNumberFromName ( QValueList <ButtonObject *> &listButto
     qsButtonName.remove ( "&quot;" );
     for ( i=0; i<listButtons.count ( ); i++ ) {
       if ( listButtons[i]->name ( ) == qsButtonName ) {
-	qsButtonName = QString ( "g4=%1; button=%1" ).arg ( ( i + 1 ) * 1024 ).arg ( ( i + 1 ) * 1024 );
+	qsButtonName = QString ( "g4=%1; button=%2" ).arg ( ( i + 1 ) * 1024 ).arg ( ( i + 1 ) * 1024 );
 	qsAction.replace ( rx, qsButtonName );
 	return;
       }
@@ -1953,22 +1989,22 @@ bool Spumux::createXml (DVDMenu *pMenu)
 			qsDown  = pButton->next(NEXT_BUTTON_DOWN);
 			qsRight = pButton->next(NEXT_BUTTON_RIGHT);
 			qsLeft  = pButton->next(NEXT_BUTTON_LEFT);
-			if ( (!qsUp.isEmpty())    && (!qsUp    != QString ("-- default --")) && 
+			if ( ( ! qsUp.isEmpty ( ) ) && ( qsUp != QString ("-- default --")) && 
 			     (qsUp    == listButtons[i]->name()) ) {
 			  qsButtonName = qsUp.replace (" ", "_");
 			  pXmlButton->up.sprintf ("%02d_%s", i+1, qsButtonName.ascii());
 			}
-			if ( (!qsDown.isEmpty())  && (!qsDown  != QString ("-- default --")) && 
+			if ( ( qsDown.isEmpty ( ) ) && ( qsDown  != QString ("-- default --")) && 
 			     (qsDown  == listButtons[i]->name()) ) {
 			  qsButtonName = qsDown.replace (" ", "_");
 			  pXmlButton->down.sprintf ("%02d_%s", i+1, qsButtonName.ascii());
 			}
-			if ( (!qsLeft.isEmpty())  && (!qsLeft  != QString ("-- default --")) && 
+			if ( ( qsLeft.isEmpty ( ) ) && ( qsLeft  != QString ("-- default --")) && 
 			     (qsLeft  == listButtons[i]->name()) ) {
 			  qsButtonName = qsLeft.replace (" ", "_");
 			  pXmlButton->left.sprintf ("%02d_%s", i+1, qsButtonName.ascii());
 			}
-			if ( (!qsRight.isEmpty()) && (!qsRight != QString ("-- default --")) && 
+			if ( ( qsRight.isEmpty ( ) ) && ( qsRight != QString ("-- default --")) && 
 			     (qsRight == listButtons[i]->name()) ) {
 			  qsButtonName = qsRight.replace (" ", "_");
 			  pXmlButton->right.sprintf ("%02d_%s", i+1, qsButtonName.ascii());
@@ -2480,6 +2516,7 @@ QString PlayMultiple::getPostCommand ( )
   qsPlayMultiple += qsPost;
   qsPlayMultiple += "\t\tcall vmgm menu entry title;\n";
   qsPlayMultiple += "\t}";
+
   return qsPlayMultiple;
 }
 
