@@ -20,6 +20,14 @@
 namespace Export
 {
 
+BaseSubtitle::BaseSubtitle  ( )
+{
+}
+
+BaseSubtitle::~BaseSubtitle  ( )
+{
+}
+
 Srt::Srt ()
 {
 }
@@ -28,7 +36,7 @@ Srt::~Srt ()
 {
 }
 
-bool Srt::exportSrt ( Subtitles *pSubtitles )
+bool Srt::exportSub ( Subtitles *pSubtitles )
 {
   QString qsExportFile = QFileDialog::getSaveFileName ( Global::qsCurrentPath, QObject::tr("Subtitle files (*.srt *.SRT)"), NULL, QObject::tr("Save Subtitles File") );
 
@@ -47,9 +55,9 @@ bool Srt::writeFile ( Subtitles *pSubtitles, QString &fileName )
   Subtitles::entry *pEntry;
   QFile projectFile ( fileName );
 
-  if ( ! projectFile.open ( IO_ReadWrite ) )
+  if ( ! projectFile.open ( IO_WriteOnly ) )
     return false;
-  
+
   QTextStream srtStream( &projectFile );
   for ( t=0;t<pSubtitles->m_listOfSubtitles.count ();t++) {
     pEntry = pSubtitles->m_listOfSubtitles[t];
@@ -61,7 +69,7 @@ bool Srt::writeFile ( Subtitles *pSubtitles, QString &fileName )
     srtStream << qsTimeStart << " --> " << qsTimeStop << "\n";
     srtStream << pEntry->qsText << "\n\n";
   }
-  
+
   projectFile.flush ( );
   projectFile.close ( );
 
