@@ -21,6 +21,7 @@
 #include "log.h"
 
 // Forward declartion of the Thumbs cache class
+class SlideDefaults;
 namespace Cache {
    class Thumbs;
 };
@@ -153,11 +154,14 @@ public:
 	static QString qsLanguage;
 	static QString qsDefaultLanguage; // en
 	static QString qsDefaultFormat;   // PAL or NTSC
+	static uint    iRegionalZone;
 	static uint    iMaxRunningThreads;
 	static int     iDeleteTempOlderThan;
 	static int     iChildThreadPriority;
-	static QEventLoop  eventLoop;
-	static MenuObject *pCopyObject;
+	static bool    bPNGRender;
+	static QEventLoop     eventLoop;
+	static MenuObject    *pCopyObject;
+	static SlideDefaults *pSlideDefaults;
 	// Here we store the path to the different tools required.
 	static QValueList<Utils::toolsPaths *> listToolsPaths;
 	static Cache::Thumbs *pThumbsCache;
