@@ -41,7 +41,8 @@
 ImageObject::ImageData::ImageData ( )
   : MenuObject::Data ( )
 {
-    m_iDataType = Data::IMAGE;
+  m_bHidden   = false;
+  m_iDataType = Data::IMAGE;
 }
 
 ImageObject::ImageData::~ImageData ( )
@@ -55,9 +56,10 @@ MenuObject::Data &ImageObject::ImageData::operator = ( Data &theOther )
   if ( m_iDataType == theOther.m_iDataType )  {
        ImageData *pOther  = (ImageData *)&theOther;
        m_imageManipulator = pOther->m_imageManipulator;
+       m_bHidden          = pOther->m_bHidden;
   }
   if ( theOther.m_iDataType == Data::DATA )  {
-       m_imageManipulator = theOther.m_modifiers;
+       m_imageManipulator   = theOther.m_modifiers;
   }
   return *this;
 }
@@ -71,7 +73,8 @@ bool ImageObject::ImageData::operator == ( Data &theOther )
 
   if ( m_iDataType == theOther.m_iDataType )  {
     ImageData *pOther = (ImageData *)&theOther;
-    bReturn = ( m_imageManipulator == pOther->m_imageManipulator );
+    bReturn  = ( ( m_imageManipulator == pOther->m_imageManipulator ) &&
+                 ( m_bHidden          == pOther->m_bHidden          ) );
   }
   return bReturn;
 }
@@ -112,6 +115,11 @@ void ImageObject::setFile ( QString fileName )
 	m_qsFileName = fileName;
 }
 
+void ImageObject::setHidden ( bool bHidden )
+{
+  imageData ( )->m_bHidden = bHidden;
+}
+
 void ImageObject::setZoom ( float fZoom )
 {
   // For the purpose of this class the Zoom is alreaduy incorporated into m_pixmap ...
@@ -142,6 +150,11 @@ Modifiers *ImageObject::modifiers()
   return (Modifiers *) &manipulator ( );
 }
 
+ImageObject::ImageData *ImageObject::imageData ( )
+{
+  return (ImageData *)m_pData;
+}
+
 QString &ImageObject::fileName()
 {
 	return m_qsFileName;
@@ -158,7 +171,12 @@ QImage &ImageObject::image ( )
 
 float ImageObject::zoom ( )
 {
-	return manipulator ( ).fZoom;
+        return manipulator ( ).fZoom;
+}
+
+bool ImageObject::hidden ( )
+{
+        return imageData ( )->m_bHidden;
 }
 
 void ImageObject::drawContents ( QPainter *painter )
@@ -208,7 +226,7 @@ void ImageObject::drawContents ( QPainter *painter )
 	if ( manipulator ( ).fTransparency == 1.0 )
 		return;
 
-	if ( ! isActive ( ) )  {
+	if ( ( ! isActive ( ) ) && ( ! hidden ( ) ) ) {
                 if ( m_pShadow )
 	             m_pShadow->drawContents ( painter );
 
@@ -514,11 +532,16 @@ bool ImageObject::readProjectFile  (QDomNode &theNode)
 	QDomElement theElement = theNode.toElement();
 	// The video node has only attributes and nothing else.
 	QDomAttr attribute = theElement.attributeNode ( IMAGE_OBJECT_FILE_NAME );
-	if (!attribute.isNull())
-		setFile ( attribute.value() );
+	if ( ! attribute.isNull ( ) )
+		setFile ( attribute.value ( ) );
 
-	QDomNode manNode = theNode.firstChild();
-	while (!manNode.isNull())	{
+	setHidden ( false );
+	attribute = theElement.attributeNode ( IMAGE_OBJECT_HIDDEN );
+	if ( ! attribute.isNull ( ) && attribute.value ( ) == "true" )
+		setHidden  ( true );
+
+	QDomNode  manNode = theNode.firstChild ( );
+	while ( ! manNode.isNull ( ) )  {
 		QDomElement manElement = manNode.toElement();
 		if (manElement.tagName() == MANIPULATOR)
 			manipulator().readProjectFile (manNode);
@@ -537,7 +560,9 @@ bool ImageObject::writeProjectFile (QDomElement &theElement)
 	QDomElement imageNode = xmlDoc.createElement( IMAGE_OBJECT );	// <FrameObject>
 	// Here we set the attributes of the <dvdauthor> tag
 	if (!m_qsFileName.isNull())
-		imageNode.setAttribute( IMAGE_OBJECT_FILE_NAME, m_qsFileName );
+		imageNode.setAttribute ( IMAGE_OBJECT_FILE_NAME, m_qsFileName );
+	if ( hidden ( ) )
+		imageNode.setAttribute ( IMAGE_OBJECT_HIDDEN, "true" );
 
 	manipulator().writeProjectFile (imageNode);
 
@@ -876,6 +901,7 @@ MenuObject *ImageObject::clone ( QWidget *pParent, MenuObject * )
   pNewObject->setRect        ( rect        ( ) );
   pNewObject->setManipulator ( manipulator ( ) );
   pNewObject->setAnimation   ( animation   ( ) );
+  pNewObject->setHidden      ( hidden      ( ) );
 
   MenuObject *pShadow = shadow  ( );
   if ( pShadow )
