@@ -779,10 +779,8 @@ MenuObject *MenuPreview::insertDraggedSourceEntry ( QDropEvent *pDropEvent, QIma
 	// Note that at this point we KNOW that the source is coming from the ListViewAllSources - toolbar !!!
 	ListViewMedia   *pListViewMedia   = (ListViewMedia *)pDropEvent->source     ( );
 	SourceFileEntry *pSourceFileEntry = pListViewMedia->draggingSourceFileEntry ( );
-	SourceFileInfo  *pSourceFileInfo  = NULL;
 
 	for (t=0;t<pSourceFileEntry->listFileInfos.count();t++)	{
-		pSourceFileInfo  = pSourceFileEntry->listFileInfos[t];
 		pButtonObject = (ButtonObject *)createButtonObject( );
 		pObjectCollection->append (pButtonObject);
 	}
@@ -1759,7 +1757,7 @@ void MenuPreview::slotCreateButtonDialog ( ButtonObject *pButtonObject )
 	// Second step is to invoke the ButtonDialog ...
 	m_pDialogButton = new DialogButton ( this );
 	m_pDialogButton->initMe ( pButtonObject, this );
-	m_pDialogButton->setMenuButtons  ( listMenuButtons );
+	m_pDialogButton->setMenuButtons   ( listMenuButtons );
 	m_pDialogButton->show ( );
 	connect ( m_pDialogButton, SIGNAL ( signalUpdateStructure ( ) ), this, SLOT ( slotUpdateStructure       ( ) ) );
 	connect ( m_pDialogButton, SIGNAL ( signalUpdatePixmap    ( ) ), this, SLOT ( slotUpdatePixmap          ( ) ) );
