@@ -21,15 +21,15 @@
 // Modifiers class
 //
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-Modifiers::Modifiers() 
-{ 
+Modifiers::Modifiers ( )
+{
   fRotate = fShearX = fShearY = fTransparency = 0.0; 
   fZoom   = fScaleX = fScaleY = 1.0; 
   iStartFrame       =  iStopFrame  =  -1;
   m_pStructureItem  = NULL;
 }
 
-Modifiers::~Modifiers() 
+Modifiers::~Modifiers ( )
 {
   // Since the Modifier is part of a MenuObject AND the MenuObject deletes its own StructureItem,
   // This StructureItem is already destroyed.
@@ -38,7 +38,7 @@ Modifiers::~Modifiers()
   //  m_pStructureItem = NULL;
 }
 
-Modifiers& Modifiers::operator = (Modifiers &other)
+Modifiers& Modifiers::operator = ( Modifiers &other )
 {
 	fRotate       = other.fRotate;
 	fZoom         = other.fZoom;
@@ -52,6 +52,20 @@ Modifiers& Modifiers::operator = (Modifiers &other)
 	return *this;
 };
 
+bool Modifiers::operator == ( Modifiers &other )
+{
+  bool bReturn = ( ( fRotate       == other.fRotate       ) &&
+                   ( fZoom         == other.fZoom         ) &&
+                   ( fScaleX       == other.fScaleX       ) &&
+                   ( fScaleY       == other.fScaleY       ) &&
+                   ( fShearX       == other.fShearX       ) &&
+                   ( fShearY       == other.fShearY       ) &&
+                   ( iStartFrame   == other.iStartFrame   ) &&
+                   ( iStopFrame    == other.iStopFrame    ) &&
+                   ( fTransparency == other.fTransparency ) );
+  return bReturn;
+};
+
 bool Modifiers::isUnchanged ()
 {
     Modifiers initialValues;
@@ -116,7 +130,7 @@ bool Modifiers::readProjectFile (QDomNode &theNode)
   attribute = manElement.attributeNode ( MODIFIERS_SCALEX );
   if (!attribute.isNull())
     fScaleX = attribute.value().toFloat();
-  
+
   attribute = manElement.attributeNode ( MODIFIERS_SCALEY );
   if (!attribute.isNull())
     fScaleY = attribute.value().toFloat();
@@ -136,7 +150,7 @@ bool Modifiers::readProjectFile (QDomNode &theNode)
   attribute = manElement.attributeNode ( MODIFIERS_START_FRAME );
   if (!attribute.isNull())
     iStartFrame = attribute.value().toInt();
-  
+
   attribute = manElement.attributeNode ( MODIFIERS_STOP_FRAME );
   if (!attribute.isNull())
     iStopFrame = attribute.value().toInt();
@@ -146,9 +160,14 @@ bool Modifiers::readProjectFile (QDomNode &theNode)
 
 StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, StructureItem *pPreviousItem )
 {
+  if ( ! pParentItem )  {
+    m_pStructureItem = NULL;
+    return NULL;
+  }
+
   // And finally we create the modifiers info ...
-  if ( !( (fRotate == 0.0) && (fShearX == 0.0) && (fShearY == 0.0) &&
-	  (fZoom   == 1.0) && (fScaleX == 1.0) && (fScaleY == 1.0) ) )  {
+  if ( !( ( fRotate == 0.0 ) && ( fShearX == 0.0 ) && ( fShearY == 0.0 ) &&
+          ( fZoom   == 1.0 ) && ( fScaleX == 1.0 ) && ( fScaleY == 1.0 ) ) )  {
     // First we get the translatable strings :
     StructureItem *pTemp;
     MenuObject *pMenuObject = pParentItem->getMenuObject ( );
@@ -158,7 +177,7 @@ StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, Structur
     QString qsRotate    = QObject::tr ( "Rotate"       );
 
     if ( ! m_pStructureItem )  {
-      m_pStructureItem = new StructureItem ( pMenuObject, pParentItem, pPreviousItem, qsModifiers, NULL );
+      m_pStructureItem = new StructureItem ( pMenuObject, StructureItem::Modifiers, pParentItem, pPreviousItem, qsModifiers, NULL );
       m_pStructureItem->setExpandable ( TRUE );
     }
 
@@ -168,7 +187,7 @@ StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, Structur
 
     qsArgs = QString ( "%1 <%2x%3>" ).arg ( fZoom ).arg ( fScaleX ).arg ( fScaleY );
     pTemp  = m_pStructureItem->setSibling ( pMenuObject, pTemp, qsZoom,  qsArgs );
-    
+
     qsArgs = QString ( "%1, %2" ).arg ( fShearX ).arg ( fShearY );
     pTemp  = m_pStructureItem->setSibling ( pMenuObject, pTemp, qsShear, qsArgs );
   }
@@ -185,35 +204,42 @@ StructureItem *Modifiers::createStructure ( StructureItem *pParentItem, Structur
 // ImageManipulator class
 //
 ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-ImageManipulator::ImageManipulator ()
+bool ImageManipulator::colorKeying::operator == ( ImageManipulator::colorKeying &theOther )
 {
-	node_name = QString (MANIPULATOR);
+  return ( ( theColor == theOther.theColor ) && ( fDeltaColor == theOther.fDeltaColor ) );
+}
 
-	backgroundFileName = QString ("");
+
+ImageManipulator::ImageManipulator ( )
+  : Modifiers ( )
+{
+	node_name = QString ( MANIPULATOR );
+
+	backgroundFileName = QString ( "" );
 	bShowBackground = false;
-	fKenBurnsX1 = -1.0f;
-	fKenBurnsY1 = -1.0f;
-	fKenBurnsX2 = -1.0f;
-	fKenBurnsY2 = -1.0f;
-	fStartX     =  0.0f;
-	fStartY     =  0.0f;
-	iXRes = 720;
-	iYRes = 480;
+	fKenBurnsX1     = -1.0f;
+	fKenBurnsY1     = -1.0f;
+	fKenBurnsX2     = -1.0f;
+	fKenBurnsY2     = -1.0f;
+	fStartX         =  0.0f;
+	fStartY         =  0.0f;
+	iXRes           =   720;
+	iYRes           =   480;
 	iTransformationMode = 0;
-	fAspectRatio = 4.0f/3.0f;
-	fShearX = 0.0f;
-	fShearY = 0.0f;
-	fZoom   = 1.0f;
-	fScaleX = 1.0f;
-	fScaleY = 1.0f;
-	fRotate = 0.0f;
-	fRed    = 1.0f;
-	fGreen  = 1.0f;
-	fBlue   = 1.0f;
-	fBrightness   = 0.0f;
-	fTransparency = 0.0f;	// Opaque in the beginning ...
-	iStartFrame   =   -1;
-	iStopFrame    =   -1;
+	fAspectRatio   =   4.0f/3.0f;
+	fShearX        =   0.0f;
+	fShearY        =   0.0f;
+	fZoom          =   1.0f;
+	fScaleX        =   1.0f;
+	fScaleY        =   1.0f;
+	fRotate        =   0.0f;
+	fRed           =   1.0f;
+	fGreen         =   1.0f;
+	fBlue          =   1.0f;
+	fBrightness    =   0.0f;
+	fTransparency  =   0.0f;	// Opaque in the beginning ...
+	iStartFrame    =     -1;
+	iStopFrame     =     -1;
 }
 
 ImageManipulator::~ImageManipulator()
@@ -370,6 +396,45 @@ bool ImageManipulator::isUnchanged ()
   return true;
 }
 
+bool ImageManipulator::operator == ( ImageManipulator &other )
+{
+  Modifiers &IAm  = (Modifiers &)*this;
+  Modifiers &cool = (Modifiers &)other;
+  bool bReturn = ( IAm == cool );
+  if ( ! bReturn )
+    return false;
+
+  bReturn = ( ( backgroundFileName    == other.backgroundFileName  ) &&
+              ( bShowBackground       == other.bShowBackground     ) &&
+              ( fStartX               == other.fStartX             ) &&
+              ( fStartY               == other.fStartY             ) &&
+              ( fKenBurnsX1           == other.fKenBurnsX1         ) &&
+              ( fKenBurnsY1           == other.fKenBurnsY1         ) &&
+              ( fKenBurnsX2           == other.fKenBurnsX2         ) &&
+              ( fKenBurnsY2           == other.fKenBurnsY2         ) &&
+              ( iXRes                 == other.iXRes               ) &&
+              ( iYRes                 == other.iYRes               ) &&
+              ( iTransformationMode   == other.iTransformationMode ) &&
+              ( fAspectRatio          == other.fAspectRatio        ) &&
+              ( fRed                  == other.fRed                ) &&
+              ( fGreen                == other.fGreen              ) &&
+              ( fBlue                 == other.fBlue               ) &&
+              ( fBrightness           == other.fBrightness         ) &&
+              ( listColorKeys.count() == other.listColorKeys.count() ) );
+  if ( ! bReturn )
+    return false;
+
+  QValueList<colorKeying *>::iterator it1 =       listColorKeys.begin ( );
+  QValueList<colorKeying *>::iterator it2 = other.listColorKeys.begin ( );
+
+  while ( it1 != listColorKeys.end ( ) )  {
+    if  ( ! ( *(*it1++) == *(*it2++) ) )
+      return false;
+  }
+
+  return bReturn;
+};
+
 bool ImageManipulator::writeProjectFile (QDomElement &theElement)
 {
   QDomDocument xmlDoc = theElement.ownerDocument();
@@ -415,19 +480,23 @@ bool ImageManipulator::writeProjectFile (QDomElement &theElement)
       QDomElement colorKeyNode = xmlDoc.createElement ( MANIPULATOR_COLOR_KEY );
       Rgba        theColor ( listColorKeys[t]->theColor );
       if ( listColorKeys[t]->fDeltaColor != 0.0 )
-	colorKeyNode.setAttribute ( MANIPULATOR_DELTA, QString ("%1").arg ( listColorKeys[t]->fDeltaColor ) );
+        colorKeyNode.setAttribute ( MANIPULATOR_DELTA, QString ("%1").arg ( listColorKeys[t]->fDeltaColor ) );
       colorKeyNode.setAttribute   ( MANIPULATOR_COLOR, theColor.toString ( ) );
       manipulatorNode.appendChild ( colorKeyNode );
     }
     theElement.appendChild( manipulatorNode );
   }
-  
+
   return true;
 }
 
 StructureItem *ImageManipulator::createStructure ( StructureItem *pParentItem, StructureItem *pPreviousItem )
 {
   QString qsName;
+  if ( ! pParentItem )  {
+    m_pStructureItem = NULL;
+    return NULL;
+  }
 
   ImageManipulator initialValues;
   // And finally we create the modifiers info ...
@@ -451,11 +520,11 @@ StructureItem *ImageManipulator::createStructure ( StructureItem *pParentItem, S
 	  ( iStartFrame   == initialValues.iStartFrame)   &&
 	  ( iStopFrame    == initialValues.iStopFrame)    &&
 	  ( listColorKeys.count() > 0) ) )  {
-	  
+
     StructureItem *pTemp=NULL;
     if ( ! m_pStructureItem ) {
       MenuObject *pMenuObject = pParentItem->getMenuObject ( );
-      m_pStructureItem = new StructureItem ( pMenuObject, pParentItem, pPreviousItem, QObject::tr ( "Modifiers" ), NULL );
+      m_pStructureItem = new StructureItem ( pMenuObject, StructureItem::Modifiers, pParentItem, pPreviousItem, QObject::tr ( "Modifiers" ), NULL );
       pParentItem->setExpandable ( TRUE );
     }
 
@@ -464,33 +533,47 @@ StructureItem *ImageManipulator::createStructure ( StructureItem *pParentItem, S
       delete pTemp;
       pTemp = (StructureItem *)m_pStructureItem->firstChild ( );
     }
-    
+
     if ( ( fRed   != initialValues.fRed   ) ||
 	 ( fGreen != initialValues.fGreen ) ||
 	 ( fBlue  != initialValues.fBlue  ) )
-      new StructureItem ( m_pStructureItem, QObject::tr ("Color Adjust"),  QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Color Adjust"),  QString ("%1, %2, %3").arg(fRed).arg(fGreen).arg(fBlue));
     if ( fBrightness    != initialValues.fBrightness )
-      new StructureItem ( m_pStructureItem, QObject::tr ("Brightness"),    QString ("%1").arg(fBrightness));
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Brightness"),    QString ("%1").arg(fBrightness));
     if ( fTransparency  != initialValues.fTransparency )
-      new StructureItem ( m_pStructureItem, QObject::tr ("Transparency"),  QString ("%1").arg(fTransparency));
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Transparency"),  QString ("%1").arg(fTransparency));
     if ( ( fShearX      != initialValues.fShearX ) || ( fShearY  != initialValues.fShearY)  )
-      new StructureItem ( m_pStructureItem, QObject::tr ("Shear (x, y)"),  QString ("%1, %2").arg(fShearX).arg(fShearY));
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Shear (x, y)"),  QString ("%1, %2").arg(fShearX).arg(fShearY));
     if ( ( iStartFrame  != initialValues.iStartFrame ) || ( iStopFrame  != initialValues.iStopFrame) )
-      new StructureItem ( m_pStructureItem, QObject::tr ("VisibleFromTo"), QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("VisibleFromTo"), QString ("%1, %2").arg(iStartFrame).arg(iStopFrame));
     if ( fZoom  != initialValues.fZoom )
-      new StructureItem ( m_pStructureItem, QObject::tr ( "Zoom" ), QString ("%1").arg ( fZoom ) );
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ( "Zoom" ), QString ("%1").arg ( fZoom ) );
     if ( fRotate  != initialValues.fRotate )
-      new StructureItem ( m_pStructureItem, QObject::tr ("Rotate"), QString ("%1 deg").arg ( fRotate ) );
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ("Rotate"), QString ("%1 deg").arg ( fRotate ) );
     if ( listColorKeys.count ( ) > 0 )  {
       QString qsColorKeys ( "|" );
       for ( uint t=0; t<listColorKeys.count ( ); t++ )
 	qsColorKeys += QString ( "0x%1|" ).arg ( listColorKeys[t]->theColor, 16 );
-      new StructureItem ( m_pStructureItem, QObject::tr ( "ColorKey" ), qsColorKeys );
+      new StructureItem ( m_pStructureItem, StructureItem::Attributes, QObject::tr ( "ColorKey" ), qsColorKeys );
     }
   }
   return m_pStructureItem;
 }
 
+ImageManipulator &ImageManipulator::operator = ( Modifiers &theOther )
+{
+  fRotate       = theOther.fRotate;
+  fZoom         = theOther.fZoom;
+  fScaleX       = theOther.fScaleX;
+  fScaleY       = theOther.fScaleY;
+  fShearX       = theOther.fShearX;
+  fShearY       = theOther.fShearY;
+  iStartFrame   = theOther.iStartFrame;
+  iStopFrame    = theOther.iStopFrame;
+  fTransparency = theOther.fTransparency;
+  return *this;
+};
+
 ImageManipulator& ImageManipulator::operator = (ImageManipulator &theOther)
 {
   uint t;
