@@ -29,6 +29,25 @@ class MovieObject : public ImageObject
 	Q_OBJECT
 public:
 	enum enType { Loop = 0, Stretch, Stop };
+private:
+	class MovieData : public ImageObject::ImageData
+	{
+	public:
+	           MovieData ( );
+	  virtual ~MovieData ( );
+	  virtual  Data &operator  = ( Data & );
+	  virtual  bool  operator == ( Data & );
+	  virtual  Data *clone ( );
+
+	  long     m_iMSecPreview;
+	  QTime    m_timeOffset;
+	  QTime    m_timeDuration;
+	  bool     m_bMenuLength;
+	  enType   m_enLoop;
+	  bool     m_bStartAfterDropEvent;
+	};
+
+public:
 	MovieObject                     ( QWidget *pParent=0 );
 	virtual ~MovieObject            ( );
 
@@ -92,19 +111,16 @@ protected slots:
 	ImageManipulator m_imageManipulator;
 */
 
-protected:
+private:
+	MovieData *movieData ( );
+
+private:
 	DVDMenu *m_pDVDMenu;
 	bool     m_bExtracted;
 	QSize    m_sizeOriginalMovieSize;
-	long     m_iMSecPreview;
-	QTime    m_timeOffset;
-	QTime    m_timeDuration;
-	bool     m_bMenuLength;
-	enType   m_enLoop;
 	QImage   m_imagePreview;	// used to create a preview in a background task.
 	int      m_iHowNiceShouldIBe;
-	bool     m_bStartAfterDropEvent;
 	QTimer  *m_pConvertTimer;
 };
 
-#endif	// MOVIEOBJECT_H
+#endif  // MOVIEOBJECT_H
