@@ -8,6 +8,7 @@
 **
 *****************************************************************************/
 #include <stdlib.h> 
+#include <unistd.h>
 #include <dlfcn.h>
 
 #include <qdir.h>
@@ -612,8 +613,6 @@ GroupView *OneClickWizard::addGroup ( CXmlSlideshow *pSlideshow )
   CXmlSlideshow::time_object *pXmlObj = NULL;
   CXmlSlideshow::img_struct  *pXmlImg = NULL;
   CXmlSlideshow::vid_struct  *pXmlVid = NULL;
-  CXmlSlideshow::img_struct   tempImg;
-  CXmlSlideshow::vid_struct   tempVid;
   GroupView::Item *pItem       = NULL;
   GroupView       *pGroupView  = new GroupView ( m_pToolBoxGroups, NULL, NULL, pSlideshow );
   QImage theImage ( QImage ( ).fromMimeSource ( "error.jpg" ) );
@@ -631,13 +630,15 @@ GroupView *OneClickWizard::addGroup ( CXmlSlideshow *pSlideshow )
 
     bAlternate = ! bAlternate;
 
-    if ( pXmlObj->node_name == tempImg.node_name )  {
+    if ( pXmlObj->node_name == IMG_NODE )  {
       pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
+printf ( "<%s> <%d,%d, %d,%d>\n", pXmlImg->src.ascii(), pXmlImg->effect[0].x0, pXmlImg->effect[0].y0, pXmlImg->effect[0].y0, pXmlImg->effect[0].y1 );
+
       pCache  = Global::pThumbsCache->find ( pXmlImg->src, true );
       fileInfo.setFile ( pXmlImg->src );
       pItem = new GroupView::Item ( pGroupView, fileInfo.fileName ( ), bAlternate );
     }
-    else if ( pXmlObj->node_name == tempVid.node_name )  {
+    else if ( pXmlObj->node_name == VID_NODE )  {
       pXmlVid = (CXmlSlideshow::vid_struct *)pXmlObj;
       pCache  = Global::pThumbsCache->find ( pXmlVid->src, false );
       fileInfo.setFile ( pXmlVid->src );
@@ -809,11 +810,11 @@ void OneClickWizard::addSourceToGroup ( GroupView *pGroupView )
   QString          qsMovieFilter;
   QStringList      list;
   GroupView::Item *pItem;
-  qsMovieFilter =  Global::pApp->getImageFilter ( );
+  qsMovieFilter   = Global::pApp->getImageFilter ( );
   if ( pGroupView->sourceFileEntry ( ) )
-    qsMovieFilter =  Global::pApp->getMovieFilter ( );
+    qsMovieFilter = Global::pApp->getMovieFilter ( );
 
-  list          =  FilePreviewDialog::getOpenFileNames ( NULL, Global::qsCurrentPath, QString ("Movies ( ") + qsMovieFilter + QString (" );;All ( * )"));
+  list = FilePreviewDialog::getOpenFileNames ( NULL, Global::qsCurrentPath, QString ("Movies ( ") + qsMovieFilter + QString (" );;All ( * )"));
   if ( list.count ( ) < 1 )
     return;
 
@@ -1000,6 +1001,7 @@ void OneClickWizard::sourceFileToPlugin ( Plugin::SourceGroup *pGroup, SourceFil
     Plugin::SourceGroup::SourceEntry *pSourceEntry = new Plugin::SourceGroup::SourceEntry;
     pSourceEntry->qsFileName = pInfo->qsFileName;
     pSourceEntry->iLength    = theUtils.getMsFromString ( pInfo->qsLength );
+    
     pGroup->listFiles.append ( pSourceEntry );
   }
   // In case no screenshot could be found ... Sorry we have an issue here
@@ -1019,8 +1021,6 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   unsigned int     t, iCount;
   CXmlSlideshow::time_object *pXmlObj = NULL;
   CXmlSlideshow::img_struct  *pXmlImg = NULL;
-  CXmlSlideshow::img_struct   tempImg;
-  CXmlSlideshow::vid_struct   tempVid;
 
   pGroup->qsGroupName         = pSlideshow->slideshow_name;
   pGroup->bSlideshow          = true;
@@ -1032,6 +1032,7 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   pGroup->iFlags  =   pSlideshow->imgBkgImg ( ) ? 1 : 0;
   pGroup->iFlags |=   pSlideshow->intro_page    ? 2 : 0;
   pGroup->iFlags |= ( pSlideshow->yres == 576 ) ? 4 : 0;
+  pGroup->iFlags |=   pSlideshow->kenBurns  ( ) ? 8 : 0;
 
   // The following is currently not used ...
   pGroup->dateStart           = QDateTime ( date, time );
@@ -1042,7 +1043,7 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
   for ( t=0; t<iCount; t++ )  {
     pXmlObj = pSlideshow->getTimeObject ( t );
     pXmlImg = NULL;
-    if ( pXmlObj->node_name == tempImg.node_name )  {
+    if ( pXmlObj->node_name == IMG_NODE )  {
       pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
       // Make sure the Group has a sceenshot associated with
       if ( pGroup->qsScreenshot.isEmpty ( ) )  {
@@ -1056,18 +1057,23 @@ void OneClickWizard::slideshowToPlugin ( Plugin::SourceGroup *pGroup, CXmlSlides
         }
       }
     }
-    else if ( pXmlObj->node_name == tempVid.node_name )
+    else if ( pXmlObj->node_name == VID_NODE ) 
       pXmlImg = (CXmlSlideshow::img_struct *)pXmlObj;
     if ( ! pXmlImg )
       continue;
 
     Plugin::SourceGroup::SourceEntry *pSourceEntry = new Plugin::SourceGroup::SourceEntry;
     pSourceEntry->qsFileName = pXmlImg->src;
-    pSourceEntry->bVidSource = ( pXmlObj->node_name == tempVid.node_name );
+    pSourceEntry->bVidSource = ( pXmlObj->node_name == VID_NODE );
     if ( pXmlImg->fDuration > 0.0f )
       pSourceEntry->iLength  = (unsigned long)( pXmlImg->fDuration * 1000.0 ); // in MSec
     else
       pSourceEntry->iLength  = (unsigned long)( pSlideshow->delay  * 1000.0 ); // in MSec
+    if ( pSlideshow->kenBurns  ( ) && ! pSourceEntry->bVidSource )  {
+      pSourceEntry->qsKenBurns.sprintf ( "%d,%d,%d,%d,%d,%d,%d,%d", 
+        pXmlImg->effect[0].x0,  pXmlImg->effect[0].y0,  pXmlImg->effect[0].x1,  pXmlImg->effect[0].y1, 
+        pXmlImg->effect[0].xe0, pXmlImg->effect[0].ye0, pXmlImg->effect[0].xe1, pXmlImg->effect[0].ye1 );
+    }
     pGroup->listFiles.append ( pSourceEntry );
   }
   // In case no screenshot could be found ... Sorry we have an issue here
