@@ -54,28 +54,30 @@ protected:
     void addSourceToGroup  ( GroupView       * );
     void toSourceGroup     ( );
     void groupsToPlugin    ( );
+    void createScrollView  ( );
 
     void sourceFileToPlugin ( Plugin::SourceGroup *, SourceFileEntry * );
     void slideshowToPlugin  ( Plugin::SourceGroup *, CXmlSlideshow   * );
 
 protected slots:
-    virtual void accept             ( );
-    virtual void slotHelp           ( );
-    virtual void slotBrowseTemp     ( );
-    virtual void slotBrowseDVD      ( );
-    virtual void slotGroupUp        ( );
-    virtual void slotGroupDown      ( );
-    virtual void slotGroupDelete    ( );
-    virtual void slotGroupRename    ( );
-    virtual void slotAddVideos      ( );
-    virtual void slotAddImages      ( );
-    virtual void slotCurrentGroup   ( int  );
-    virtual void slotChangePlugin   ( int  );
-    virtual void slotCreateISO      ( bool );
-    virtual void slotBurnDVD        ( bool );
-    virtual void slotProjectName    ( const QString & );
-    virtual void slotGroupContextMenu     ( QListViewItem *, const QPoint &, int );
-    virtual void slotSourceToSourceGroup  ( QListBoxItem  * );
+    virtual void accept                 ( );
+    virtual void slotHelp               ( );
+    virtual void slotBrowseTemp         ( );
+    virtual void slotBrowseDVD          ( );
+    virtual void slotGroupUp            ( );
+    virtual void slotGroupDown          ( );
+    virtual void slotGroupDelete        ( );
+    virtual void slotGroupRename        ( );
+    virtual void slotAddVideos          ( );
+    virtual void slotAddImages          ( );
+    virtual void slotResizeScrollView   ( );
+    virtual void slotCurrentGroup       ( int  );
+    virtual void slotChangePlugin       ( int  );
+    virtual void slotCreateISO          ( bool );
+    virtual void slotBurnDVD            ( bool );
+    virtual void slotProjectName        ( const QString & );
+    virtual void slotGroupContextMenu   ( QListViewItem *, const QPoint &, int );
+    virtual void slotSourceToSourceGroup( QListBoxItem  * );
 
 private:
     QStringList m_listOfPlugins;
@@ -91,6 +93,10 @@ private:
     Plugin::Interface  *m_pPlugin;
 
     QValueList<Group *> m_listOfGroups;
+
+    // GUI elements in the scroll view
+    QToolBox    *m_pToolBoxGroups;
+    QScrollView *m_pScrollView;
 };
 
 }; // end namespace Input
