@@ -4,8 +4,15 @@ then
 
   cd simpledvd
   make install
+  if [ -e  Makefile.tmp ]; then
+    rm -rf Makefile.tmp
+  fi;
+
   cd ../complexdvd
   make install
+  if [ -e  Makefile.tmp ]; then
+    rm -rf Makefile.tmp
+  fi;
 
 elif [ "$1" = "clean" ]
 then
