@@ -320,7 +320,8 @@ void MenuSlide::animate ( )
 void MenuSlide::animate ( unsigned long iFrameNumber )
 {
   int t, iImageCount, iStartImage, iEndImage, iImageFrames;
-  int iImageWidth, iWidth, iImageHeight, iHeight;
+//  int iImageWidth, iWidth, iImageHeight, iHeight;
+  int iWidth, iHeight;
   //int iStartFrame, iEndFrame;
   float   fDeltaZoom, fFPS = 25.0f;
   QImage  theImage;
@@ -348,8 +349,8 @@ void MenuSlide::animate ( unsigned long iFrameNumber )
     fDeltaZoom = 1.0  / ( iFrameNumber - ( t * iImageFrames ) );
     if ( ( fDeltaZoom > 0.0 ) && ( fDeltaZoom <= 1.0 ) ) {
       printf ( "Image<%d>=<%0.3f=%0.3f> ", t, fDeltaZoom, fDeltaZoom * iFrameNumber);
-      iImageWidth  = (int)( fDeltaZoom * iFrameNumber * iWidth  );
-      iImageHeight = (int)( fDeltaZoom * iFrameNumber * iHeight );
+//      iImageWidth  = (int)( fDeltaZoom * iFrameNumber * iWidth  );
+//      iImageHeight = (int)( fDeltaZoom * iFrameNumber * iHeight );
       theImage     = m_listImages[t]->thumbnail.smoothScale ( iWidth, iHeight, QImage::ScaleMin );
 
       thePainter.drawImage ( 20, 20, theImage );
@@ -501,10 +502,10 @@ QString MenuSlide::buildImageObject ( MenuSlide::ImageContainer *pImage, int iIm
 ////////////////////////////////////////////////////////////////////////////////////////
 QString MenuSlide::buildAnimation ( int iImageNumber )
 {  
-  int iTotalImages = m_listImages.count ( );
+//  int iTotalImages = m_listImages.count ( );
   double fDeltaX, fDeltaZoom, fFPS;
-  double fImageLength, fTotalLength;
-  unsigned long iTotalFrames, iStartFrame, iEndFrame, iImageFrames, t;
+  double fImageLength;
+  unsigned long iStartFrame, iEndFrame, iImageFrames, t;
   int iTotalHeight, iStartHeight = 230;
 
   QString qsAnimation; // the resulting Animation script.
@@ -516,7 +517,7 @@ QString MenuSlide::buildAnimation ( int iImageNumber )
 
   // E.g. 9 images, 5 sec length per image, 3 concurrent images == 20 sec total length
   fImageLength = getImageDuration ( );
-  fTotalLength = fImageLength  *  ( iTotalImages / m_iConcurrentImages + 1 );
+//  fTotalLength = fImageLength  *  ( iTotalImages / m_iConcurrentImages + 1 );
 
   fFPS = 25.0; // PAL
   iTotalHeight = 576;
@@ -525,7 +526,7 @@ QString MenuSlide::buildAnimation ( int iImageNumber )
     iTotalHeight = 480;
   }
 
-  iTotalFrames = (unsigned long)( fFPS * fTotalLength );
+//  iTotalFrames = (unsigned long)( fFPS * fTotalLength );
   
   // Next we calculat the start / end frame.
   iStartFrame  = (unsigned long)( fImageLength * iImageNumber * fFPS / m_iConcurrentImages );
