@@ -82,8 +82,7 @@ bool TestPlugs::loadPlugin ( uint iWhich )
 
 void TestPlugs::unloadPlugin ( )
 {
-  if ( m_pConfigWidget )
-    delete m_pConfigWidget;
+// Is destroyed in the destructor of the plugin
   m_pConfigWidget = NULL;
 
   // destroy the class
