@@ -25,6 +25,7 @@ class QListBox;
 class QPopupMenu;
 
 #include "formmain.h"
+#include "xml_slideshow.h"
 #include "plugins/interface.h"
 
 class ButtonObject;
@@ -210,6 +211,7 @@ private: // Private functions ...
 	bool readProjectFile        ( QDomNode &, float & );
 	bool renderSubtitles        ( SourceFileInfo *, bool b=false );
 	bool buildFromDvdauthorXML  ( CXmlDVDAuthor *, QValueList<CXmlSpumux *> & );
+        void recoverKB              ( CXmlSlideshow ::effect_struct *, QString );
 	void createTempDirStructure ( );
 	void createDvdauthorXml     ( );
 	void createSubtitlesXml     ( );
