@@ -16,6 +16,8 @@
 
 #include "dialogqxinesetup.h"
 #include "kaffeineswidget.h"
+#include "xineinfo.h"
+#include "../mediainfo.h"
 
 KaffeinesWidget::KaffeinesWidget(QWidget *parent, const char *name, void *)	//pExistingEngine)
 	: KXineWidget (parent, name, QString::null, QString::null, "auto", "xshm"), 
@@ -43,7 +45,9 @@ KaffeinesWidget::KaffeinesWidget(QWidget *parent, const char *name, void *)	//pE
 
 KaffeinesWidget::~KaffeinesWidget ()
 {
-
+  if ( m_pMediaInfo )
+	  delete m_pMediaInfo;
+  m_pMediaInfo = NULL;
 }
 
 QWidget *KaffeinesWidget::getWidget ()
@@ -223,7 +227,10 @@ void KaffeinesWidget::setSpeed(float fValue)
 
 void KaffeinesWidget::setVolume(float fValue)
 {
-  // Volume seems to work between [0 ..1000]
+  // Volume seems to work between [0 ..100]
+  slotSetVolume((int)(fValue*100.0));
+  return;
+  // older version ... seems to blow volume away ...
   if (m_softwareMixer)
     slotSetVolume((int)(fValue*1000.0));
   else
@@ -243,6 +250,45 @@ void KaffeinesWidget::setPositionByTime ( uint iPosition )
   slotSeekToTime ( seekTime );
 }
 
+void KaffeinesWidget::setNavigate( enNavigate nav )
+{
+  switch ( nav ) {
+  case NavigateUp:
+    slotDVDMenuUp ( );
+  break;
+  case NavigateDown:
+    slotDVDMenuDown ( );
+  break;
+  case NavigateLeft:
+    slotDVDMenuLeft ( );
+  break;
+  case NavigateRight:
+    slotDVDMenuRight ( );
+  break;
+  case NavigateSelect:
+    slotDVDMenuSelect ( );
+  break;
+ }
+}
+
+void KaffeinesWidget::setMenu ( enMenu menu )
+{
+  if ( menu == MenuRoot )
+    slotMenuRoot ( );
+  else if ( menu == MenuTitle )
+    slotMenuTitle ( );
+}
+
+void KaffeinesWidget::setSubtitleTrack ( int iTrackNumber )
+{
+  slotSetSubtitleChannel ( iTrackNumber );
+}
+
+void KaffeinesWidget::setAudioTrack ( int iTrackNumber )
+{
+  slotSetAudioChannel ( iTrackNumber );
+}
+
 float KaffeinesWidget::volume               ()
 {
   return 0.0f;
@@ -273,6 +319,15 @@ QImage KaffeinesWidget::getScreenshot ()
 
 QImage KaffeinesWidget::getScreenshot ( float fTime )
 {
+	if ( ! m_pMediaInfo )
+		m_pMediaInfo = new XineInfo ( (void *) getXineEngine ( ) );
+	QString qsFileName = getMRL ( );
+	if ( m_pMediaInfo->getFileName ( ) != qsFileName )
+	 	 m_pMediaInfo->setFileName ( getMRL ( ) );
+
+	return m_pMediaInfo->getScreenshot ( (long)( fTime * 1000.0 ) );
+
+	/*
 	// fTime in Seconds ...
 	QTime seekTime;
 	seekTime.addSecs ((int)fTime);
@@ -281,6 +336,7 @@ QImage KaffeinesWidget::getScreenshot ( float fTime )
 	seekTime.addMSecs ((int)fTime);
 	slotSeekToTime (seekTime);
 	return KXineWidget::getScreenshot ();
+	*/
 }
 
 bool KaffeinesWidget::setScreenshot ( long iMSecOffset )
