@@ -175,7 +175,7 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
 
   QFileInfo fileInfo ( QFile::encodeName ( m_qsFileName ) );
   QString qsAudioExtensions = getExtensions ( false );
-  bool iIsVideo = 1;
+  int  iIsVideo = 1;
   if ( qsAudioExtensions.find ( fileInfo.extension ( FALSE ) ) > -1 )
        iIsVideo = 0;
 
@@ -203,7 +203,9 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
 //  test = listCommand.join ( test );
 //  printf ( "MPLayerInfo::queryValues () <%s>\n", test.ascii ( ) );
 
-  m_pSlaveProcess->start ( ); 
+  QTimer::singleShot ( 0, this, SLOT ( slotStart ( ) ) );
+  usleep ( 10 );
+//  m_pSlaveProcess->start ( ); 
   Unlock ( );
 
   if ( useEventLoop ( ) )
@@ -212,6 +214,14 @@ void MPlayerInfo::queryValues ( bool bTryToLock )
     waitForProcess  ( );
 }
 
+void MPlayerInfo::slotStart ( )
+{
+  // Called through timer, as the timer is execued in the main thread.
+  // the above function queryValues () is executed in another thread, 
+  // thus crashing in m_pSlaveProcess->start ( ); -> XFlush()'s call
+  m_pSlaveProcess->start ( );
+}
+
 void MPlayerInfo::waitForProcess ( )
 {
   if ( ! m_pSlaveProcess )
@@ -448,7 +458,7 @@ QImage MPlayerInfo::getScreenshot( long iMSecOffset )
 
 	qsTempPath = QFile::encodeName ( QString ( "%1/%2" ).arg ( m_qsTempPathName ).arg ( fileInfo.baseName ( ) ) );
 	qsCommand  = QString ( "mkdir -p \"%1\"" ).arg ( qsTempPath );
-	iRet = system ( qsCommand.utf8 ( ) );
+	iRet = system ( qsCommand.utf8 ( ) ); iRet = iRet;
 	
 	m_qsScreenshotName  = QString ("%1/00000001.jpg").arg ( qsTempPath );
 	if (iMSecOffset != 0)	// For some reasons Mplayer produces always the first image from start
@@ -468,16 +478,23 @@ QImage MPlayerInfo::getScreenshot( long iMSecOffset )
 		qsCommand = QString ( "mplayer -ao null -vo jpeg:outdir=\"%1/\" -vf scale -ss %2 -forceidx -frames 3 -quiet \"%3\" >/dev/null 2>&1 &" ).arg ( qsTempPath ).arg ( timeOffset.toString ( ) ).arg ( QFile::encodeName ( qsFileName.utf8 ( ) ) );
 
 	iRet = system ( qsCommand.utf8 ( ) );
-	//printf ("MPlayerInfo::getScreenshot iRet<%d> = <%s>\n", iRet,(const char *)qsCommand);
+	// printf ("MPlayerInfo::getScreenshot iRet<%d> = <%s>\n", iRet,(const char *)qsCommand);
 
 	int iMaxWait = 0;
-	while ( ( ! fileInfo.exists ( ) ) &&
-		( iMaxWait < 5 ) ) {
-		sleep ( 1 );
-		iMaxWait ++;
+	usleep ( 100000 ); // wait 100 MS because the command was executed in the background
+	while ( iMaxWait++ < 8 )  {
+		{       // Note: Need to create a new object each time, else the 'exist' info will be buffered. This is No Good here ...
+			QFileInfo fileInfo ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );
+			if ( fileInfo.exists  ( ) )  {
+				if ( ! theImage.load ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) ) )  {
+					debug_out ( "Could not load preview from file <%s>\n", (const char *)m_qsScreenshotName.utf8 ( ) );
+				}
+				if ( theImage.width ( ) > 0 )
+					return theImage;
+			}
+			sleep ( 1 );
+		}
 	}
-	if ( fileInfo.exists ( ) )
-		theImage = QImage ( QFile::decodeName ( m_qsScreenshotName.utf8 ( ) ) );
 
 	//m_pMutex->unlock ( );
 	return theImage;
