@@ -202,7 +202,7 @@ QImage MPlayerWidget::getScreenshot ( float fSeconds )
 {
   if ( m_pMediaInfo )
     return m_pMediaInfo->getScreenshot ( (long)(fSeconds * 1000.0) );
-  return QImage ();
+  return QImage ( QImage ( ).fromMimeSource ( "error.jpg" ) );
 }
 
 bool MPlayerWidget::setScreenshot ( long iMSecOffset )
