@@ -2,8 +2,8 @@
                            qxinewidget.h
                              -------------------
     begin                : Fre Apr 18 2003
-    revision             : $Revision: 1.80 $
-    last modified        : $Date: 2008/02/23 14:50:36 $ by $Author: qdvdauthor $
+    revision             : $Revision: 1.82 $
+    last modified        : $Date: 2013/04/05 10:23:44 $ by $Author: qdvdauthor $
     copyright            : (C) 2003-2004 by J. Kofler
     email                : kaffeine@gmx.net
  ***************************************************************************/
@@ -37,6 +37,10 @@
 
 #include <X11/Xlib.h>
 
+#ifndef XINE_MAJOR_VERSION
+#include <xine/version.h>
+#endif
+#define MYXINE_VERSION_CODE  XINE_MAJOR_VERSION*10000+XINE_MINOR_VERSION*100+XINE_SUB_VERSION
 
 class QXineWidget : public QWidget, protected QThread
 {
