@@ -9,6 +9,8 @@
 **
 ****************************************************************************/
 
+#include <unistd.h>
+
 #include <qobject.h>
 #include <qimage.h>
 #include <qfile.h>
@@ -16,35 +18,46 @@
 
 #include "xineinfo.h"
 
-XineInfo::XineInfo  (void *pVoid)
-	: MediaInfo (pVoid)
+XineInfo::XineInfo  ( void *pVoid )
+	: MediaInfo ( pVoid )
 {
+	m_pXineStream    = NULL;
+	m_pAudioDriver   = NULL;
+	m_pVideoDriver   = NULL;
+	//m_pMediaEngine   = pVoid;
 	m_bOwnXineEngine = false;
-	if (!pVoid)	{
-		m_pMediaEngine = (void *)xine_new();
-		QString configFile = QDir::homeDirPath();
-		configFile.append("/.qdvdauthor/xine_config.ini");
-		if (QFile::exists(configFile))
-			xine_config_load ((xine_t *)m_pMediaEngine, (const char *)configFile);
-		xine_init((xine_t *)m_pMediaEngine);
+	if ( ! pVoid )	{
+		m_pMediaEngine = (void *)xine_new ( );
+		QString configFile = QDir::homeDirPath ( );
+		configFile.append ( "/.qdvdauthor/xine_config.ini" );
+		if ( QFile::exists ( configFile ) )
+			xine_config_load ( (xine_t *)m_pMediaEngine, (const char *)configFile );
+		xine_init ( (xine_t *)m_pMediaEngine );
 		m_bOwnXineEngine = true;
 	}
-	createXineStream ();
+	createXineStream ( );
 }
 
 XineInfo::~XineInfo ()
 {
 //printf ("XineInfo::~XineInfo Stream<%d> engine<%d>\n", (int) m_bOwnXineStream, (int) m_bOwnXineEngine);
 	// Cleaning of the xine object.
-	if (m_bOwnXineStream)
-		xine_dispose(m_pXineStream);
-	if (!m_pMediaEngine)
+	if ( m_bOwnXineStream )
+		xine_dispose ( m_pXineStream );
+	m_pXineStream = NULL;
+	if ( ! m_pMediaEngine )
 		return;
-	xine_close_audio_driver((xine_t*)m_pMediaEngine, m_pAudioDriver);
-	xine_close_video_driver((xine_t*)m_pMediaEngine, m_pVideoDriver);
-	if (m_bOwnXineEngine)
-		xine_exit((xine_t*)m_pMediaEngine);
+	if ( m_pAudioDriver )
+		xine_close_audio_driver ( (xine_t*)m_pMediaEngine, m_pAudioDriver );
+	m_pAudioDriver = NULL;
+	if ( m_pVideoDriver )
+		xine_close_video_driver ( (xine_t*)m_pMediaEngine, m_pVideoDriver );
+	m_pVideoDriver = NULL;
+	if ( m_bOwnXineEngine )
+		xine_exit ( (xine_t*)m_pMediaEngine );
+	m_pMediaEngine = NULL;
 }
+
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
