@@ -24,7 +24,7 @@ public:
 	XineInfo (void *p=NULL);
 	virtual ~XineInfo ();
 
-	virtual QImage getScreenshot(uint);
+	virtual QImage getScreenshot ( long );
 
 protected:
 	// Mandatory function queryValues ()
@@ -41,6 +41,9 @@ private:
 	void   yuy2Toyv12 (uint8_t *, uint8_t *, uint8_t *, uint8_t *, int, int);
 	uchar *yv12ToRgb (uint8_t *, uint8_t *, uint8_t *, int, int);
 	char  *get_fourcc_string (int);
+	static void frameOutputCb ( void *pUserData, int  iVideoWidth, int iVideoHeight, double fVideoAspect, 
+				    int  *piDestX,   int *piDestY, int *piDestWidth, int *piDestHeight, double *pfDestAspect, 
+				    int  *piWinX,    int *piWinY );
 
 	void createXineStream ();
 
