@@ -86,7 +86,7 @@ QString MediaCreator::getEngineDescription (QString qsEngineName)
 		"I will try to keep this version in synch with the lates version from kaffeine.");
 	else if (qsEngineName == QString ("VLCWidget"))
 		qsEngineInfo = QString ("From the Videolan - project.\n"
-		"This widget is using the videolan media engine.\n"
+		"This widget is using the vidnewThumbnailRequesteolan media engine.\n"
 		"It is also the least tested media engine in 'Q' DVD-Author.");
 	else 
 		qsEngineInfo = QString ("Engine <%1> unknown.").arg (qsEngineName);
