@@ -142,8 +142,16 @@ void MediaScanner::remove ( QObject *pObject )
 
 bool MediaScanner::setSemaphore ( bool bSet )
 {
-  if ( bSet )
-    m_pMutex->lock   ( );
+  if ( bSet )  {
+    int iCount = 1000;
+    while ( iCount-- > 0 )  {
+      if  ( m_pMutex->tryLock ( ) )
+        return true;
+      usleep ( 1000 ); 
+    }
+    return false;
+//    m_pMutex->lock   ( );
+  }
   else
     m_pMutex->unlock ( );
   return true;
