@@ -42,53 +42,64 @@ StartStopControl::~StartStopControl ()
 	m_listOfScreenshots.clear ();
 }
 
-void StartStopControl::initMe (QString qsFileName, int iThumbnailSize, int iLengthMilliSeconds)
+void StartStopControl::initMe ( QString qsFileName, int iThumbnailSize, int iLengthMilliSeconds )
 {
-	QGridLayout *pLayout = new QGridLayout( m_pLabelStartStop, 1, 1, 2, 2, "pLayout2");
-	m_pStartStopSlider = new StartStopSlider ( m_pLabelStartStop );
-	m_pStartStopSlider->setMinMax (0, 1000);
-	connect (m_pStartStopSlider, SIGNAL (signalValuesChanged  ( int, int) ), this, SLOT(slotSliderValues ( int, int ) ) );
-	connect (m_pStartStopSlider, SIGNAL (signalStartStopPressed  ( bool ) ), this, SLOT(slotSliderPressed    ( bool ) ) );
-	connect (m_pStartStopSlider, SIGNAL (signalStartStopReleased ( bool ) ), this, SLOT(slotSliderReleased   ( bool ) ) );
-	pLayout->addWidget( m_pStartStopSlider, 0, 0 );
-	m_pLabelMovie->setFixedHeight (iThumbnailSize);
+  initMe  (  qsFileName,  iThumbnailSize );
+  createThumbnails ( iLengthMilliSeconds );
+}
 
-	if (iThumbnailSize > 1)
-		m_iThumbnailSize = iThumbnailSize;
-	m_qsFileName = qsFileName;
+void StartStopControl::initMe ( QString qsFileName, int iThumbnailSize )
+{
+  QGridLayout *pLayout = new QGridLayout     ( m_pLabelStartStop, 1, 1, 2, 2, "pLayout2");
+  m_pStartStopSlider   = new StartStopSlider ( m_pLabelStartStop );
+  m_pStartStopSlider->setMinMax (0, 1000);
+  connect (m_pStartStopSlider, SIGNAL (signalValuesChanged  ( int, int) ), this, SLOT(slotSliderValues ( int, int ) ) );
+  connect (m_pStartStopSlider, SIGNAL (signalStartStopPressed  ( bool ) ), this, SLOT(slotSliderPressed    ( bool ) ) );
+  connect (m_pStartStopSlider, SIGNAL (signalStartStopReleased ( bool ) ), this, SLOT(slotSliderReleased   ( bool ) ) );
+  pLayout->addWidget ( m_pStartStopSlider, 0,  0 );
+  m_pLabelMovie->setFixedHeight ( iThumbnailSize );
+  
+  if (iThumbnailSize > 1)
+    m_iThumbnailSize = iThumbnailSize;
+  m_qsFileName = qsFileName;
+  
+  // Next we calculate the number of Thumbnaisl we need ...
+  
+  // The available width - 2 times the size of the Handle
+  int t;
+  int iAvailableWidth = width() - 2*12;
+  int iNrOfImages = (int)((iAvailableWidth) / iThumbnailSize);
+  // But we want to ensure to have at least 2 pixels space in between two images
+  iAvailableWidth -= 2*iNrOfImages;
+  // since this can affect the nrOfImages, we ought to recalculate ...
+  iNrOfImages = (int)((iAvailableWidth) / iThumbnailSize);
+  
+  // Next we are going to create some temp pixmaps as a placeholder until
+  // the screenshots arrive.
+  
+  QImage backgroundImage = QImage (QImage::fromMimeSource ( "please_wait.jpg" ));
+  backgroundImage = backgroundImage.smoothScale (m_iThumbnailSize, m_iThumbnailSize);
+  for ( t=0; t<iNrOfImages; t++ )
+    m_listOfScreenshots.append (new QImage (backgroundImage));
+  
+  // Next we draw the line with the temp pictures, 
+  updateMovieLine ( );
+}
 
-	// Next we calculate the number of Thumbnaisl we need ...
-	
-	// The available width - 2 times the size of the Handle
-	int t;
-	int iAvailableWidth = width() - 2*12;
-	int iNrOfImages = (int)((iAvailableWidth) / iThumbnailSize);
-	// But we want to ensure to have at least 2 pixels space in between two images
-	iAvailableWidth -= 2*iNrOfImages;
-	// since this can affect the nrOfImages, we ought to recalculate ...
-	iNrOfImages = (int)((iAvailableWidth) / iThumbnailSize);
-
-	// Next we are going to create some temp pixmaps as a placeholder until
-	// the screenshots arrive.
-	
-	QImage backgroundImage = QImage (QImage::fromMimeSource ( "please_wait.jpg" ));
-	backgroundImage = backgroundImage.smoothScale (m_iThumbnailSize, m_iThumbnailSize);
-	for (t=0;t<iNrOfImages;t++)
-		m_listOfScreenshots.append (new QImage (backgroundImage));
-
-	// Next we draw the line with the temp pictures, 
-	updateMovieLine ();
-	// before we go ahead and request the screenshots.
-	long iDeltaSeconds = 0;
-	if (iNrOfImages  != 1)	// catch possible exception
-		iDeltaSeconds = (long) ( iLengthMilliSeconds / (iNrOfImages) );
-	for (t=0;t<iNrOfImages;t++)
-	  MediaCreator::registerWithMediaScanner (this, m_qsFileName, m_listOfScreenshots[t], iDeltaSeconds * t);
+void StartStopControl::createThumbnails ( int iLengthMilliSeconds )
+{
+  // before we go ahead and request the screenshots.
+  long iDeltaSeconds = 0;
+  int  iNrOfImages   = m_listOfScreenshots.count ( );
+  if ( iNrOfImages  != 1 )	// catch possible exception
+    iDeltaSeconds = (long) ( iLengthMilliSeconds / (iNrOfImages) );
+  for ( int t=0; t<iNrOfImages; t++ )
+    MediaCreator::registerWithMediaScanner ( this, m_qsFileName, m_listOfScreenshots[t], iDeltaSeconds * t );
 }
 
 void StartStopControl::showSlider (bool bShow)
 {
-	m_pLabelStartStop->setShown (bShow);
+  m_pLabelStartStop->setShown (bShow);
 }
 
 void StartStopControl::setProgress (float fProgress)
@@ -174,7 +185,7 @@ void StartStopControl::timerEvent (QTimerEvent *pTimerEvent)
 	// Because of threading issues we ought to use the timer here and not a 
 	// simple function call from the background task.
 	int t;
-	if (pTimerEvent->timerId () == MEDIASCANNER_EVENT)	{
+	if (pTimerEvent->timerId () == MEDIASCANNER_EVENT + 2)	{ // ExecuteJob::TYPE_IMAGE
 		for (t=0;t<(int)m_listOfScreenshots.count();t++)	{
 			if (m_listOfScreenshots[t]->width() > m_iThumbnailSize)
 				*m_listOfScreenshots[t] = m_listOfScreenshots[t]->smoothScale (m_iThumbnailSize, m_iThumbnailSize, QImage::ScaleMin);
