@@ -120,18 +120,18 @@ void DialogCreate::slotGenerate ()
 	m_pMainDialog->hide();	// bug in Qt. When main dialog is hidden it will close the whole application when pressing OK of a QMessageBox.
 	m_Slideshow.slideshow_name = m_pEditSlideshowTitle->text();
 //	verifySlideshowExists ( );
-	emit (signalSetSlideshowEntry(m_Slideshow.slideshow_name));
+	emit ( signalSetSlideshowEntry ( m_Slideshow.slideshow_name ) );
 	// change the tab to show log / progress.
-	m_pTabWidget->setCurrentPage (1);
-	preprocessSlideshow();
-	createDVDSlideshowFile();
-	m_pEditTotalNumber->setText (QString("%1").arg(m_Slideshow.count()+2));
-	m_pEditImageNumber->setText ("0");
-	fileInfo.setFile(m_Slideshow.getImg(0)->src);
-	m_pEditCurrentFileName->setText(fileInfo.fileName());
-	m_pButtonGenerate->setEnabled(false);
+	m_pTabWidget->setCurrentPage ( 1 );
+	preprocessSlideshow    ( );
+	createDVDSlideshowFile ( );
+	m_pEditTotalNumber->setText ( QString("%1").arg ( (int)( ( m_Slideshow.count ( ) / 2.0 ) + 3.5 ) ) );
+	m_pEditImageNumber->setText ( "0" );
+	fileInfo.setFile ( m_Slideshow.getImg ( 0 )->src );
+	m_pEditCurrentFileName->setText ( fileInfo.fileName ( ) );
+	m_pButtonGenerate->setEnabled   ( false );
 	// and finally we execute dvd-slideshow.
-	executeDVDSlideshow();
+	executeDVDSlideshow ( );
 }
 
 bool DialogCreate::sanityCheck()
@@ -248,7 +248,7 @@ void DialogCreate::findDVDSlideshow()
 	m_pEditExecutableDir->setText(QString("not found"));
 }
 
-// How to get CXmlSlideshow - structure ...
+// How to get a CXmlSlideshow - structure ...
 void DialogCreate::preprocessSlideshow()
 {
   uint t, iImgCount, iCount, iPreprocessingImgCount = 0;
@@ -357,8 +357,10 @@ void DialogCreate::createDVDSlideshowFile()
 	CXmlSlideshow::time_object *pTimeObject;
 	CXmlSlideshow::img_struct *pImg;
 	CXmlSlideshow::filter_struct *pFilter;
-//	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/slideshow.in");
-	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/") + m_pEditSlideshowTitle->text() + QString (".in");
+	QString qsTitle = m_pEditSlideshowTitle->text ( );
+	if ( qsTitle.length ( ) < 1 )
+		qsTitle = "slideshow";
+	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/") + qsTitle + QString (".in");
 	QFile theFile (qsSlideshowFile);
 	if ( ! theFile.open (IO_WriteOnly) )
 	  return;
@@ -366,7 +368,8 @@ void DialogCreate::createDVDSlideshowFile()
 	int iDelay = m_Slideshow.delay;
 	int iFilterDelay = m_Slideshow.filter_delay;
 	// Here we create the title ...
-	theStream << "title:" << iTitleDelay << ":" << m_pEditSlideshowTitle->text() << "\n";
+	if ( m_pEditSlideshowTitle->text ( ).length ( ) > 0 )
+		theStream << "title:" << iTitleDelay << ":" << m_pEditSlideshowTitle->text() << "\n";
 	for (t=0;t<m_Slideshow.count();t++)	{
 		pTimeObject = m_Slideshow.getTimeObject(t);
 		if (pTimeObject->node_name == "img")	{
@@ -398,7 +401,7 @@ fadeout:3
 void DialogCreate::executeDVDSlideshow()
 {
 	m_pTextStatus->setText (tr("Processing images"));
-	// Here we create a new thread to handle the generation in the background.
+	// Here we create a new thread to handle them_pEditSlideshowTitle generation in the background.
 	// This Thread shoud be completely independand of the parent thread.
 	QString qsDVDSlideshow = m_pEditExecutableDir->text();
 	// add the name of the executable only if needed.
@@ -407,7 +410,7 @@ void DialogCreate::executeDVDSlideshow()
 	QString qsCommand;
 
 	QStringList listArgs;
-	listArgs.append(qsDVDSlideshow);	        // the executable itself
+	listArgs.append ( qsDVDSlideshow );	        // the executable itself
 
 	if (m_pComboFormat->currentItem() == 0)         // Generate PAL ???
 		listArgs.append(QString ("-p"));
@@ -417,31 +420,35 @@ void DialogCreate::executeDVDSlideshow()
 	listArgs.append(m_pEditOutputFileName->text()); // The output FileName
 	listArgs.append(QString ("-f"));
 	// the generated inputFileName
-	listArgs.append(QString ("%1/%2.in").arg(m_pEditTempDir->text()).arg(m_pEditSlideshowTitle->text()));
+	QString qsTitle = m_pEditSlideshowTitle->text ( );
+	if ( qsTitle.length ( ) < 1 )
+		qsTitle = "slideshow";
+	QString qsSlideshowFile = m_pEditTempDir->text() + QString ("/") + qsTitle + QString (".in");
+
+	listArgs.append ( qsSlideshowFile );
 	if (m_Slideshow.audio_list.count() > 0)	{
 		for (uint t=0;t<m_Slideshow.audio_list.count();t++)	{
 			listArgs.append(QString ("-a"));
 			listArgs.append(m_Slideshow.audio_list[t]);
 		}
 	}
-	if (!m_Slideshow.background .isNull())	{
-		listArgs.append(QString ("-b"));
-		listArgs.append(m_Slideshow.background);	// the background image (if any)
+	if ( ! m_Slideshow.background.isEmpty  ( ) )	{
+		listArgs.append ( QString ( "-b" ) );
+		listArgs.append ( m_Slideshow.background );	// the background image (if any)
 	}
-	if (m_Slideshow.delay > 0)	{
-		listArgs.append(QString ("-t"));
-		listArgs.append(QString("%1").arg(m_Slideshow.delay));
+	if ( m_Slideshow.delay > 0 )  {
+		listArgs.append ( QString ( "-t" ) );
+		listArgs.append ( QString ( "%1" ).arg ( m_Slideshow.delay ) );
 	}
 
 	m_pNewProcess  = new QProcess ( this );
-	connect( m_pNewProcess, SIGNAL(readyReadStdout()), this, SLOT(slotReadFromStdout()) );
-	connect( m_pNewProcess, SIGNAL(readyReadStderr()), this, SLOT(slotReadFromStderr()) );
-	connect( m_pNewProcess, SIGNAL(processExited()), this, SLOT(slotProcessExited()) );
+	connect( m_pNewProcess, SIGNAL( readyReadStdout ( ) ), this, SLOT ( slotReadFromStdout ( ) ) );
+	connect( m_pNewProcess, SIGNAL( readyReadStderr ( ) ), this, SLOT ( slotReadFromStderr ( ) ) );
+	connect( m_pNewProcess, SIGNAL( processExited   ( ) ), this, SLOT ( slotProcessExited  ( ) ) );
 
-	m_pNewProcess->setArguments (listArgs);
-	m_pNewProcess->start ();
-
-//printf ("Command<%s>\n", (const char *)qsCommand);
+	m_pNewProcess->setArguments ( listArgs );
+	m_pNewProcess->start ( );
+//printf ("Command<%s>\n", listArgs.join ( " " ).ascii ( ) );
 }
 /* dvd-slideshow - output
 [dvd-slideshow]########################################
@@ -468,10 +475,10 @@ void DialogCreate::slotReadFromStdout()
 	m_pTextOutput->append( qsText );
 	if (bFoundSeparator)	{
 		// Here we search for the right information int the stdOut
-		QStringList listLines = QStringList::split (QString ("\n"), stdOut);
+		QStringList listLines    = QStringList::split ( QString ("\n"), stdOut );
 		// Okay do the computing ...
-		QStringList listParts = QStringList::split (QString (" "), listLines[0]);
-		QStringList listNumbers = QStringList::split (QString ("/"), listParts[1]);
+		QStringList listParts    = QStringList::split ( QString (" "), listLines[0] );
+		QStringList listNumbers  = QStringList::split ( QString ("/"), listParts[1] );
 		if (listNumbers.count() == 1)	{	// this is at the end like "[dvd-slideshow] Joining each mpeg..."
 			m_pEditCurrentFileName->setText(listLines[0].right (listLines[0].length() - 16));
 		}
@@ -479,7 +486,8 @@ void DialogCreate::slotReadFromStdout()
 			fileInfo.setFile (listParts[2]);
 			m_pEditCurrentFileName->setText(fileInfo.fileName());
 		}
-		m_pProgress->setProgress ((int)((float)(m_iProgressCounter++ +1)/(m_Slideshow.count()+2) * 100.0));
+		int iProgress = (int)((float)(m_iProgressCounter++ +1)/((m_Slideshow.count ( )/2.0) + 2 ) * 100.0);
+		m_pProgress->setProgress ( iProgress );
 		m_pEditImageNumber->setText(QString ("%1").arg(m_iProgressCounter));
 		//m_pEditImageNumber->setText(QString ("%1").arg(listNumbers[0].toInt()+1));
 		// finally we unmark the separator ...
@@ -515,11 +523,11 @@ void DialogCreate::slotProcessExited()
     emit (signalSlideshowDone(m_Slideshow.slideshow_name, qsOutputFile));
 }
 
-void DialogCreate::slotBack()
+void DialogCreate::slotBack ( )
 {
-  m_pButtonGenerate->setEnabled(true);
-  m_pMainDialog->show();
-  reject ();	// This will only close this dialog and open the main dialog.
+  m_pButtonGenerate->setEnabled ( true );
+  m_pMainDialog->show ( );
+  reject ( );	// This will only close this dialog and open the main dialog.
  		// accept() would close the whole SlideshowDialog.
 }
 
