@@ -165,7 +165,7 @@ void CSlideDialog::slotImport()
 	// And here we add the imported images to the current image list.
 	m_slideshowFiles.clear ();
 	m_pListTable->clear ();
-	if (importedSlideshow.ppArrayImg)	{
+	if (importedSlideshow.countImg () > 0 )	{
 		for (uint t=0;t<importedSlideshow.count();t++)	{
 			pObject = importedSlideshow.getTimeObject (t);
 			if (pObject->node_name == "img")	{
