@@ -462,7 +462,9 @@ QApplication::postEvent (this, new QCustomEvent(QEvent::User+2));
 	m_bCreatingThumbnails = false;
 }
 #include <qtimer.h>
+#ifdef QDVD_LINUX 
 #include <unistd.h>	// neede for sleep() only.
+#endif
 // The following two functions will refresh the pixmap in the main thread (ImageLine object)
 void ImageLine::refreshPixmap()
 {
