@@ -22,7 +22,11 @@
 
 #include "imagepreview.h"
 #include "dialogimage.h"
+#ifdef QDVD_SLIDESHOW
 #include "modifiers2.h"
+#else
+#include "../modifiers.h"
+#endif
 
 ImagePreview::ImagePreview (QWidget *pParent, const char * name, WFlags f )
 	: QLabel (pParent, name, f) // |WRepaintNoErase)
