@@ -30,7 +30,9 @@
 
 #include <math.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <arpa/inet.h>
+#include <unistd.h>
 #include <sys/stat.h>
 
 #include <qdir.h>
@@ -56,7 +58,7 @@
 #ifdef debug_out
 #undef debug_out
 #endif
-#if 1
+#if 1 
 static void dummy(const char*,...){};
 #define debug_out dummy
 #define sdebug_out dummy
@@ -328,6 +330,8 @@ QStringList &Manager::getFilterNames ( )
   qsTempFile = Global::qsTempPath  +  "/filterList.txt";
   qsCommand += QString ( " -f >%1" ).arg   ( qsTempFile );
   int iRet   = system  ( qsCommand.ascii ( ) );
+
+  //printf ( "%s\n", qsCommand.ascii ( ) );
   iRet = iRet; // quiet down the compiler.
   chmod ( qsTempFile.utf8 ( ), S_IRUSR | S_IWUSR | S_IWRITE | S_IROTH | S_IWOTH | S_IWGRP | S_IRGRP );
 
@@ -697,13 +701,21 @@ printf ( "bRemoteServer<%d> IP=<0x%016X> = <%s>\n", m_bRemoteServer, p->getIP (
         }
       }
       else  {
-        startServer ( );
-        pServerInfo->setRecovery ( true );
-        // run ( );
-        //start ( );
-        QDataStream stream  ( m_pSocket );
-        stream << (Q_UINT16)CLIENT_GO_TO_WORK << (Q_UINT64)0LL;
-        m_pSocket->flush ( );
+        if ( m_pSocket->isOpen ( ) && m_qsTempXMLFile.length ( ) > 0 )  {
+          QDataStream stream  ( m_pSocket );
+          stream << (Q_UINT16)CLIENT_I_LOST_CONTACT << (Q_UINT64)m_qsTempXMLFile.length ( );
+          stream << m_qsTempXMLFile;
+          m_pSocket->flush ( );
+        }
+        else  {
+          startServer ( );
+          pServerInfo->setRecovery ( true );
+          // run ( );
+          //start ( );
+          QDataStream stream  ( m_pSocket );
+          stream << (Q_UINT16)CLIENT_GO_TO_WORK << (Q_UINT64)0LL;
+          m_pSocket->flush ( );
+        }
       }
     }
     else
@@ -816,6 +828,8 @@ void Client::receivedServerDone ( )
 
 void Client::killServerThread ( )
 {
+  if ( ! m_pSocket->isOpen ( ) )
+    slotReconnect ( );
   QDataStream stream ( m_pSocket );
   stream << (Q_UINT16)CLIENT_KILL_YOURSELF << (Q_UINT64)0LL;
   m_pSocket->flush ( );
@@ -871,11 +885,26 @@ void Client::sendNextPacket ( )
   }
 }
 
+bool Client::checkSocket ( )
+{
+  if ( ! m_pSocket )
+    return false;
+
+  if ( ! m_pSocket->isOpen ( ) )
+    return false;
+  if ( m_pSocket->state ( ) != QSocket::Connected )
+    return false;
+
+  return true;
+}
+
 bool Client::sendVersionAndHostRequest ( )
 {
   char cHostName[1024];
   gethostname ( (char *)&cHostName, 1024 );
   QString  qsHostName  ( cHostName       );
+  if ( ! checkSocket ( ) )
+    return false;
 
   QDataStream stream ( m_pSocket );
   stream << (Q_UINT16)CLIENT_WHO_AND_WHERE_ARE_YOU << (Q_UINT64)qsHostName.length ( );
@@ -1125,7 +1154,12 @@ void Client::runSlideshow ( CXmlSlideshow *pSlideshow )
     qsFileName = theUtils.getTempFile ( qsFileName + ".xml" );
 
   pSlideshow->writeXml ( qsFileName );
+  m_qsTempXMLFile = qsFileName;
 
+  if ( ! m_pSocket )  {
+    setWaiting ( false );
+    return;
+  }
   QDataStream stream   (  m_pSocket );
 
   if ( m_bRemoteServer )  {
@@ -1160,13 +1194,16 @@ void Client::runSlideshow ( CXmlSlideshow *pSlideshow )
       qsTempPath += m_pButtonTransition->qsName + "/";
     stream << (Q_UINT16)CLIENT_TAKE_THAT_XML << (Q_UINT64)( qsFileName.length ( ) + qsTempPath.length ( ) );
     stream << qsFileName << qsTempPath;
-    m_pSocket->flush ( );
+    if ( m_pSocket ) 
+         m_pSocket->flush ( );
     usleep ( 1000000 );
   }
   stream << (Q_UINT16)CLIENT_GO_TO_WORK << (Q_UINT64)0LL;
 
   debug_out ( "Get the server to work ... msgID<0x%04X>\n",  CLIENT_GO_TO_WORK );
-  m_pSocket->flush ( );
+  if ( m_pSocket )
+       m_pSocket->flush ( );
+
   setWaiting ( false );
 }
 
