@@ -25,7 +25,7 @@ public:
   // Public functions needed for the abstract base class.
   SelectionObject         ( QWidget *pParent=0 );
   virtual ~SelectionObject                   ( );
-  
+
   void resetObjectStates                     ( );
   bool find                   ( MenuObject   * );
   bool mouseOver             ( const QPoint  & );
@@ -39,6 +39,8 @@ public:
   virtual void drawSelected     ( QPainter   * );
   virtual void setShadow        ( MenuObject * );
   virtual MenuObject* shadow    (              );
+  virtual void setRect          ( QRect &      );
+  virtual QRect &rect           ( );
 
   void clearShadows   ( );
   void drawShadows    ( QPainter * );
@@ -54,7 +56,6 @@ protected slots:
 
 private:
   QValueList<ShadowObject *> m_listOfShadows;
-
 };
 
 #endif	// SELECTIONOBJECT_H
