@@ -122,8 +122,10 @@ SourceToolBar::~SourceToolBar ()
   m_listSourceFileEntries.clear ( );
   if ( m_pMediaInfo )
     delete m_pMediaInfo;
+  m_pMediaInfo = NULL;
   if ( m_pThumbnailDialog )
     delete m_pThumbnailDialog;
+  m_pThumbnailDialog = NULL;
 }
 
 QListView *SourceToolBar::getStructureListView ( )
@@ -345,6 +347,7 @@ void SourceToolBar::slotRightClickedOnVideoList ( QListViewItem *pItem, const QP
 
       if ( pInfo->pSlideshow )  { // If the movie was created through a slideshow ...
         pMenu->insertItem ( tr ( "&Slideshow" ),          this, SLOT ( slotEditSlideshow  ( ) ) );
+        pMenu->insertItem ( tr ( "&Images ..." ),         this, SLOT ( slotImagesDialog   ( ) ) );
         pMenu->insertItem ( tr ( "&Re-Render" ),          this, SLOT ( slotRerenderSlide  ( ) ) );
       }
       pMenu->insertItem   ( tr ( "P&roperties ..." ),     this, SLOT ( slotEditMovie      ( ) ) );
@@ -388,6 +391,7 @@ void SourceToolBar::createContextMenu ( SourceFileEntry *pEntry, QPoint &pos )
       pMenu->insertItem ( tr ( "&Play" ),                  this, SLOT ( slotPlayMovie      ( ) ) );
     if ( pInfo && pInfo->pSlideshow )   {// If the movie was created through a slideshow ...
       pMenu->insertItem ( tr ( "&Slideshow" ),             this, SLOT ( slotEditSlideshow  ( ) ) );
+      pMenu->insertItem ( tr ( "&Images ..." ),            this, SLOT ( slotImagesDialog   ( ) ) );
       pMenu->insertItem ( tr ( "&Re-Render" ),             this, SLOT ( slotRerenderSlide  ( ) ) );
     }
     pMenu->insertItem   ( tr ( "P&roperties ..." ),        this, SLOT ( slotEditMovie      ( ) ) );
@@ -929,12 +933,12 @@ void SourceToolBar::updateEntryHeader ( SourceFileEntry *pEntry )
 {
   uint t, i;
   QString qsFormat ("--");
-  SourceFileInfo *pInfo;
+//  SourceFileInfo *pInfo;
   QListViewItem  *pItem;
   // Oh and the ListViewVideoSources should also be updated ...
   for (t=0;t<pEntry->listFileInfos.count();t++)	{
     // Okay found the SourceFileInfo now we need the ListViewItemMedia - object for this Info.
-    pInfo = pEntry->listFileInfos[t];
+//    pInfo = pEntry->listFileInfos[t];
     pItem = m_pListViewAllSources->firstChild ();
     while ( pItem )	{
       if  ( pItem->text ( 1 ) == pEntry->qsDisplayName ) {
@@ -1360,12 +1364,12 @@ SourceFileEntry *SourceToolBar::entryFromSlideshow ( CXmlSlideshow *pXmlSlidesho
   QString qsFileName;
   Utils   theUtils;
   CXmlSlideshow::vid_struct *pXmlVid;
-  CXmlSlideshow::img_struct *pXmlImage;
+//  CXmlSlideshow::img_struct *pXmlImage;
   SourceFileEntry *pEntry;
   SourceFileInfo  *pInfo;
   unsigned int t, iLength = 0;
 
-  pXmlImage = pXmlSlideshow->getImg ( 0 );
+//  pXmlImage = pXmlSlideshow->getImg ( 0 );
 
   pEntry = new SourceFileEntry;
   pEntry->qsDisplayName.sprintf ( "[%02d] - %s", getFreeSourceSlot ( ), pXmlSlideshow->slideshow_name.ascii ( ) );
@@ -1473,7 +1477,7 @@ void SourceToolBar::editSourceFileInfo ( SourceFileInfo  *pSourceFileInfo )
 
 void SourceToolBar::slotRerenderSlide ( )
 {
-  SourceFileInfo  *pInfo  = getCurrentSourceFileInfo ( );
+  SourceFileInfo  *pInfo  = getCurrentSourceFileInfo  ( );
   SourceFileEntry *pEntry = getCurrentSourceFileEntry ( );
   // Re-render the slideshow if different
   if ( pEntry && pInfo )  {
@@ -1483,6 +1487,64 @@ void SourceToolBar::slotRerenderSlide ( )
   }
 }
 
+void SourceToolBar::slotImagesDialog ( )
+{
+  Utils theUtil;
+  SourceFileEntry *pEntry     = NULL;
+  SourceFileInfo  *pInfo      = getCurrentSourceFileInfo ( );
+  CXmlSlideshow   *pSlideshow = pInfo->pSlideshow;
+  if ( ! pSlideshow )
+    return;
+
+  pEntry = sourceFileEntry ( pSlideshow );
+  if ( ! pEntry )  {
+    pEntry = getCurrentSourceFileEntry ( ); 
+    pSlideshow->id = (void *)pEntry;
+  }
+
+  // First we pop up the slideshow generation dialog box
+  Input::DialogImages fileDialog ( this );
+  fileDialog.initMe    ( pEntry );
+  if ( fileDialog.exec ( ) == QDialog::Rejected )
+    return;
+
+  CXmlSlideshow   *pXmlSlideshow;
+  QValueList<CXmlSlideshow *>  newList = fileDialog.getSlideshows ( );
+
+  if ( newList.size ( ) != 1 )  {
+    MessageBox::warning ( NULL, tr ("Warning."),
+                                tr ("There was an internal error.\n\n Aborting.\n"),
+                                QMessageBox::Ok, QMessageBox::NoButton );
+    return;
+  }
+
+  pXmlSlideshow = newList[0];
+  if ( pXmlSlideshow->count ( ) < 1 )  {
+    // No more images in the slideshow
+    removeEntry ( pEntry, false );
+    delete pEntry;
+    return;
+  }
+
+  // Re-render the slideshow if different
+  if ( pEntry && pInfo )  {
+    CXmlSlideshow *pSlideshow = pInfo->pSlideshow;
+    if ( ! ( *pSlideshow == *pXmlSlideshow ) )  {
+       Render::Manager::unregisterEntry ( pEntry );
+
+       // In case the Slideshow name has changed. We need to also change the file name.
+       QString qsFileName = pXmlSlideshow->slideshow_name;
+       qsFileName.replace ( "/", "_" );
+       pInfo->qsFileName    = theUtil.getTempFile ( qsFileName + ".vob" );
+       pEntry->bIsSlideshow = true;
+
+      *pSlideshow = *pXmlSlideshow;
+       updateSlideshowItem ( pEntry );
+       Render::Manager::registerEntry ( pEntry );
+    }
+  }
+}
+
 void SourceToolBar::slotEditSlideshow ( )
 {
   SourceFileInfo *pInfo      = getCurrentSourceFileInfo ( );
@@ -1494,6 +1556,7 @@ void SourceToolBar::slotEditSlideshow ( )
 
   if ( theDialog.exec ( ) ==  QDialog::Accepted ) {
     bool bChecked   = pSlideshow->imgBkgImg   ( );
+    bool bKenBurns  = pSlideshow->kenBurns    ( );
     int iFormat     = theDialog.m_pComboFormat->currentItem ( );
     int iFourByThree= ( ( iFormat == 0 )  || ( iFormat == 1 ) ) ? 0 : 1;
     bool bPal       = ( ( iFormat == 1 )  || ( iFormat == 3 ) );
@@ -1506,6 +1569,7 @@ void SourceToolBar::slotEditSlideshow ( )
                         ( pSlideshow->filter_delay     == theDialog.m_pSpinFilterDelay->value    ( ) ) &&
                         ( pSlideshow->intro_page       == theDialog.m_pCheckIntroPage->isChecked ( ) ) &&
                         ( bChecked                     == theDialog.m_pRadioImgBkgImg->isChecked ( ) ) &&
+                        ( bKenBurns                    == theDialog.m_pCheckKenBurns ->isChecked ( ) ) &&
                         ( bPal  == ( theUtils.getFormat ( pSlideshow->xres, pSlideshow->yres ) > FORMAT_NTSC4 ) ) );
     pSlideshow->slideshow_name   = theDialog.m_pEditName->text  ( );
     pSlideshow->background       = theDialog.background ( );
@@ -1515,6 +1579,7 @@ void SourceToolBar::slotEditSlideshow ( )
     pSlideshow->filter_delay     = theDialog.m_pSpinFilterDelay->value    ( );
     pSlideshow->intro_page       = theDialog.m_pCheckIntroPage->isChecked ( );
     pSlideshow->setImgBkgImg     ( theDialog.m_pRadioImgBkgImg->isChecked ( ) );
+    pSlideshow->setKenBurns      ( theDialog.m_pCheckKenBurns ->isChecked ( ) );
     pSlideshow->xres             = 720;
     pSlideshow->yres             = bPal ? 576 : 480;
     pSlideshow->aspect           = iFourByThree;
