@@ -38,54 +38,33 @@ void StructureItem::initMe ( enType type )
 StructureItem *StructureItem::setSibling ( MenuObject *pMenuObject, StructureItem *pItem, QString qsName, QString qsArgs )
 {
   StructureItem *pSibling = NULL;
-  int a=0, b=0;
 
-  if ( pItem ) {
-    a = 1;
+  if ( pItem )
     pSibling = (StructureItem *)pItem->nextSibling ( );
-  }
-  else {
-    a = 2;
+  else
     pSibling = (StructureItem *)firstChild ( );
-  }
 
-  if ( ! pSibling ) {
+  if ( ! pSibling )
     pSibling = new StructureItem ( pMenuObject, StructureItem::Unknown, this, pItem, qsName, qsArgs );
-    b = 1;
-  }
-  else {
+  else
     pSibling->setText ( qsName, qsArgs );
-    b = 2;
-  }
 
-  //  printf ( "  StructureItem::setSibling <%p> == a=<%d> b=<%d>  <%s><%s>\n", this, a, b, qsName.ascii(), qsArgs.ascii() );
   return pSibling;
 }
 
 StructureItem *StructureItem::setSibling ( DVDMenu *pDVDMenu, StructureItem *pItem, QString qsName, QString qsArgs )
 {
   StructureItem *pSibling = NULL;
-  int a=0, b=0;
 
-  if ( pItem ) {
-    a = 1;
+  if ( pItem )
     pSibling = (StructureItem *)pItem->nextSibling ( );
-  }
-  else {
-    a = 2;
+  else
     pSibling = (StructureItem *)firstChild ( );
-  }
 
-  if ( ! pSibling ) {
+  if ( ! pSibling )
     pSibling = new StructureItem ( pDVDMenu, StructureItem::Unknown, this, pItem, qsName, qsArgs );
-    b = 1;
-  }
-  else {
+  else
     pSibling->setText ( qsName, qsArgs );
-    b = 2;
-  }
-
-  //  printf ( "  StructureItem::setSibling <%p> == a=<%d> b=<%d>  <%s><%s>\n", this, a, b, qsName.ascii(), qsArgs.ascii() );
 
   return pSibling;
 }
@@ -93,27 +72,17 @@ StructureItem *StructureItem::setSibling ( DVDMenu *pDVDMenu, StructureItem *pIt
 StructureItem *StructureItem::setSibling ( MenuPreview *pMenuPreview, StructureItem *pItem, QString qsName, QString qsArgs )
 {
   StructureItem *pSibling = NULL;
-  int a=0, b=0;
 
-  if ( pItem ) {
-    a = 1;
+  if ( pItem )
     pSibling = (StructureItem *)pItem->nextSibling ( );
-  }
-  else {
-    a = 2;
+  else
     pSibling = (StructureItem *)firstChild ( );
-  }
 
-  if ( ! pSibling ) {
+  if ( ! pSibling )
     pSibling = new StructureItem ( pMenuPreview, StructureItem::Unknown, this, pItem, qsName, qsArgs );
-    b = 1;
-  }
-  else {
+  else
     pSibling->setText ( qsName, qsArgs );
-    b = 2;
-  }
 
-  //  printf ( "  StructureItem::setSibling <%p> == a=<%d> b=<%d>  <%s><%s>\n", this, a, b, qsName.ascii(), qsArgs.ascii() );
   return pSibling;
 }
 
