@@ -10,9 +10,11 @@
 **
 ****************************************************************************/
 
+#include <qdesktopwidget.h>
 #include <qprogressbar.h>
 #include <qapplication.h>
 #include <qdatetime.h>
+#include <qtextedit.h>
 #include <qfileinfo.h>
 #include <qpainter.h>
 #include <qdialog.h>
@@ -37,6 +39,7 @@ SubtitleEntry &SubtitleEntry::operator= ( SubtitleEntry &theOther )
 {
   m_iSubtitleNumber = theOther.m_iSubtitleNumber;
   m_qsIso639        = theOther.m_qsIso639;
+  m_qsFileName      = theOther.m_qsFileName;
   return *this;
 }
 
@@ -58,12 +61,19 @@ Subtitles::entry &Subtitles::entry::operator = ( Subtitles::entry &theOther )
   return *this;
 }
 
-Subtitles::Subtitles ()
+Subtitles::Subtitles (  int iWidth, int iHeight )
 {
+  Utils theUtils;
+  if ( theUtils.getFormat ( iWidth, iHeight ) == FORMAT_NONE )  {
+    iWidth  = 720; // standard NTSC res.
+    iHeight = 480; // standard NTSC res.
+  }
+  m_videoSize = QSize ( iWidth, iHeight );
+
   m_subColors[0]    = Rgba ( TRANSPARENT_COLOR       );
   m_subColors[1]    = Rgba ( START_HIGHLIGHTED_COLOR );
   m_subColors[2]    = Rgba ( START_SELECTED_COLOR    );
-  //m_subColors[3]    = Rgba ( START_FRAME_COLOR       );
+//m_subColors[3]    = Rgba ( START_FRAME_COLOR       );
 
   m_iSubtitleNumber = 0;
   m_bFit            = true;
@@ -73,7 +83,7 @@ Subtitles::Subtitles ()
   m_qsTextFont      = "Vera";
   m_alignment       = QPoint ( 1, 4 ); // HAlign=Center / VAlign=top
   m_subtitleState   = STATE_MANUAL;
-  m_rect            = QRect ( 0, 0, 720, 480 ); // standard NTSC res.
+  m_rect            = QRect ( 0, 0, iWidth, iHeight );
 }
 
 Subtitles::~Subtitles ()
@@ -92,10 +102,12 @@ Subtitles &Subtitles::operator = ( Subtitles &theOther )
   m_bFit            = theOther.m_bFit;
   m_iOutline        = theOther.m_iOutline;
   m_font            = theOther.m_font;
+  m_videoSize       = theOther.m_videoSize;
   m_rect            = theOther.m_rect;
   m_alignment       = theOther.m_alignment;
   m_iSubtitleNumber = theOther.m_iSubtitleNumber;
   m_qsIso639        = theOther.m_qsIso639;
+  m_qsFileName      = theOther.m_qsFileName;
   m_qsXmlFile       = theOther.m_qsXmlFile;
   m_subtitleState   = theOther.m_subtitleState;
 
@@ -131,6 +143,9 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   qsAttribute = theElement.attributeNode ( SUBTITLES_LANG ).value();
   if ( ! qsAttribute.isEmpty ( ) )
     m_qsIso639 = qsAttribute;
+  qsAttribute = theElement.attributeNode ( SUBTITLES_FILE_NAME ).value();
+  if ( ! qsAttribute.isEmpty ( ) )
+    m_qsFileName = qsAttribute;
   qsAttribute = theElement.attributeNode ( SUBTITLES_TEXT_BASED ).value ( );
   if ( ! qsAttribute.isEmpty ( ) )
     m_bTextSubtitles = ( qsAttribute == "true" );
@@ -168,6 +183,15 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
       theRect = QRect(list[0].toInt(), list[1].toInt(),  list[2].toInt(),  list[3].toInt() );
     m_rect = theRect;
   }
+  qsAttribute = theElement.attributeNode ( SUBTITLES_VIDEO_SIZE ).value();
+  if ( ! qsAttribute.isEmpty ( ) ) {
+    // QString "x,y,width,height" 
+    QStringList list = QStringList::split ( ",", qsAttribute );
+    QSize theSize;
+    if ( list.count ( ) == 2)
+      theSize = QSize ( list[0].toInt ( ), list[1].toInt ( ) );
+    m_videoSize = theSize;
+  }
   qsAttribute = theElement.attributeNode ( SUBTITLES_ALIGNMENT ).value();
   if ( ! qsAttribute.isEmpty ( ) ) {
     // QString "x,y,width,height" 
@@ -181,8 +205,8 @@ bool Subtitles::readProjectFile ( QDomNode &xmlNode )
   if ( ! qsAttribute.isEmpty ( ) ) {
     QStringList list = QStringList::split ( ",", qsAttribute );
     if ( list.count() == MAX_SUBTITLE_COLORS ) {
-      for ( t=0;t<MAX_SUBTITLE_COLORS; t++ )  
-	m_subColors[t].fromString ( list[t] ); 
+      for ( t=0;t<MAX_SUBTITLE_COLORS; t++ )
+        m_subColors[t].fromString ( list[t] );
     }
   }
   qsAttribute = theElement.attributeNode ( SUBTITLES_TRANSPARENCY ) .value ();
@@ -245,9 +269,11 @@ bool Subtitles::writeProjectFile ( QDomElement &inElement )
   // Here we set the attributes of the <dvdauthor> tag
   //  theElement.setAttribute( SUBTITLES_TRANSPARENCY,  QString ("%1").arg ( (int)iTransparency   ) );
   theElement.setAttribute( SUBTITLES_NUMBER,        QString ("%1").arg ( (int)m_iSubtitleNumber ) );
-  theElement.setAttribute( SUBTITLES_LANG,          m_qsIso639  );
+  theElement.setAttribute( SUBTITLES_LANG,          m_qsIso639   );
   theElement.setAttribute( SUBTITLES_FONT,          m_font.toString ( ) );
   theElement.setAttribute( SUBTITLES_STATE,         QString ("%1").arg ( (int)m_subtitleState ) );
+  if ( m_qsFileName.length ( ) > 0 )
+    theElement.setAttribute( SUBTITLES_FILE_NAME,   m_qsFileName );
   if ( m_bTextSubtitles ) {
     theElement.setAttribute( SUBTITLES_TEXT_BASED,  QString ("%1").arg ( m_bTextSubtitles ? "true" : "false" ) );
     theElement.setAttribute( SUBTITLES_TEXT_FONT,   m_qsTextFont );
@@ -261,6 +287,7 @@ bool Subtitles::writeProjectFile ( QDomElement &inElement )
     qsColors += QString ( "%1," ).arg ( m_subColors[t].toString ( ) );
   theElement.setAttribute( SUBTITLES_COLORS, qsColors );
   theElement.setAttribute( SUBTITLES_RECT, QString ("%1,%2,%3,%4").arg(m_rect.x ( ) ).arg(m_rect.y ( ) ).arg(m_rect.width ( ) ).arg(m_rect.height ( ) ) );
+  theElement.setAttribute( SUBTITLES_VIDEO_SIZE, QString ("%1,%2").arg ( m_videoSize.width ( ) ).arg ( m_videoSize.height ( ) ) );
   theElement.setAttribute( SUBTITLES_ALIGNMENT, QString ("%1,%2").arg(m_alignment.x ( ) ).arg(m_alignment.y ( ) ) );
 
   // store the temp file name too ...
@@ -382,6 +409,323 @@ bool Subtitles::alreadyRendered ( QString qsBasePath )
   return true; // AFAIK this subtitle has been rendered already
 }
 
+#if 1
+Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString qsFileInfoName, bool bForce )
+{
+  // If we are using Spumux's version to render subtitles, then we won't need to render them here ... right ?
+  if ( m_bTextSubtitles )
+    return NULL;
+
+  // The first check is to see if the subtitles have been rendered already. If so we return this
+  // and ask the user if they should be re-created or not.
+  if ( ! bForce && alreadyRendered ( qsBasePath ) )
+    return this;
+
+  // Here we handle this in just one function as we can call 
+  // qApp->processEvents ( 100 ); // process for 100 ms
+  int       t, j, iTotalCount, iWidth, iHeight;
+  QString   qsThePath, qsFileName, qsStart, qsSubIdx, qsLang;
+  QRgb      theColor, colors[ MAX_SUBTITLE_COLORS ];
+  Utils     theUtils;
+  QImage    theImage;
+  QRect     theRect;
+  QPainter  thePainter;
+  QDialog   progressDialog   ( NULL );
+  QProgressBar *pProgressBar = NULL;
+  QFileInfo fileInfo ( qsFileInfoName );
+  iTotalCount = (int)m_listOfSubtitles.count ( );
+
+  // The following widgets will create the progress dialog on the fly.
+  if ( iTotalCount > 20 ) { // no progress for only a few subtitles.
+    QGridLayout  *pProgressLayout = new QGridLayout  ( &progressDialog );
+    pProgressBar = new QProgressBar ( &progressDialog );
+    pProgressLayout->addWidget( pProgressBar, 0, 0 );
+    progressDialog.resize( QSize(537, 50).expandedTo ( progressDialog.minimumSizeHint ( ) ) );
+    progressDialog.show  ( );
+  }
+  Subtitles::entry *pEntry;
+  qsLang = theUtils.iso639  ( m_qsIso639, false );
+  progressDialog.setCaption ( QObject::tr ( "Creating %1 Subtitles[%2] for %3" ).arg ( qsLang ).arg ( m_iSubtitleNumber ).arg ( fileInfo.fileName ( ) ) );
+
+  qsSubIdx.sprintf ( "/sub%02d_", m_iSubtitleNumber );
+  qsThePath = qsBasePath + qsSubIdx;
+
+  // get the rect of the video ...
+  iWidth  = theUtils.getWHFromResolution ( qsResolution, true  );
+  iHeight = theUtils.getWHFromResolution ( qsResolution, false );
+  if ( iWidth  < 350 )
+       iWidth  = 720;
+  if ( iHeight < 240 )
+       iHeight = 480;
+
+  theRect = m_rect;
+
+  // Now we do some magic with colors ...
+  // we will set the Background Color to be completely GREEN
+  // and we set the foreground color to be completely RED
+  // Then we do the drawing
+  // After the drawing has been done we wll reduce the colors in the palette to MAX_SUBTITLE_COLORS (4)
+  // Lastly we will replace the RED VALUES with the actual requested foreground color.
+  // We will use the GREEN color as the transparency value for the color.
+  // Note: color0 = background / color1 actual foreground / 
+  //       color[2 .. MAX_SUBTITLE_COLORS] = fading foreground to background with delta transparency
+  colors[0] = 0x0000FF00; // background
+  colors[1] = 0x00FF0000; // foreground
+
+  int   iMaxColors = MAX_SUBTITLE_COLORS - 2;
+  float fDelta   = (float)0xFF / (iMaxColors+1);
+  int   iBGRed, iBGGreen, iBGBlue, iRed, iGreen, iBlue, iTransparency;
+  for ( t=0; t<iMaxColors; t++ )  {
+    iGreen  = (int)((t+1) * fDelta);
+    iRed    = 255 - iGreen;
+    colors[t+2] = ( iRed << 16 ) + ( iGreen << 8 );
+  }
+
+  QRect boundingRect;
+  iTotalCount = (int)m_listOfSubtitles.count ();
+  // Processing some Qt events / messages
+  qApp->processEvents ( 100 ); // do some event processing ...
+
+  int    iDiameter = m_iOutline*2 + 1;
+  QImage theBrush;
+  if ( m_iOutline > 0 ) {
+    // First we need to create a brush to follow ...
+    QPixmap  createCircle ( iDiameter, iDiameter ); //, 1 ); // monochrome pixmap
+    QPainter circlePainter;
+    QPen     circlePen  ( colors[1], 1, Qt::SolidLine );
+    circlePainter.begin ( &createCircle ); {
+      createCircle.fill ( colors[0] );
+      circlePainter.setPen   ( circlePen );
+      circlePainter.setBrush ( QBrush ( colors[1] ) );
+      circlePainter.drawEllipse ( 0, 0, iDiameter, iDiameter );
+    } circlePainter.end ( );
+    theBrush = createCircle.convertToImage ( );
+    // Then we reduce the colors to the max avail color space.
+    theUtils.reduceColors ( theBrush, 2, (QRgb *)&colors );
+  }
+
+  iWidth  = m_rect.width  ( );
+  iHeight = m_rect.height ( );
+
+  QTextEdit edit ( NULL );
+  QStyleSheet *pStyleSheet = edit.styleSheet ( ); // modify blockquote stylesheet to remove 40px margins left and right
+  QStyleSheetItem *pStyle = NULL;
+  if ( pStyleSheet )  {
+    pStyle = new QStyleSheetItem ( pStyleSheet, "qdvd" );
+    if ( pStyle )  {
+      pStyle->setDisplayMode ( QStyleSheetItem::DisplayBlock );
+      pStyle->setMargin ( QStyleSheetItem::MarginLeft,  4 + m_iOutline );
+      pStyle->setMargin ( QStyleSheetItem::MarginRight, 4 + m_iOutline );
+      if ( m_alignment.x ( ) == 1 ) // AlignCenter
+        pStyle->setAlignment ( Qt::AlignHCenter );
+      if ( m_alignment.x ( ) == 2 ) // AlignLeft
+        pStyle->setAlignment ( Qt::AlignLeft );
+      else if ( m_alignment.x ( ) == 3 ) // AlignRight
+        pStyle->setAlignment ( Qt::AlignRight );
+      else if ( m_alignment.x ( ) == 4 ) // AlignJustify
+        pStyle->setAlignment ( Qt::AlignJustify );
+    }
+    // edit.setStyleSheet ( pStyleSheet ); not required ...
+  }
+
+  edit.setPaletteBackgroundColor ( colors[0] );
+  edit.setPaletteForegroundColor ( colors[1] );
+  edit.setTextFormat ( Qt::RichText );
+  edit.resize   ( iWidth + 2 * ( m_iOutline + 4 ), iHeight + 2 * ( m_iOutline + 4 ) );
+  edit.setFont  ( m_font  );
+
+  // This is to set the edit.viewport() to max width, so one line of text does not get word wrapped.
+  edit.setText ( "<p>12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890</p>" );
+  qApp->processEvents ( 100 ); // do some event processing ...
+
+  for ( t=0; t<iTotalCount; t++ )  {
+    theRect = m_rect;
+    pEntry  = m_listOfSubtitles[t];
+    if ( pEntry->qsText.isEmpty ( ) )
+      continue;
+
+    qsStart = pEntry->qsTimeStart;
+    qsStart.remove ( ":"      );
+    qsStart.replace( ".", "_" );
+    qsFileName = QString ("%1%2.png").arg ( qsThePath ).arg( qsStart );
+
+    QString qsText = pEntry->qsText;
+    qsText = qsText.replace ( "\n", "<br>" );
+
+    edit.setText   ( "<qdvd>" + qsText + "</qdvd>" );
+    boundingRect = edit.paragraphRect ( 0 );
+    QPixmap theDrawingBoard = QPixmap::grabWidget ( edit.viewport ( ) );
+    boundingRect.setX ( boundingRect.x ( ) + m_iOutline + 4 );
+    boundingRect.setY ( boundingRect.y ( ) + m_iOutline + 4 );
+    boundingRect.setWidth ( iWidth );
+
+/*
+QString qq=qsHorizAlign + pEntry->qsText + qsHorizAlignClose;
+printf ( "%s::%d > r<%d,%d x %d,%d> %s\n", __FILE__, __LINE__, boundingRect.x(), boundingRect.y(), boundingRect.width(),boundingRect.height(), qq.ascii() );
+
+static int ii = 0;
+QString q;
+if ( ii < 10 )
+  q = QString ( "/tmp/a_0%1.png" ).arg ( ii++ );
+else
+  q = QString ( "/tmp/a_%1.png" ).arg ( ii++ );
+theDrawingBoard.save ( q, "PNG" );
+*/
+
+    thePainter.begin ( &theDrawingBoard  ); {
+      int x, y, w, h;
+      x = 0;
+      y = 0;
+      w = theRect.width  ( ); // should be iWidth
+      h = theRect.height ( ); // should be iHeight
+      // We should always adjust the height
+      if ( m_bFit ) {
+        x = boundingRect.x      ( ) - m_iOutline;
+        y = boundingRect.y      ( ) - m_iOutline;
+        w = boundingRect.width  ( ) + m_iOutline * 2;
+        h = boundingRect.height ( ) + m_iOutline * 2;
+        if ( x <  0 )       x = 0;
+        if ( y <  0 )       y = 0;
+        if ( w >= iWidth  ) w = iWidth -1;
+        if ( h >= iHeight ) h = iHeight-1;
+        theRect = QRect ( x + theRect.x ( ), y + theRect.y ( ), w, h );
+      }
+      pEntry->rect = theRect;
+
+      // Sanity check
+      if ( w > theDrawingBoard.width  ( ) - x )
+           w = theDrawingBoard.width  ( ) - x;
+      if ( h > theDrawingBoard.height ( ) - y )
+           h = theDrawingBoard.height ( ) - y;
+      if ( w <=  0 )
+           w  = 10;
+      if ( h <=  0 )
+           h  = 10;
+
+      // create new dimensioned pixmap
+      QPixmap thePixmap = QPixmap ( w, h );
+#if ( QT_VERSION > 0x0301FF )
+      copyBlt ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h );
+#else
+      bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP );
+#endif
+      theImage = thePixmap.convertToImage ( );
+
+    }  thePainter.end ( );
+
+    if ( m_bFit )  {
+      // The QTextEdit paragraphRect returns the right height but not the right width ...
+      // so we'll cut it out.
+      cutHorizontal ( theImage, colors[0] );
+      pEntry->rect = theImage.rect ( );
+    }
+    else if ( m_alignment.y ( ) != 3 )  {
+      QImage temp = theImage.copy ( );//( theRect.width ( ), theRect.height ( ), 32 );
+      theImage.fill ( colors[0] );
+      // If VerticalAlignment not AlignTop, then we'll have to trick here...
+      cutHorizontal ( temp, colors[0] ); // returns the minimum rect image
+
+      int iOffsetX = 0;  // default left
+      int iOffsetY = 0;  // default top
+      if ( m_alignment.x ( ) == 1 ) // AlignCenter
+        iOffsetX = (int)( ( theRect.width ( ) - temp.width ( ) ) / 2.0 );
+      else if ( m_alignment.x ( ) == 3 ) // AlignRight
+        iOffsetX = theRect.width ( ) - temp.width ( );
+      if ( m_alignment.y ( ) == 2 ) // AlignVCenter
+        iOffsetY = (int)( ( theRect.height ( ) - temp.height ( ) ) / 2.0 );
+      else if ( m_alignment.y ( ) == 4 ) // AlignBottom
+        iOffsetY = theRect.height ( ) - temp.height ( );
+
+      // and finally we'll have to copy the text to the right position
+      bitBlt ( &theImage, iOffsetX, iOffsetY, &temp );
+    }
+
+    // Enable transparency ...
+    theImage.setAlphaBuffer ( true );
+
+    // Then we reduce the colors to the max avail color space.
+    theUtils.reduceColors ( theImage, MAX_SUBTITLE_COLORS, (QRgb *)&colors );
+
+    // next we generate the backround color ...
+    theColor = m_subColors[0].rgb ( ) & 0x00FFFFFF;
+    iBGRed   = qRed   ( theColor );
+    iBGGreen = qGreen ( theColor );
+    iBGBlue  = qBlue  ( theColor );
+    theImage.setColor ( 0, m_subColors[0].rgb ( ) );
+
+    // and then the rest of the colors
+    theColor = m_subColors[1].rgb ( ) & 0x00FFFFFF;
+    iRed     = qRed   ( theColor );
+    iGreen   = qGreen ( theColor );
+    iBlue    = qBlue  ( theColor );
+    // Here we'll blend the max 4 colors for the subtitles
+    for ( j=1; j<MAX_SUBTITLE_COLORS; j++ ) {
+      int iDelta, r, g, b;
+      iTransparency = 255 - (( colors[j] & 0xFF00 ) >> 8); // shift green to get the base transparency value
+      // which must be added to the multiplied by the user defined transparency
+      fDelta = (float)(255 - m_subColors[j].alpha ( ) ) / 0xFF;
+      iTransparency = (int)( fDelta * (255-iTransparency ) ) + iTransparency;
+
+      iDelta = ( (colors[j] & 0xFF0000 ) >> 16 );
+      fDelta = (float)(0xFF - iDelta) / 0xFF;
+      r = iRed   + (int)( ( iBGRed   - iRed   ) * fDelta );
+      g = iGreen + (int)( ( iBGGreen - iGreen ) * fDelta );
+      b = iBlue  + (int)( ( iBGBlue  - iBlue  ) * fDelta );
+
+      theColor   =qRgba ( r, g, b, iTransparency );
+      theImage.setColor ( j, theColor );
+    }
+
+    if ( m_iOutline > 0 ) {
+      // Next is to inclrease the number of colors to 4
+      theImage.setNumColors ( 4 );
+      //theImage.setColor ( 3, 0xFF101010 ); // FF == Opaque // 00=Transparent
+      theImage.setColor ( 0, 0x00000000 );
+      theImage.setColor ( 3, m_subColors[0].rgb ( ) ); //real deal ...
+      // Okay, we have outline enabled which means we should replace all background color with either 
+      // transparency or with the pixelcolor of the backdrop or with the pixel color of the generated subtitle.
+      int w, h, x, y, xb, yb, brushX, brushY, idx;
+      w = theImage.width  ( );
+      h = theImage.height ( );
+
+      int pIdx;
+      for ( x=0; x<w; x++ ) {
+        for ( y=0; y<h; y++ ) { // Image x, and y ...
+          // here we take m_iOutline number of pixels before and after an set them to the fourth color.
+          pIdx = theImage.pixelIndex ( x, y );
+          if ( ( pIdx == 1 ) || ( pIdx == 2 ) ) { // not background
+            // So we should underlay the brush ...
+            for ( yb=0; yb<iDiameter; yb++ ) { // copy brush over ...
+              brushY = y - m_iOutline + yb;
+              if ( ( brushY < 0 ) || ( brushY >= h ) )  // out of bounds
+                continue;
+              for ( xb=0; xb<iDiameter; xb++ ) {
+                brushX = x - m_iOutline + xb; 
+                if ( ( brushX < 0 ) || ( brushX >= w ) ) // out of bounds
+                  continue;
+                idx = theImage.pixelIndex ( brushX, brushY );
+                if ( ( idx == 0 ) && ( theBrush.pixelIndex ( xb, yb ) == 1 ) )
+                  theImage.setPixel   ( brushX, brushY, 3 );
+              }
+            }
+          }
+        }
+      }
+    }
+    theImage.save ( qsFileName, "PNG", 100 );  // 100%== No compression. png image
+
+    if ( ( iTotalCount > 20 ) && ( pProgressBar ) ) {
+      pProgressBar->setProgress ( (int)((float)t / iTotalCount * 100.0) );
+      if ( t%10 == 0 ) 
+        qApp->processEvents ( 100 ); // do some event processing ...
+    }
+  }
+  // that's it ...
+  return NULL;
+}
+
+#else
+
 Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString qsFileInfoName, bool bForce )
 {
   // If we are using Spumux's version to render subtitles, then we won't need to render them here ... right ?
@@ -525,7 +869,17 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 
       // Here we draw onto the drawing board
       QRect temp ( 0, 0, iWidth, iHeight );
-      thePainter.drawText ( temp, iFlags, pEntry->qsText, -1, &boundingRect );
+      thePainter.drawText ( temp, iFlags, pEtry->qsText, -1, &boundingRect );
+
+/*
+static int ii = 0;
+QString q;
+if ( ii < 10 )
+  q = QString ( "/tmp/a_0%1.png" ).arg ( ii++ );
+else
+  q = QString ( "/tmp/a_%1.png" ).arg ( ii++ );
+theDrawingBoard.save ( q, "PNG" );
+*/
 
       int x, y, w, h;
       x = 0;
@@ -554,8 +908,8 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
 #else
       bitBlt  ( &thePixmap, 0, 0, &theDrawingBoard, x, y, w, h, Qt::CopyROP);
 #endif
-      theImage = thePixmap.convertToImage ();
-    }  thePainter.end ();
+      theImage = thePixmap.convertToImage ( );
+    }  thePainter.end ( );
     // Enable transparency ...
     theImage.setAlphaBuffer ( true );
 
@@ -640,6 +994,73 @@ Subtitles *Subtitles::render ( QString qsBasePath, QString qsResolution, QString
   return NULL;
 }
 
+#endif
+
+void Subtitles::cutHorizontal ( QImage &img, QRgb filter )
+{
+  // The height of the rect holds the max Y to search.
+  // This function will search the max extension of the text in this image.
+  // That is the first/last pixel that is not the filter color
+  int   x, y, iMaxX, iMinX, iMaxY, iMinY;
+  uint *pLine  = NULL;
+  bool bFound  = false;
+  int  iWidth  = img.width  ( );
+  int  iHeight = img.height ( );
+
+  iMaxX = 0;
+  iMaxY = iHeight;
+  iMinX = iWidth;
+  iMinY = 0;
+  for ( y=0; y<iHeight; y++ )  {
+    pLine = (uint *)img.scanLine ( y );
+    for ( x=0; x<iMinX; x++ )  {
+      if ( ( pLine[x] & 0x00FFFFFF ) != filter )  {
+        bFound = true;
+        if ( iMinX > x )  {
+             iMinX = x;
+        }
+      }
+    }
+    if ( ! bFound )
+      iMinY = y;
+  }
+  bFound = false;
+  for ( y=iHeight-1; y>=0; y-- )  {
+    pLine = (uint *)img.scanLine ( y );
+    for ( x=img.width ( )-1; x>=iMaxX; x-- )  {
+      if ( ( pLine[x] & 0x00FFFFFF ) != filter )  {
+        bFound = true;
+        if ( iMaxX < x )  {
+             iMaxX = x;
+        }
+      }
+    }
+    if ( ! bFound )
+      iMaxY = y;
+  }
+
+  iMinX = iMinX - m_iOutline - 4;
+  iMinY = iMinY - m_iOutline - 4;
+  iMaxX = iMaxX + m_iOutline + 4;
+  iMaxY = iMaxY + m_iOutline + 4;
+  if ( iMinX < 0 )
+       iMinX = 0;
+  if ( iMinY < 0 )
+       iMinY = 0;
+  if ( iMaxX > iWidth  )
+       iMaxX = iWidth;
+  if ( iMaxY > iHeight )
+       iMaxY = iHeight;
+
+  iWidth  = iMaxX-iMinX;
+  iHeight = iMaxY-iMinY;
+  QImage image ( iWidth, iHeight, 32 );
+
+  // Now we have the min/max values, lets cut the cake ...
+  bitBlt ( &image, 0, 0, &img, iMinX, iMinY, iWidth, iHeight );
+  img = image;
+}
+
 // static function to auto extract MetaInfo from a DV video stream in a backround thread
 void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo, QString qsIso639 )
 {
@@ -691,25 +1112,27 @@ void Subtitles::generateSubtitles ( QObject *pOrigObject, SourceFileInfo *pInfo,
     qsIso639 = "en";
   qsLang = theUtils.iso639 ( qsIso639, false );
 
-  fileInfo.setFile ( pInfo->qsFileName );
+  fileInfo.setFile  ( pInfo->qsFileName );
   qsXmlFile.sprintf ( "/subtitle_%d.xml", iFirstNewSubtitleNumber );
   qsXmlFile = theUtils.getTempFile ( fileInfo.baseName ( TRUE ) ) + qsXmlFile;
 
-  pSubtitles = new Subtitles;
+  pSubtitles = new Subtitles ( rect.width ( ), rect.height ( ) );
   // Set subtitle parameters ...
   pSubtitles->m_subtitleState       = Subtitles::STATE_EXTRACTING;
   pSubtitles->m_iSubtitleNumber     = iFirstNewSubtitleNumber;
-  pSubtitles->m_qsIso639            = qsIso639;
   pSubtitles->m_qsXmlFile           = qsXmlFile;
+  pSubtitles->m_qsIso639            = qsIso639;
   pSubtitles->m_subColors[0]        = Rgba (   0,   0,  0, 255 ); // black background
   pSubtitles->m_subColors[1]        = Rgba ( 250, 250, 10, 255 ); // Yellow font color
   pSubtitles->m_iOutline            = 2;
   pSubtitles->m_rect                = rect;
   pSubtitles->m_font.fromString ( "Sans Serif,24,-1,5,75,0,0,0,0,0" );
   // link it with the SourceFileInfo ...
-  if ( pInfo->arraySubtitles[ iFirstNewSubtitleNumber ] )
-    delete pInfo->arraySubtitles[ iFirstNewSubtitleNumber ];
-  pInfo->arraySubtitles [ iFirstNewSubtitleNumber ] = pSubtitles;
+  if ( pInfo->arraySubtitles [iFirstNewSubtitleNumber] )  {
+    pSubtitles->m_qsFileName = pInfo->arraySubtitles [iFirstNewSubtitleNumber]->m_qsFileName;
+    delete pInfo->arraySubtitles [iFirstNewSubtitleNumber];
+  }
+  pInfo->arraySubtitles [iFirstNewSubtitleNumber] = pSubtitles;
 
   // And extract the subtitles in a background task ...
   MediaCreator::registerWithMediaScanner ( pOrigObject, pInfo, pSubtitles, fFPS );
