@@ -251,9 +251,6 @@ void SubtitlesGui::initMe ( )
   }
   m_pComboFontSizes->setCurrentItem (iIndex);
 
-  QPainter thePainter ( m_pFrameBackgroundColor );
-  thePainter.drawLine ( 0, 0, m_pFrameBackgroundColor->width ( ), m_pFrameFontColor->height ( ) );
-
   m_pTextEdit->setTextFormat ( PlainText );
   m_pButtonFit->setOn        (  true );
   m_pEditWidth->setEnabled   ( false );
@@ -946,9 +943,9 @@ void SubtitlesGui::slotCloseSource ()
   if ( m_pDragLabel )  {
     if ( ! m_pDragLabel->isVisible ( ) ) {
       // case we have dropped a movie and played at least a bit of it.
-      int iWidth, iHeight;
-      iWidth  = m_pFramePreview->geometry ( ).width ( );
-      iHeight = m_pFramePreview->geometry ( ).height( );
+//      int iWidth, iHeight;
+//      iWidth  = m_pFramePreview->geometry ( ).width ( );
+//      iHeight = m_pFramePreview->geometry ( ).height( );
 
       m_pMediaInterface->stop ( );
       m_pLayout->remove ( m_pMediaInterface->getWidget ( ) );
@@ -1053,7 +1050,6 @@ void SubtitlesGui::slotAddNew ()
   // and stuff it in the appropriate spot in the table.
   // Some sanity check are beeing made to prevent two entries at the same time.
   uint t;
-  int   iRow = 0;
   long  iStartTime, iEndTime;
   QTime timeStart, timeEnd, nullTime;
   Subtitles::entry *pEntry, *pNewEntry, *pNextEntry = NULL;
@@ -1080,7 +1076,7 @@ void SubtitlesGui::slotAddNew ()
 
   for (t=0;t<m_pSubtitles->m_listOfSubtitles.count ();t++) {
     pEntry = m_pSubtitles->m_listOfSubtitles[t];
-    iRow = t+1;
+//    iRow = t+1;
 
     if ( iStartTime >= pEntry->iTimeStart )
       continue;
