@@ -503,7 +503,8 @@ void TemplateDownload::createSelection ()
 	pIconView = m_pIconViewAnimated;
       else if ( pEntry->qsType == "transition" )
 	pIconView = m_pIconViewTransition;
-      QIconViewItem *pItem = new QIconViewItem ( pIconView, pEntry->qsDescription, pEntry->theThumbnail );
+      QString qsDesc = pEntry->qsName + "\n" + pEntry->qsDescription;
+      QIconViewItem *pItem = new QIconViewItem ( pIconView, qsDesc, pEntry->theThumbnail );
       pItem->setKey ( pEntry->qsName );
       pItem->setSelectable  ( true  );
      }
