@@ -201,7 +201,7 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
   QWMatrix theMatrix;
   QRect dummyRect, theRect;
   int iFlags, x, y;
-  int iSourceHeight, iSourceWidth, iSourceStartX, iSourceStartY, iTargetStartX, iTargetStartY;
+  int iSourceHeight, iSourceWidth, iTargetStartX, iTargetStartY;
   Rgba sourceColor, targetColor, theColor;
   QRgb sourcePixel, targetPixel;
   QImage sourceImg, targetImg;
@@ -259,8 +259,6 @@ void TextObject::drawSemiTransparent (QPainter *pPainter)
   // we should copy this over, bit for bit. 
   iSourceHeight = thePixmap.height(); 
   iSourceWidth  = thePixmap.width ();
-  iSourceStartX = 0;
-  iSourceStartY = 0;
   iTargetStartX = pPainter->viewport().x() + m_boundingRect.x();
   iTargetStartY = pPainter->viewport().y() + m_boundingRect.y();
 
