@@ -163,7 +163,6 @@ QStringList Utils::localTemplates ( )
 
 QString Utils::findGuiSU ( )
 {
-  int iRet = 0;
   uint t;
   QString qsReturn;
   QString qsTmpOut = QString ( "%1/%2_out.txt" ).arg ( Global::qsTempPath ).arg ( getlogin ( ) );
@@ -171,7 +170,8 @@ QString Utils::findGuiSU ( )
   QFileInfo fileInfo ( qsTmpOut );
   for ( t=0; t<3; t++ )     {
     // the next check is to see if we can find kdesu
-    iRet = system ((const char *)QString ( "which %1 > %2 2>/dev/null").arg ( arraySUs[t] ).arg ( qsTmpOut ) );
+    int iRet = system ((const char *)QString ( "which %1 > %2 2>/dev/null").arg ( arraySUs[t] ).arg ( qsTmpOut ) );
+    iRet = iRet;
     fileInfo.setFile ( qsTmpOut );
     // Okay we cna not find it, so we wont bother asking the user ...
     if ( fileInfo.size ( ) > 4 )  {
@@ -222,9 +222,10 @@ void Utils::augmentAlpha ( int iDeltaA, QImage &filter, QImage &start, QImage &s
       if ( fVal > 1.0f )
            fVal = 1.0f;
 
-      r = qRed   ( pix1 ) * (int)( ( 1.0f - fVal ) + qRed   ( pix2 ) * fVal );
-      g = qGreen ( pix1 ) * (int)( ( 1.0f - fVal ) + qGreen ( pix2 ) * fVal );
-      b = qBlue  ( pix1 ) * (int)( ( 1.0f - fVal ) + qBlue  ( pix2 ) * fVal );
+      r = (int)( qRed   ( pix1 ) * ( 1.0f - fVal ) + qRed   ( pix2 ) * fVal );
+      g = (int)( qGreen ( pix1 ) * ( 1.0f - fVal ) + qGreen ( pix2 ) * fVal );
+      b = (int)( qBlue  ( pix1 ) * ( 1.0f - fVal ) + qBlue  ( pix2 ) * fVal );
+
 
       pix1 = qRgb     ( r, g, b );
       result.setPixel ( x, y, pix1 );
@@ -255,9 +256,9 @@ void Utils::augmentAlpha ( int iDeltaA, int iDeltaB, QImage &filter, QImage &sta
       if ( fVal2 > 1.0f )
            fVal2 = 1.0f;
 
-      r = qRed   ( pix1 ) * (int)( ( 1.0f - fVal1 ) + qRed   ( pix2 ) * fVal2 );
-      g = qGreen ( pix1 ) * (int)( ( 1.0f - fVal1 ) + qGreen ( pix2 ) * fVal2 );
-      b = qBlue  ( pix1 ) * (int)( ( 1.0f - fVal1 ) + qBlue  ( pix2 ) * fVal2 );
+      r = (int)( qRed   ( pix1 ) * ( 1.0f - fVal1 ) + qRed   ( pix2 ) * fVal2 );
+      g = (int)( qGreen ( pix1 ) * ( 1.0f - fVal1 ) + qGreen ( pix2 ) * fVal2 );
+      b = (int)( qBlue  ( pix1 ) * ( 1.0f - fVal1 ) + qBlue  ( pix2 ) * fVal2 );
 
       if ( pBackground )  {
         //fVal3 = 1.0f-fVal1 + fVal2;
@@ -294,6 +295,21 @@ QString Utils::currentStyleName ( )
   return QString("Default");
 }
 
+bool Utils::getWidthHeight ( QString qsDimension, int &iWidth, int &iHeight )
+{
+  iWidth  = 0;
+  iHeight = 0;
+  QStringList listSize = QStringList::split ( "x", qsDimension );
+  bool bReturn = false;
+  if ( listSize.count ( ) > 1 )  {
+    iWidth  = listSize[0].toInt ( );
+    iHeight = listSize[1].toInt ( );
+    bReturn  = ( ( iWidth > 10 ) && ( iHeight > 10 ) );
+  }
+  return bReturn;
+}
+
+
 QString Utils::formatChapter (QString qsInput)
 {
 	char cBuffer[20];
@@ -1188,14 +1204,13 @@ bool Utils::hasVobus ( QString qsFileName )
 bool Utils::checkCommand ( const char *pCommand )
 {
   // executes a command and checks if there was a result
-  int iRet = 0;
   char tmpName[20] =  { "/tmp/out_XXXXXX" };
   int iFD = mkstemp ( (char *)&tmpName );
   iFD = iFD; // Silence the compiler warnings.
   QString qsTmpFile = QString ( "%1"  ).arg ( tmpName  );
   QString qsCommand = QString ( "%1 > %2 " ).arg ( pCommand ).arg ( qsTmpFile );
 
-  iRet = system ( qsCommand.ascii ( ) );
+  int iRet = system ( qsCommand.ascii ( ) ); iRet = iRet;
   QFile theFile ( qsTmpFile );
   if ( theFile.exists ( ) ) {
     if ( theFile.size ( ) > 2 )
