@@ -28,13 +28,6 @@ public:
 	// Structure to store the paths to the different tools.
 	struct toolsPaths {
 		toolsPaths ()	{ bPresent = false; };
-//		toolsPaths &operator = (toolsPaths &theOther)
-//		{
-//			qsExecutableName = theOther.qsExecutableName;
-//			qsFullPath  = theOther.qsFullPath;
-//			bPresent = theOther.bPresent;
-//			return *this;
-//		}
 		QString qsExecutableName; 
 		QString qsFullPath; 
 		bool bPresent;
@@ -65,20 +58,21 @@ public:
 	QString getToolByIndex       ( uint );
 	bool    isMandatory          ( uint );
 	QValueList<Utils::toolsPaths *> scanSystem ( );
-	QRgb    nearestColor         ( QRgb *, int, QRgb );
-	void    reduceColors         ( QImage &, int, QRgb * );
-	long    countColors          ( QImage &  );
+	QRgb    nearestColor         ( QRgb    *, int, QRgb   );
+	void    reduceColors         ( QImage  &, int, QRgb * );
+	long    countColors          ( QImage  & );
 	float   getVersionInfo       ( QString & );
 	QImage  convertStringToImage ( QString & );
 	QString convertImageToString ( QImage  & );
 	QString getVideoFormat       ( int,  int );
 	int     getFormat            ( int,  int );
-	int     getFormat            ( QString & );
+	int     getFormat            ( QString  &);
 	bool    getResolution        ( int, int &, int & );
-	bool    webToFile            ( QString &, QString & );
+	bool    webToFile            ( QString  &, QString & );
 	QStringList localTemplates   ( );
 	QString findGuiSU            ( );
 
+        bool    getWidthHeight       ( QString, int &, int & );
 	long    getMsFromString      ( QString       );
 	QString getStringFromMs      ( long          );
 	int     getWHFromResolution  ( QString, bool );
