@@ -652,7 +652,7 @@ bool CXmlDVDAuthor::dvdauthor_struct::writeXml ( QDomDocument *pDocument, QDomEl
 	int t = 0;
 	QDomElement rootDVDAuthor = pDocument->createElement ( node_name ); // <dvdauthor>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		rootDVDAuthor.appendChild ( domComment );
 	}
@@ -684,7 +684,7 @@ bool CXmlDVDAuthor::vmgm_struct::writeXml(QDomDocument *pDocument, QDomElement *
 
 	QDomElement vmgmNode = pDocument->createElement( node_name );	// <vmm>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		vmgmNode.appendChild ( domComment );
 	}
@@ -710,7 +710,7 @@ bool CXmlDVDAuthor::titleset_struct::writeXml(QDomDocument *pDocument, QDomEleme
 	int t = 0;
 	QDomElement titlesetNode = pDocument->createElement( node_name );	// <titleset>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		titlesetNode.appendChild ( domComment );
 	}
@@ -745,7 +745,7 @@ bool CXmlDVDAuthor::menus_struct::writeXml(QDomDocument *pDocument, QDomElement
 	QDomElement menusNode = pDocument->createElement( node_name );	// <menus>
 	// Here we set the attributes of the <dvdauthor> tag
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		menusNode.appendChild ( domComment );
 	}
@@ -788,7 +788,7 @@ bool CXmlDVDAuthor::video_struct::writeXml(QDomDocument *pDocument, QDomElement
 
 	QDomElement videoNode = pDocument->createElement( node_name );	// <video>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n   " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		videoNode.appendChild ( domComment );
 	}
@@ -817,7 +817,7 @@ bool CXmlDVDAuthor::audio_struct::writeXml(QDomDocument *pDocument, QDomElement
 
 	QDomElement audioNode = pDocument->createElement( node_name );	// <audio>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n   " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		audioNode.appendChild ( domComment );
 	}
@@ -846,7 +846,7 @@ bool CXmlDVDAuthor::subpicture_struct::writeXml(QDomDocument *pDocument, QDomEle
 	debug_out ("CXmlDVDAuthor::subpicture_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement subpictureNode = pDocument->createElement( node_name );	// <dvdauthor>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n   " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		subpictureNode.appendChild ( domComment );
 	}
@@ -866,7 +866,7 @@ bool CXmlDVDAuthor::titles_struct::writeXml(QDomDocument *pDocument, QDomElement
 	int t = 0;
 	QDomElement titlesNode = pDocument->createElement( node_name );	// <titles>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n  " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		titlesNode.appendChild ( domComment );
 	}
@@ -904,7 +904,7 @@ bool CXmlDVDAuthor::pgc_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	int t = 0;
 	QDomElement pgcNode = pDocument->createElement( node_name );	// <pgc>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		pgcNode.appendChild ( domComment );
 	}
@@ -949,7 +949,7 @@ bool CXmlDVDAuthor::button_struct::writeXml(QDomDocument *pDocument, QDomElement
 	debug_out ("CXmlDVDAuthor::button_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement buttonNode = pDocument->createElement( node_name );	// <button>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		buttonNode.appendChild ( domComment );
 	}
@@ -971,7 +971,7 @@ bool CXmlDVDAuthor::cell_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	debug_out ("CXmlDVDAuthor::cell_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement cellNode = pDocument->createElement( node_name );	// <cell>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		cellNode.appendChild ( domComment );
 	}
@@ -996,7 +996,7 @@ bool CXmlDVDAuthor::vob_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	debug_out ("CXmlDVDAuthor::vob_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement vobNode = pDocument->createElement( node_name );	// <vob>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		vobNode.appendChild ( domComment );
 	}
@@ -1020,7 +1020,7 @@ bool CXmlDVDAuthor::fpc_struct::writeXml ( QDomDocument *pDocument, QDomElement
 	debug_out ("CXmlDVDAuthor::fpc_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement fpcNode = pDocument->createElement ( node_name );	// <fpc>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		fpcNode.appendChild ( domComment );
 	}
@@ -1039,7 +1039,7 @@ bool CXmlDVDAuthor::pre_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 	debug_out ("CXmlDVDAuthor::pre_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement preNode = pDocument->createElement( node_name );	// <pre>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		preNode.appendChild ( domComment );
 	}
@@ -1058,7 +1058,7 @@ bool CXmlDVDAuthor::post_struct::writeXml(QDomDocument *pDocument, QDomElement *
 	debug_out ("CXmlDVDAuthor::post_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement postNode = pDocument->createElement( node_name );	// <post>
 	if ( ! comment.isEmpty ( ) )  {
-		QString  qsComment  = QString ( "<!-- %1 // -->\n" ).arg ( comment );
+		QString  qsComment  = QString ( "<!-- %1 // -->\n    " ).arg ( comment );
 		QDomText domComment = pDocument->createTextNode ( qsComment );
 		postNode.appendChild ( domComment );
 	}
@@ -1759,6 +1759,14 @@ CXmlDVDAuthor::button_struct *CXmlDVDAuthor::pgc_struct::addButton ()
 	return ppArrayButton[i];
 }
 
+bool CXmlDVDAuthor::vob_struct::operator == ( CXmlDVDAuthor::vob_struct &theOther )
+{
+  return ( ( comment  == theOther.comment  ) &&
+           ( file     == theOther.file     ) &&
+           ( chapters == theOther.chapters ) &&
+           ( pause    == theOther.pause    ) );
+}
+
 CXmlDVDAuthor::vob_struct *CXmlDVDAuthor::pgc_struct::addVob ()
 {
 	// This function simply enlarges the array of available titlesets.
