@@ -10,6 +10,7 @@
  ** will automagically be available in the other part.
  **
  *****************************************************************/
+#include <stdlib.h>
 #include <math.h>
 
 #include "xml_slideshow.h"
@@ -61,7 +62,7 @@ CXmlSlideshow::time_object::~time_object ( )
 CXmlSlideshow::effect_struct::effect_struct ()
 {
 	node_name = QString ("effect");
-	QString name;  // either crop/kenburns/scroll
+	name= "";  // either crop/kenburns/scroll
 	bUserDefined = false;
 	x0  = 0;
 	y0  = 0;
@@ -71,7 +72,84 @@ CXmlSlideshow::effect_struct::effect_struct ()
 	ye0 = 0;
 	xe1 = 0;
 	ye1 = 0;
-	scroll = QString ("");	// either left or right
+	scroll = QString (""); // either left or right
+}
+
+bool CXmlSlideshow::effect_struct::isDefault ( )
+{
+  return ( ( 0 ==  x0 ) && ( 0 ==  y0 ) && ( 0 ==  x1 ) && ( 0 ==  y1 ) &&
+           ( 0 == xe0 ) && ( 0 == ye0 ) && ( 0 == xe1 ) && ( 0 == ye1 ) );
+}
+
+void CXmlSlideshow::effect_struct::randomKenBurns ( float fStrength, int iWidth, int iHeight, bool bForce )
+{
+  int iCorner = -1;
+
+  if ( bForce || isDefault ( ) ) {
+    name = EFFECT_TYPE_KENBURNS;
+    // Randomly create start stop etc ...
+    // RandomRange :
+    if ( ( fStrength > 0.99999 ) || ( fStrength < 0.00001 ) )
+           fStrength = 0.5;
+
+    // RandomRange is delta between cut-out image and full image corner. E.g. 50
+    int iRandomXRange = (int)( fStrength / 2.0 * iWidth  );
+    int iRandomYRange = (int)( fStrength / 2.0 * iHeight );
+
+    // Also we want to limit the randomness to 0.5 - 1.0
+    float fMinScale = 0.1f;
+    float fMaxScale = 1.0f - fMinScale;
+    float fScaleX   = ( (float)rand ( ) / RAND_MAX ) * fMaxScale + fMinScale;
+    float fScaleY   = ( (float)rand ( ) / RAND_MAX ) * fMaxScale + fMinScale;
+
+    // randomly determine in which corner to start
+    float fRand = (float)rand ( );
+    iCorner = (int)( fRand / RAND_MAX * 4.0 );
+    if ( iCorner == 0 )  { // Starting Upper left corner
+      x0  = 0;
+      y0  = 0;
+      x1  = iWidth  - (int)( fScaleX * iRandomXRange );
+      y1  = iHeight - (int)( fScaleY * iRandomYRange );
+
+      xe0 = iWidth  - x1;
+      ye0 = iHeight - y1;
+      xe1 = iWidth;
+      ye1 = iHeight;
+    }
+    else if ( iCorner == 1 )  { // Starting Upper right corner
+      x0  = (int)( fScaleX * iRandomXRange );
+      y0  = 0;
+      x1  = iWidth;
+      y1  = iHeight - (int)( fScaleY * iRandomYRange );
+
+      xe0 = 0;
+      ye0 = iHeight - y1;
+      xe1 = iWidth - x0;
+      ye1 = iHeight;
+    }
+    else if ( iCorner == 2 )  { // Starting Lower right corner
+      x0  = (int)( fScaleX * iRandomXRange );
+      y0  = (int)( fScaleY * iRandomYRange );
+      x1  = iWidth;
+      y1  = iHeight;
+
+      xe0 = 0;
+      ye0 = 0;
+      xe1 = iWidth  - x0;
+      ye1 = iHeight - y0;
+    }
+    else { // Starting Lower left corner
+      x0  = 0;
+      y0  = (int)( fScaleY * iRandomYRange );
+      x1  = iWidth  - (int)( fScaleX * iRandomXRange );;
+      y1  = iHeight;
+
+      xe0 = iWidth  - x1;
+      ye0 = 0;
+      xe1 = iWidth;
+      ye1 = iHeight - y0;
+    }
+  }
 }
 
 bool CXmlSlideshow::effect_struct::readXml (QDomElement *pDocElem)
@@ -111,31 +189,33 @@ bool CXmlSlideshow::effect_struct::writeXml(QDomDocument *pDocument, QDomElement
 //	debug_out ("CXmlSlideshow::effect_struct::writeXml <%s><%s>\n",(const char *)pNodeElement->tagName(), (const char *)node_name);
 	QDomElement effectNode = pDocument->createElement( node_name );	// <effect_start> or <effect_stop>
 
-	if (!name.isNull())
-		effectNode.setAttribute( EFFECT_NAME, name );
-	else
+	if ( ! name.isEmpty ( ) )
+		effectNode.setAttribute ( EFFECT_NAME, name );
+	else if ( isDefault ( ) ) // Check if we have anything to store.
 		return true;
+
 	if ( bUserDefined )
-		effectNode.setAttribute( EFFECT_USER_DEF, "true" );
-	if (x0 > 1)
-		effectNode.setAttribute( EFFECT_X0, QString ("%1").arg(x0) );
-	if (y0 > 1)
-		effectNode.setAttribute( EFFECT_Y0, QString ("%1").arg(y0) );
-	if (x1 > 1)
-		effectNode.setAttribute( EFFECT_X1, QString ("%1").arg(x1) );
-	if (y1 > 1)
-		effectNode.setAttribute( EFFECT_Y1, QString ("%1").arg(y1) );
-	if (xe0 > 1)
-		effectNode.setAttribute( EFFECT_XE0, QString ("%1").arg(xe0) );
-	if (ye0 > 1)
-		effectNode.setAttribute( EFFECT_YE0, QString ("%1").arg(ye0) );
-	if (xe1 > 1)
-		effectNode.setAttribute( EFFECT_XE1, QString ("%1").arg(xe1) );
-	if (ye1 > 1)
-		effectNode.setAttribute( EFFECT_YE1, QString ("%1").arg(ye1) );
-	if (!scroll.isEmpty())
-		effectNode.setAttribute( EFFECT_SCROLL, scroll );
-	pNodeElement->appendChild( effectNode );
+		effectNode.setAttribute ( EFFECT_USER_DEF, "true" );
+	if ( x0  > 1 )
+		effectNode.setAttribute ( EFFECT_X0,  QString ( "%1" ).arg (  x0 ) );
+	if ( y0  > 1 )
+		effectNode.setAttribute ( EFFECT_Y0,  QString ( "%1" ).arg (  y0 ) );
+	if ( x1  > 1 )
+		effectNode.setAttribute ( EFFECT_X1,  QString ( "%1" ).arg (  x1 ) );
+	if ( y1  > 1 )
+		effectNode.setAttribute ( EFFECT_Y1,  QString ( "%1" ).arg (  y1 ) );
+	if ( xe0 > 1 )
+		effectNode.setAttribute ( EFFECT_XE0, QString ( "%1" ).arg ( xe0 ) );
+	if ( ye0 > 1 )
+		effectNode.setAttribute ( EFFECT_YE0, QString ( "%1" ).arg ( ye0 ) );
+	if ( xe1 > 1 )
+		effectNode.setAttribute ( EFFECT_XE1, QString ( "%1" ).arg ( xe1 ) );
+	if ( ye1 > 1 )
+		effectNode.setAttribute ( EFFECT_YE1, QString ( "%1" ).arg ( ye1 ) );
+	if ( ! scroll.isEmpty ( ) )
+		effectNode.setAttribute ( EFFECT_SCROLL, scroll );
+
+	pNodeElement->appendChild ( effectNode );
 	return true;
 }
 
@@ -143,10 +223,10 @@ CXmlSlideshow::effect_struct& CXmlSlideshow::effect_struct::operator =(CXmlSlide
 {
 	name = theOther.name;
 	bUserDefined = theOther.bUserDefined;
-	x0 = theOther.x0;
-	y0 = theOther.y0;
-	x1 = theOther.x1;
-	y1 = theOther.y1;
+	x0  = theOther.x0;
+	y0  = theOther.y0;
+	x1  = theOther.x1;
+	y1  = theOther.y1;
 	xe0 = theOther.xe0;
 	ye0 = theOther.ye0;
 	xe1 = theOther.xe1;
@@ -172,13 +252,13 @@ bool CXmlSlideshow::effect_struct::operator == ( CXmlSlideshow::effect_struct &t
 CXmlSlideshow::img_struct::img_struct ()
 	: time_object ()
 {
-	node_name = QString ( "img");
+	node_name = QString ( IMG_NODE );
 	src       = QString (   "" );
 	text      = QString (   "" );
-	width     =    0;
-	height    =    0;
-	pMatrix   = NULL;
-	rotate    = 0.0f;
+	width     =     0;
+	height    =     0;
+	pMatrix   =  NULL;
+	rotate    =  0.0f;
 	effect[0].node_name = effect[0].node_name + "_start";
 	effect[1].node_name = effect[1].node_name + "_end";
 }
@@ -199,7 +279,6 @@ CXmlSlideshow::img_struct::~img_struct ()
 
 bool CXmlSlideshow::img_struct::readXml ( QDomElement *pDocElem )
 {
-//	bool bReturn = true;
 	if (pDocElem->tagName() != node_name)
 		return false;
 	// So lets get first the attributes for this node.
@@ -219,32 +298,28 @@ bool CXmlSlideshow::img_struct::readXml ( QDomElement *pDocElem )
 	if ( pMatrix )
 		delete pMatrix;
 	pMatrix = NULL;
-#ifdef QDVD_RENDER
+
 	if ( ! a.value ( ).isEmpty ( ) )  {
+#ifdef QDVD_RENDER
 		QStringList list = a.value ( ).split ( "," );
 		qreal fValues[10]; //m11, m12, m21, m22, dx, dy;
-		for ( int t=0; t<list.count ( ); t++ )
-			fValues[t] = list[t].toDouble ( );
-		pMatrix = new QMatrix ( fValues[0], fValues[1], fValues[2], fValues[3], fValues[4], fValues[5] );
-//		pMatrix = new QMatrix ( qreal m11, qreal m12, qreal m21, qreal m22, qreal dx, qreal dy );
-	}
 #else
-	if ( ! a.value ( ).isEmpty ( ) )  {
 		QStringList list = QStringList::split ( ",", a.value ( ) );
 		double fValues[10]; //m11, m12, m21, m22, dx, dy;
+#endif
 		for ( int t=0; t<(int)list.count ( ); t++ )
 			fValues[t] = list[t].toDouble ( );
 		pMatrix = new QMatrix ( fValues[0], fValues[1], fValues[2], fValues[3], fValues[4], fValues[5] );
 	}
 	bool bReturn = false;
 	QDomNode xmlNode = pDocElem->firstChild ( );
-	ImageManipulator tmpImageManipulator;
 	filter_struct    tmpFilter;
 	if ( pTransition )
 		delete pTransition;
+	pTransition = NULL;
+
 	while ( !xmlNode.isNull ( ) ) {
 		QDomElement searchTree = xmlNode.toElement();
-		ImageManipulator *pImageManipulator = new ImageManipulator;
 		if ( searchTree.tagName ( ) == tmpFilter.node_name )  {
 			pTransition = new filter_struct;
 			bReturn = pTransition->readXml ( &searchTree );
@@ -253,17 +328,19 @@ bool CXmlSlideshow::img_struct::readXml ( QDomElement *pDocElem )
 			bReturn = effect[0].readXml ( &searchTree  );
 		if ( searchTree.tagName ( ) == effect[1].node_name )
 			bReturn = effect[1].readXml ( &searchTree  );
-		if ( searchTree.tagName ( ) == tmpImageManipulator.node_name)	{
+#ifndef QDVD_RENDER
+		if ( searchTree.tagName ( ) == QString ( MANIPULATOR ) )	{
+			ImageManipulator *pImageManipulator = new ImageManipulator;
 			pModifier = (void *)pImageManipulator;
 			bReturn = pImageManipulator->readProjectFile( searchTree );
 		}
+#endif
 		// If there has been a problem then return false.
 		if ( ! bReturn )
 			return false;
 		// Otherwise go to the next node ...
 		xmlNode = xmlNode.nextSibling ( );
 	}
-#endif
 	return true;
 }
 
@@ -296,9 +373,10 @@ bool CXmlSlideshow::img_struct::writeXml(QDomDocument *pDocument, QDomElement *p
 
 	pNodeElement->appendChild ( imgNode );
 	if ( pTransition )
-		pTransition->writeXml ( pDocument, pNodeElement );
-	effect[0].writeXml            ( pDocument, pNodeElement );
-	return effect[1].writeXml     ( pDocument, pNodeElement );
+		pTransition->writeXml ( pDocument, &imgNode );
+
+	effect[0].writeXml            ( pDocument, &imgNode );
+	return effect[1].writeXml     ( pDocument, &imgNode );
 }
 
 CXmlSlideshow::time_object& CXmlSlideshow::img_struct::operator =(CXmlSlideshow::time_object &theOther)
@@ -349,13 +427,13 @@ bool CXmlSlideshow::img_struct::operator == ( CXmlSlideshow::time_object &theOth
 {
 	CXmlSlideshow::img_struct *pTheOther = (CXmlSlideshow::img_struct *)&theOther;
 	bool bReturn = ( 
-		 ( src == pTheOther->src                 ) &&
-		 ( text == pTheOther->text               ) &&
-		 ( width == pTheOther->width             ) &&
-		 ( height == pTheOther->height           ) &&
-		 ( rotate  == pTheOther->rotate          ) &&
-		 ( effect[0]== pTheOther->effect[0]      ) &&
-		 ( effect[1] == pTheOther->effect[1]     ) &&
+		 ( src == pTheOther->src                  ) &&
+		 ( text == pTheOther->text                ) &&
+		 ( width == pTheOther->width              ) &&
+		 ( height == pTheOther->height            ) &&
+		 ( rotate  == pTheOther->rotate           ) &&
+		 ( effect[0]== pTheOther->effect[0]       ) &&
+		 ( effect[1] == pTheOther->effect[1]      ) &&
 		 ( fEndTime   == pTheOther->fEndTime     ) &&
 		 ( fDuration   == pTheOther->fDuration   ) &&
 		 ( fStartTime   == pTheOther->fStartTime ) );
@@ -392,7 +470,7 @@ pMatrix->dy  ( ), pTheOther->pMatrix->dy  ( ), fabs( pMatrix->dy  ( ) - pTheOthe
 CXmlSlideshow::vid_struct::vid_struct ( )
 	: img_struct ( )
 {
-	node_name = QString ( "vid" );
+	node_name = QString ( VID_NODE );
 	length = 0L;
 }
 
@@ -439,9 +517,9 @@ bool CXmlSlideshow::vid_struct::writeXml ( QDomDocument *pDocument, QDomElement
 
 	pNodeElement->appendChild ( imgNode );
 	if ( pTransition )
-		pTransition->writeXml ( pDocument, pNodeElement );
-	effect[0].writeXml            ( pDocument, pNodeElement );
-	return effect[1].writeXml     ( pDocument, pNodeElement );
+		pTransition->writeXml ( pDocument, &imgNode );
+	effect[0].writeXml            ( pDocument, &imgNode );
+	return effect[1].writeXml     ( pDocument, &imgNode );
 }
 
 CXmlSlideshow::time_object& CXmlSlideshow::vid_struct::operator =(CXmlSlideshow::time_object &theOther)
@@ -609,11 +687,11 @@ CXmlSlideshow::CXmlSlideshow ( )
 	id            = NULL;
 	total_audio_length = 0;
 	bImgBackgroundImg  = false;
+	bKenBurns          = false;
 }
 
 CXmlSlideshow::~CXmlSlideshow ()
 {
-//printf ( "CXmlSlideshow::~CXmlSlideshow <%s>\n", slideshow_name.ascii ( ) );
 	clear ( );
 }
 
@@ -686,6 +764,11 @@ void CXmlSlideshow::clearObjects ( )
 	total_audio_length = 0;
 }
 
+bool CXmlSlideshow::kenBurns ( )
+{
+	return bKenBurns;
+}
+
 bool CXmlSlideshow::imgBkgImg ( )
 {
 	return bImgBackgroundImg;
@@ -698,6 +781,21 @@ bool CXmlSlideshow::imgBkgImg ( )
 	return bReturn;
 }
 
+void CXmlSlideshow::setKenBurns ( bool bSet )
+{
+  if ( bSet && ! bKenBurns )  {
+    uint iImgCount = countImg ( );
+    for ( uint t=0; t<iImgCount; t++ )  {
+      CXmlSlideshow::img_struct *pImg = getImg ( t );
+      if ( ! pImg )
+        continue;
+      // don't force it if the img already has KenBurns
+      pImg->effect[0].randomKenBurns ( 0.3, pImg->width, pImg->height, false );
+    }
+  }
+  bKenBurns = bSet;
+}
+
 void CXmlSlideshow::setImgBkgImg ( bool bImgBkgImg )
 {
   // For now we stay with the global var.
@@ -726,15 +824,16 @@ CXmlSlideshow &CXmlSlideshow::operator = (CXmlSlideshow &theOther)
 	background     = theOther.background;
 	slideshow_name = theOther.slideshow_name;
 	audio_list     = theOther.audio_list;
+	bKenBurns      = theOther.bKenBurns;
 	validFilterNames   = theOther.validFilterNames;
 	bImgBackgroundImg  = theOther.bImgBackgroundImg;
 	total_audio_length = theOther.total_audio_length;
 	// Here we copy the objects over ..
 	for (t=0;t<theOther.count();t++)	{
 		pTimeObject = theOther.getTimeObject(t);
-		if (pTimeObject->node_name == "img")
+		if (pTimeObject->node_name == IMG_NODE )
 			pNewObject = addImg    ( );  //new img_struct;
-		else if (pTimeObject->node_name == "vid")
+		else if (pTimeObject->node_name == VID_NODE )
 			pNewObject = addVid    ( );  //new img_struct;
 		else
 			pNewObject = addFilter ( );  //new filter_struct;
@@ -766,7 +865,12 @@ printf ( "%s:%d > XmlSlideshow<%s> bRet<%s> cnt<%d vs %d> ", __FILE__, __LINE__,
 for ( t=0; t<count ( ); t++ )  {
 	p1 = getTimeObject ( t );
 	p2 = theOther.getTimeObject ( t );
-printf ( "[%d]%s,%s=<%s> ", t, p1->node_name.ascii(), p2->node_name.ascii(), ( *p1 == *p2 ) ? "true" : "false" );
+        img_struct *pImg = NULL;
+        if ( p1->node_name == IMG_NODE )  
+           pImg = (img_struct *)p1;
+        if ( p1->node_name == VID_NODE )
+           pImg = (img_struct *)p1;
+printf ( "\n[%d]%s,%s=<%s> <%s>", t, p1->node_name.ascii(), p2->node_name.ascii(), ( *p1 == *p2 ) ? "true" : "false", pImg ? pImg->src.ascii() : "NotImageObj" );
 }
 printf ("\n" );
 */
@@ -886,6 +990,8 @@ bool CXmlSlideshow::readXml ( QDomElement *pElement )
 	total_audio_length= a.value ( ).toInt ( );
 	a = pElement->attributeNode ( SLIDESHOW_IMG_BKG_IMG  );
 	bImgBackgroundImg = ( a.value ( ) == "true" ) ? true : false;
+	a = pElement->attributeNode ( SLIDESHOW_KEN_BURNS );
+	bKenBurns  = ( a.value ( ) == "true" ) ? true : false;
 	audioList  = pElement->attributeNode ( SLIDESHOW_AUDIO_LIST  ).value ( );
 	filterList = pElement->attributeNode ( SLIDESHOW_FILTER_LIST ).value ( );
 #ifdef QDVD_RENDER
@@ -1002,6 +1108,8 @@ bool CXmlSlideshow::writeXml ( QDomElement *pElement )
 		pElement->setAttribute( SLIDESHOW_YRES,  QString ("%1").arg ( yres ) );
 	if ( total_audio_length > 0 )
 		pElement->setAttribute( SLIDESHOW_AUDIO_LENGTH,  QString ("%1").arg ( total_audio_length ) );
+	if ( bKenBurns )
+		pElement->setAttribute( SLIDESHOW_KEN_BURNS, "true" );
 	if ( bImgBackgroundImg )
 		pElement->setAttribute( SLIDESHOW_IMG_BKG_IMG, "true" );
 	if ( ! intro_page )
@@ -1092,6 +1200,78 @@ CXmlSlideshow::img_struct *CXmlSlideshow::addImg()
   return pImg;
 }
 
+bool CXmlSlideshow::insertImg ( uint iPos, CXmlSlideshow::img_struct *pImg )
+{
+  if ( iPos > (uint)m_listTimeObjects.count ( ) ) 
+    return false;
+
+  bool bRet = false;
+  int  iCount = 0, iImagePos = 0;
+  time_object *pTimeObject = NULL;
+  QValueList<time_object *>::iterator it = m_listTimeObjects.begin ( );
+  while ( it != m_listTimeObjects.end ( ) )  {
+    iCount++; // Always increase
+    pTimeObject = *it++;
+    if ( pTimeObject->node_name == IMG_NODE )
+      iImagePos ++;
+    if ( (uint)iCount == iPos )  {
+      bRet = true;
+      m_listTimeObjects.insert ( it, pImg );
+      break;
+    }
+  }
+  if ( ! bRet ) // Not yet found, then we should push it to the end ...
+    m_listTimeObjects.push_back ( pImg );
+
+  QValueList<img_struct *>::iterator it2 = m_listImages.begin ( );
+  while ( it2 != m_listImages.end ( ) || iImagePos-- >= 0 )  {
+    it2++;
+  }
+  if ( it2 != m_listImages.end ( ) )
+    m_listImages.insert ( it2, pImg );
+  else
+    m_listImages.push_back ( pImg );
+
+  // Always true at this point
+  return true;
+}
+
+bool CXmlSlideshow::insertVid ( uint iPos, CXmlSlideshow::vid_struct *pVid )
+{
+  if ( iPos > (uint)m_listTimeObjects.count ( ) )
+    return false;
+
+  bool bRet = false;
+  int  iCount = 0, iVideoPos = 0;
+  time_object *pTimeObject = NULL;
+  QValueList<time_object *>::iterator it = m_listTimeObjects.begin ( );
+  while ( it != m_listTimeObjects.end ( ) )  {
+    iCount++; // Always increase
+    pTimeObject = *it++;
+    if ( pTimeObject->node_name == VID_NODE )
+      iVideoPos ++;
+    if ( (uint)iCount == iPos )  {
+      bRet = true;
+      m_listTimeObjects.insert ( it, pVid );
+      break;
+    }
+  }
+  if ( ! bRet ) // Not yet found, then we should push it to the end ...
+    m_listTimeObjects.push_back ( pVid );
+
+  QValueList<vid_struct *>::iterator it2 = m_listVids.begin ( );
+  while ( it2 != m_listVids.end ( ) || iVideoPos-- >= 0 )  {
+    it2++;
+  }
+  if ( it2 != m_listVids.end ( ) )
+    m_listVids.insert ( it2, pVid );
+  else
+    m_listVids.push_back ( pVid );
+
+  // Always true at this point
+  return true;
+}
+
 void CXmlSlideshow::delImg ( CXmlSlideshow::img_struct *pImg )
 {
   if ( ! pImg )
