@@ -32,6 +32,10 @@
 #include <QList>
 #include <QMutex>
 
+#ifndef UINT64_C
+#define UINT64_C uint64_t
+#endif
+
 #include <libavutil/avutil.h>
 
 #if ( LIBAVUTIL_VERSION_MAJOR >= 50 )
@@ -136,11 +140,13 @@ class FFmpeg : public Encoder
 
     QImage &getFrame        ( AVFrame *, int, int );
     QImage &getFrame        ( double );
+    void   delFrame         ( AVFrame *& );
     bool   isValidStream    ( );
     double getFrameRate     ( );
 
     void        setSWScale  ( int, int, int a=0, int c=0 );
     SwsContext *getSWScale  ( );
+    void       freePicture  ( AVFrame *& );
     AVFrame   *allocPicture ( uint8_t *&, PixelFormat, int, int   );
     AVPacket *getNextPacket ( AVStream *, AVStream  *, int & );
 
@@ -160,7 +166,8 @@ class FFmpeg : public Encoder
     int         m_iVideoOutSize;
     int         m_iPadding[2];
     int         m_iPaddingYUV[3];
-    AVFrame    *m_pFrame;         // Current Frame ???
+    AVFrame    *m_pFrame;       // Buffer for the current converted frame ( 720x480 )
+    AVFrame    *m_pScaledFrame; // In case we need to scale, and pad the frame to keep the videos AspectRatio
   };
 
 public:
@@ -171,7 +178,7 @@ public:
   virtual bool addImage       ( QImage *, int, float fVolume=1.0f );
   virtual void endStream      ( );
 
-  virtual bool addVid         ( QString, int, int, int a=0, int c=0 );
+  virtual bool addVid         ( QString, int, int, int a=0, int c=0, double r=0.0 );
   virtual bool initVid        ( QString );
   virtual void closeVid       (         );
   virtual QImage &getVidFrame (  double );
