@@ -10,6 +10,7 @@
 
 #include <time.h>
 #include <stdlib.h>
+#include <time.h>
 
 #include <QDir>
 #include <QImage>
@@ -19,6 +20,7 @@
 // Get the SYSTEM_PATH
 #include "../qdvdauthor/CONFIG.h"
 
+#include "utils.h"
 #include "engine/ffmpeg_enc.h"
 #include "filter.h"
 
@@ -30,6 +32,10 @@ namespace Render
 ****************************************************************************/
 Filter::Filter ( )
 {
+  m_bUseKenBurns    = false;
+  m_iAspectRatio    = 0;
+  m_iTotalImages[0] = 0;
+  m_iTotalImages[1] = 0;
 }
 
 Filter::~Filter ( )
@@ -71,6 +77,40 @@ bool Filter::exec ( Encoder::FFmpeg *, QImage &, QImage &, int, enAudioTrans, QI
   return false;
 }
 
+void Filter::setKenBurnsParams ( CXmlSlideshow::img_struct *pStart, CXmlSlideshow::img_struct *pStop, QImage &background, int iAspectRatio, int iTotal1, int iTotal2 )
+{
+  if ( pStart )
+    m_kenBurns[0] = *pStart;
+  if ( pStop )
+    m_kenBurns[1] = *pStop;
+  if ( pStart || pStop )
+    m_bUseKenBurns  = true;
+  m_background      = background;
+  m_iAspectRatio    = iAspectRatio;
+  m_iTotalImages[0] = iTotal1;
+  m_iTotalImages[1] = iTotal2;
+}
+
+void Filter::encode ( Encoder::FFmpeg *pEncoder, QImage &result, float fProgress, enAudioTrans audioTrans )
+{
+  float  fVolume;
+  // And at the end we will add this to the VOB compliant video TS
+  switch ( audioTrans )  {
+  case VolumeNull:
+    fVolume = 0.0f;
+  break;
+  case VolumeUp:
+    fVolume = fProgress;
+  break;
+  case VolumeDown:
+    fVolume = 1.0f  - fProgress;
+  break;
+  default:
+    fVolume = 1.0f;
+  }
+  pEncoder->addImage ( &result, 1, fVolume );
+}
+
 QStringList Filter::getFilterNames ( )
 {
   // Get all supported filter names.
@@ -78,7 +118,7 @@ QStringList Filter::getFilterNames ( )
 //  KenBurnsFilter kbFilter;
   AlphaFilter     aFilter;
 
-  QValueList<Filter *> filterList;
+  QList<Filter *> filterList;
   filterList.append (  &xFilter );
 //  filterList.append ( &kbFilter );
   filterList.append (  &aFilter );
@@ -86,7 +126,7 @@ QStringList Filter::getFilterNames ( )
   QStringList list, retList;
   QStringList::iterator it;
 
-  QValueList<Filter *>::iterator itFilter = filterList.begin ( );
+  QList<Filter *>::iterator itFilter = filterList.begin ( );
   while  ( itFilter !=  filterList.end ( ) )  {
     list=(*itFilter++)->getFilterNames ( );
     it = list.begin ( );
@@ -113,7 +153,6 @@ bool CrossFadeFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage
   int    t;
   QImage result;
   qreal  fAlpha;
-  float  fVolume;
 
   for  ( t=0; t<iNumberOfImages; t++ )  {
     result = imgStart;
@@ -123,22 +162,7 @@ bool CrossFadeFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage
     thePainter.setOpacity (  fAlpha ); // 0 = transparent 1=opaque
     thePainter.drawImage  ( 0, 0, imgStop, 0, 0 );
 
-    // And at the end we will add this to the VOB compliant video TS
-    switch ( audioTrans )  {
-    case VolumeNull:
-      fVolume = 0.0f;
-    break;
-    case VolumeUp:
-      fVolume = (float)t / iNumberOfImages;
-    break;
-    case VolumeDown:
-      fVolume = 1.0f  - (float)t / iNumberOfImages;
-    break;
-    default:
-      fVolume = 1.0f;
-    }
-
-    pEncoder->addImage ( &result, 1, fVolume );
+    encode ( pEncoder, result, (float)t/iNumberOfImages, audioTrans );
   }
   return true;
 }
@@ -167,6 +191,61 @@ bool KenBurnsFilter::exec ( Encoder::FFmpeg *, QImage &, QImage &, int, enAudioT
   return false;
 }
 
+bool KenBurnsFilter::exec ( QImage &origImage, CXmlSlideshow::effect_struct *pEffect, QImage &result, int iFrameNr, int iTotalFrames )
+{
+  if ( ( ! pEffect ) || ( pEffect->name != EFFECT_TYPE_KENBURNS ) || ( iTotalFrames < 1 ) || ( iFrameNr < 0 )  || ( iTotalFrames < iFrameNr ) ) {
+    result = origImage.copy ( );
+    return false;
+  }
+  // Here we apply the KenBurns effect to the original image.
+  int x, y, w, h, x2, y2;
+  x=0; y=0; w=origImage.width ( ); h=origImage.height ( );
+  double fProgress = (double)iFrameNr / (double)iTotalFrames;
+
+  // Calculate current upper right corner.
+  x = pEffect->x0 + ( ( pEffect->xe0 - pEffect->x0 ) * fProgress );
+  y = pEffect->y0 + ( ( pEffect->ye0 - pEffect->y0 ) * fProgress );
+
+  // Calculate current lower right position
+  x2 = pEffect->x1 + ( ( pEffect->xe1 - pEffect->x1 ) * fProgress );
+  y2 = pEffect->y1 + ( ( pEffect->ye1 - pEffect->y1 ) * fProgress );
+
+  w = x2 - x;
+  h = y2 - y;
+
+  if ( w >= 0 && w < 5 )
+    w = 5;
+  if ( h >= 0 && h < 5 )
+    h = 5;
+
+  bool bHMirror = false, bVMirror = false;
+  if ( w < 0 )  {
+    bVMirror = true;
+    w  = x;
+    x  = x2;
+    x2 = w;
+    w  = x2 - x;
+  }
+  if ( h < 0 )  {
+    bHMirror = true;
+    h  = y;
+    y  = y2;
+    y2 = h;
+    h  = y2 - y;
+  }
+/*
+printf ( "f<%d> tf<%d> xywh<%d, %d, %d, %d> start<%d, %d, %d, %d> stop<%d, %d, %d, %d> pogress<%f> origW<%d> origH<%d>\n", iFrameNr, iTotalFrames, x, y, w, h,
+pEffect->x0,  pEffect->y0,  pEffect->x1,  pEffect->y1,
+pEffect->xe0, pEffect->ye0, pEffect->xe1, pEffect->ye1,
+fProgress, origImage.width ( ), origImage.height ( ) );
+*/
+  result = origImage.copy ( x, y, w, h );
+  if ( bHMirror || bVMirror ) 
+    result = result.mirrored ( bHMirror, bVMirror );
+
+  return true;
+}
+
 QStringList KenBurnsFilter::getFilterNames ( )
 {
   QStringList list;
@@ -194,6 +273,9 @@ AlphaFilter::~AlphaFilter ( )
 
 bool AlphaFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage &imgStop, int iNumberOfImages, enAudioTrans audioTrans, QImage *pBackground )
 {
+  if ( m_bUseKenBurns )
+    return execKB ( pEncoder, imgStart, imgStop, iNumberOfImages, audioTrans, pBackground );
+
   // If no user selection, then we'll have to randomly get one ...
   QString qsTransitionPath =  + SYSTEM_DIRECTORY + QString ( "/share/qdvdauthor/slideshow/transitions/alpha/" );
   QString qsFilterName, qsBaseName, qsExt;
@@ -213,7 +295,7 @@ bool AlphaFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage &im
   qsExt = ".jpg";
   qsFilterName = qsTransitionPath + qsBaseName + qsExt;
 
-  QFile filter ( qsFilterName );
+  QFile  filter ( qsFilterName );
   if ( ! filter.exists ( ) )  {
     qsTransitionPath =  + SYSTEM_DIRECTORY + QString ( "/share/qdvdauthor/slideshow/transitions/luma/" );
     qsExt = ".png"; // Luma directory contains only png's
@@ -237,7 +319,7 @@ bool AlphaFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage &im
   }
 
   int    t;
-  float  fDeltaA, fVolume;
+  float  fDeltaA; //, fVolume;
   QImage result ( filterImage.size ( ), QImage::Format_RGB32 );
 
   // Each step the alpha value of each pixel is increased / decreased by this much
@@ -255,24 +337,9 @@ bool AlphaFilter::exec ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage &im
     else
       augmentAlpha ( (int)(fDeltaA * t), filterImage, imgStart, imgStop, result );
 
-    // And at the end we will add this to the VOB compliant video TS
-    switch ( audioTrans )  {
-    case VolumeNull:
-      fVolume = 0.0f;
-    break;
-    case VolumeUp:
-      fVolume = (float)t / iNumberOfImages;
-    break;
-    case VolumeDown:
-      fVolume = 1.0f  - (float)t / iNumberOfImages;
-    break;
-    default:
-      fVolume = 1.0f;
-    }
-    pEncoder->addImage ( &result, 1, fVolume );
+    encode ( pEncoder, result, (float)t/iNumberOfImages, audioTrans );
   }
-
-  return false;
+  return true; //false;
 }
 
 void AlphaFilter::augmentAlpha ( int iDeltaA, int iDeltaB, QImage &filter, QImage &start, QImage &stop, QImage &result, QImage *pBackground )
@@ -347,6 +414,114 @@ void AlphaFilter::augmentAlpha ( int iDeltaA, QImage &filter, QImage &start, QIm
   }
 }
 
+bool AlphaFilter::execKB ( Encoder::FFmpeg *pEncoder, QImage &imgStart, QImage &imgStop, int iNumberOfImages, enAudioTrans audioTrans, QImage *pBackground )
+{
+  // If no user selection, then we'll have to randomly get one ...
+  QString qsTransitionPath =  + SYSTEM_DIRECTORY + QString ( "/share/qdvdauthor/slideshow/transitions/alpha/" );
+  QString qsFilterName, qsBaseName, qsExt;
+
+  if ( m_qsFilterName.size ( ) < 1 )  {
+    QStringList listOfFilter = getFilterNames ( );
+    if ( listOfFilter.count ( ) < 1 )  {  // Alpha filter are missing from the system. Default to XFade Filter
+      CrossFadeFilter alternate;
+      return alternate.exec ( pEncoder, imgStart, imgStop, iNumberOfImages, audioTrans, pBackground );
+    }
+    int iFilter = (int)( ( (float)rand ( ) / RAND_MAX ) * listOfFilter.count ( ) );
+    qsBaseName  = listOfFilter[iFilter];
+  }
+  else
+    qsBaseName = m_qsFilterName;
+
+  qsExt = ".jpg";
+  qsFilterName = qsTransitionPath + qsBaseName + qsExt;
+
+  QFile  filter ( qsFilterName );
+  if ( ! filter.exists ( ) )  {
+    qsTransitionPath =  + SYSTEM_DIRECTORY + QString ( "/share/qdvdauthor/slideshow/transitions/luma/" );
+    qsExt = ".png"; // Luma directory contains only png's
+    qsFilterName = qsTransitionPath + qsBaseName + qsExt;
+  }
+  filter.setFileName ( qsFilterName );
+  if ( ! filter.exists ( ) )  {
+    CrossFadeFilter alternate;
+    return alternate.exec ( pEncoder, imgStart, imgStop, iNumberOfImages, audioTrans, pBackground );
+  }
+  QImage filterImage ( qsFilterName );
+  filterImage = filterImage.scaled ( imgStart.size ( ), Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
+  filterImage = filterImage.convertToFormat ( QImage::Format_RGB32, Qt::AutoColor | Qt::DiffuseDither );
+
+  // At this point the filter, start, and end image must have all the same size.
+  if ( ( filterImage.size ( ) != imgStart.size ( ) ) ||
+       ( filterImage.size ( ) != imgStop.size  ( ) ) )  {
+    CrossFadeFilter xFilter;
+    return xFilter.exec ( pEncoder, imgStart, imgStop, iNumberOfImages, audioTrans );
+  }
+
+  // Both start and end image have to set the KenBurns properly.
+  Utils theUtils;
+  int iStartImage[2], iEndImage[2], iTotalImages[2];
+  // Lets start with Start
+  iStartImage[0]  = 0; // unused
+  iEndImage[0]    = m_iTotalImages[0] - iNumberOfImages;
+  iTotalImages[0] = m_iTotalImages[0];
+  // and continue with Stop
+  iStartImage[1]  = 0; // unused
+  iEndImage[1]    = m_iTotalImages[1] - iNumberOfImages;
+  iTotalImages[1] = m_iTotalImages[1];
+
+  int    t;
+  float  fDeltaA;
+  QImage result ( filterImage.size ( ), QImage::Format_RGB32 );
+  QImage imgStart1, imgStop1, *pImgStart, *pImgStop;
+  KenBurnsFilter kb;
+
+  QString  qsFileName = m_kenBurns[0].src;
+  QImage   origImage1  ( qsFileName );
+  qsFileName = m_kenBurns[1].src;
+  QImage   origImage2  ( qsFileName );
+
+  // Each step the alpha value of each pixel is increased / decreased by this much
+  int  iDiff = 0;
+  if ( pBackground )  {
+    iDiff = 25; // this is the gap between start, and end image, which will be filled with the background
+    if ( iNumberOfImages < iDiff * 2 )
+         iDiff = (int)( (float)iNumberOfImages / 2.0f );
+  }
+  fDeltaA   = 512.0f / ( iNumberOfImages - iDiff - 1 );
+
+  bool bStartKenBurns = ( m_kenBurns[0].effect[0].name == EFFECT_TYPE_KENBURNS );
+  bool bStopKenBurns  = ( m_kenBurns[1].effect[0].name == EFFECT_TYPE_KENBURNS );
+
+  if ( m_kenBurns[0].pMatrix )
+       origImage1 = origImage1.transformed ( *m_kenBurns[0].pMatrix, Qt::SmoothTransformation );
+  if ( m_kenBurns[1].pMatrix )
+       origImage2 = origImage2.transformed ( *m_kenBurns[1].pMatrix, Qt::SmoothTransformation );
+
+  for ( t=0; t<iNumberOfImages; t++ )  {
+    pImgStart = &imgStart;
+    pImgStop  = &imgStop;
+    if ( ( m_iTotalImages[0] != 0 ) && ( bStartKenBurns ) )  { // m_kenBurns based on original img size ...
+      kb.exec ( origImage1, &m_kenBurns[0].effect[0], imgStart1, iEndImage[0] + t, iTotalImages[0] );
+      theUtils.prescaleImage ( imgStart1, m_iAspectRatio );
+      theUtils.frameImage ( imgStart1, filterImage.width ( ), filterImage.height ( ), &m_background, NULL );
+      pImgStart = &imgStart1;
+    }
+    if ( ( m_iTotalImages[1] != 0 ) && ( bStopKenBurns ) )  {
+      kb.exec ( origImage2, &m_kenBurns[1].effect[0], imgStop1, iStartImage[1] + t, iTotalImages[1] );
+      theUtils.prescaleImage ( imgStop1, m_iAspectRatio );
+      theUtils.frameImage ( imgStop1, filterImage.width ( ), filterImage.height ( ), &m_background, NULL );
+      pImgStop = &imgStop1;
+    }
+    if ( pBackground )
+      augmentAlpha ( (int)(fDeltaA * t), (int)(fDeltaA * (t-iDiff)), filterImage, *pImgStart, *pImgStop, result, pBackground );
+    else
+      augmentAlpha ( (int)(fDeltaA * t), filterImage, *pImgStart, *pImgStop, result );
+
+    encode ( pEncoder, result, (float)t/iNumberOfImages, audioTrans );
+  }
+  return true;
+}
+
 QStringList AlphaFilter::getFilterNames ( )
 {
   QStringList list;
@@ -367,3 +542,4 @@ QStringList AlphaFilter::getFilterNames ( )
 }
 
 }; // end of namespace Render
+
