@@ -58,7 +58,7 @@ check_qt_dir4 ()
 
   if [ -z "$QTDIR4" ]
   then
-    qtPaths="/usr /usr/local /usr/lib64 /usr/lib /usr/share /usr/local/lib64 /usr/local/lib";
+    qtPaths="/usr/lib64 /usr/lib /usr/share /usr/local/lib64 /usr/local/lib /usr /usr/local";
     for thePath in $qtPaths
     do
       find_qt_dir4 $thePath
@@ -74,7 +74,14 @@ QMAKE=qmake
 check_qt_dir4
 
 if [ "x$QTDIR4" == "x" ]; then
-  QMAKE=qmake
+  # Unfortunately Fedora decided to rename qake for qt4
+  QMAKE=qmake-qt4
+  check_qt_dir4
+  if [ "x$QTDIR4" == "x" ]; then
+    QMAKE=qmake
+  else
+    QMAKE=$QTDIR4/bin/qmake-qt4
+  fi;
 else
   QMAKE=$QTDIR4/bin/qmake
 fi
@@ -95,12 +102,29 @@ then
   exit -1
 fi;
 
+buildQRender ()
+{
+  make clean
+
+  $QMAKE -o Makefile.tmp qrender.pro;
+  sed "10 s,^,QTDIR = $QTDIR\n," Makefile.tmp > Makefile
+
+  make -j $CORES
+}
+
+# If the user chooses to link dynamically against ffmpeg
+# we do not need/want to get the latest ffmpeg library,
+# but instead use the system ffmpeg.
+if [ "x$STATIC_FFMPEG" == "x" ] || [ "x$STATIC_FFMEPG" == "x1" ]; then
+  buildQRender
+  exit 0
+fi;
 
 # The 0.5 release from March 2009
 # theLib="http://ffmpeg.mplayerhq.hu/releases/ffmpeg-0.5.tar.bz2"
 
 # Or the latest source from svn/git
-theLib="http://ffmpeg.mplayerhq.hu/releases/ffmpeg-export-snapshot.tar.bz2"
+theLib="http://ffmpeg.mplayerhq.hu/releases/ffmpeg-snapshot.tar.bz2"
 theFile=`basename $theLib`
 
 echo
@@ -127,13 +151,15 @@ then
 fi;
 
 # One little hack to avoid breaking this build if ffmpeg changes 
-whichLib=`wget --spider http://qdvdauthor.sf.net/ffmpeg_location.txt 2>&1 | grep "200 OK"`
+#whichLib=`wget --spider http://qdvdauthor.sf.net/ffmpeg_location.txt 2>&1 | grep "200 OK"`
 if [ "x$whichLib" != "x" ]; 
 then
+  if [ -f ffmpeg_location.txt ]; then
+    rm ffmpeg_location.txt
+  fi;
   # Found a workaround library. Now lets get the location and run with it.
   wget http://qdvdauthor.sf.net/ffmpeg_location.txt
-  if [ -f ffmpeg_location.txt ];
-  then
+  if [ -f ffmpeg_location.txt ]; then
     theLib=`cat ffmpeg_location.txt`
   fi;
 fi;
@@ -164,34 +190,47 @@ else
   fi;
   bzip2 -d $theFile
   theFile=`basename $theFile .bz2`
+  if [ -d ffmpeg ]; then 
+    # This could be differet than the $extractDir
+    rm ffmpeg -rf
+  fi;
   extractDir=`tar --list -f $theFile | grep INSTALL | sed "s/\\/INSTALL$//"`
+  if [ -d "$extractDir" ]; then
+    rm -r "$extractDir"
+  fi;
   tar -xf $theFile
-  if [ -e ffmpeg ]; then
+  if [[ -e ffmpeg && -L ffmpeg ]]; then
     rm ffmpeg
   fi;
-  ln -s "$extractDir" ffmpeg
+  if [ "xffmpeg" != x"$extractDir" ]; then
+    ln -s "$extractDir" ffmpeg
+  fi;
 fi;
 
 cd ffmpeg
 #./configure --prefix=/home/varol/utils/ffmpeg --enable-gpl --enable-nonfree --enable-shared --enable-static
 #./configure --prefix="`pwd`" --enable-gpl --enable-swscale --enable-static --enable-shared
-./configure --prefix="`pwd`" --enable-gpl --enable-static --enable-shared
+hasCrystal=`grep crystalhdd configure`
+if [ "x" == "x$hasCrystal" ]; then
+  ./configure --prefix="`pwd`" --enable-gpl --enable-static --enable-shared
+else
+  ./configure --prefix="`pwd`" --enable-gpl --enable-static --enable-shared --disable-crystalhd
+fi
 
 make -j $CORES && make install
 
 # At this point the static libraries should have been built
 
 # one last thing to do is to copy the header files to the include/ffmpeg directory
+if [ ! -d include ]; then
+  mkdir include 
+fi;
+
 cd include
 mkdir ffmpeg
 cp `find . -name "*.h"` ffmpeg/
 
 # and lastly we should clean qrender and re-build it
 cd ../..
-make clean 
-
-$QMAKE -o Makefile.tmp qrender.pro;
-sed "10 s,^,QTDIR = $QTDIR\n," Makefile.tmp > Makefile
-
-make -j $CORES 
+buildQRender
 
