@@ -21,6 +21,8 @@
 #include "parser.h"
 #include "logger.h"
 
+Render::Server *g_pServer = NULL;
+
 int main ( int argc, char *argv[] )
 {
   QApplication app ( argc, argv );
@@ -49,6 +51,7 @@ int main ( int argc, char *argv[] )
   Render::Server server;
   server.setLogInfo ( parser.getLogLevel ( ), parser.getLogfileName ( ) );
   logger.setLogInfo ( parser.getLogLevel ( ), parser.getLogfileName ( ) );
+  g_pServer = &server;
 
   if ( ! server.listen ( QHostAddress::Any, parser.getServerPort ( ) ) )  {
     // QRender is most likely alreadyt running in the background. So this is not an error per-se
@@ -57,11 +60,12 @@ int main ( int argc, char *argv[] )
   }
   else  {
     if ( ! parser.isTTY ( ) )
-      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] in deamon mode, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
+      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] <%016%p> in deamon mode, Listening to port : %d\n\n", (int)iPid+1, g_pServer, parser.getServerPort ( ) );
     else
-      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] in the foreground, Listening to port : %d\n\n", (int)iPid+1, parser.getServerPort ( ) );
+      logger.log ( Render::Logger::logInformation, "\nStarting QRender[%d] <%016%p>in the foreground, Listening to port : %d\n\n", (int)iPid+1, g_pServer, parser.getServerPort ( ) );
     return app.exec ( );
   }
 
   return -1;
 }
+
