@@ -34,10 +34,11 @@ namespace Render
 
 Parser::Parser ( )
 {
-  m_bTTY        = false;  // default is to deamonize
-  m_iLogLevel   = 3; // Anything warning and above
-  m_iServerPort = SERVER_PORT;
-  m_qsTempPath  = QDir::tempPath ( ) + "/qrender/";
+  m_iRegionalZone = -1;     // No Zone.
+  m_bTTY          = false;  // default is to deamonize
+  m_iLogLevel     = 3;      // Anything warning and above
+  m_iServerPort   = SERVER_PORT;
+  m_qsTempPath    = QDir::tempPath ( ) + "/qrender/";
 }
 
 Parser::~Parser ( )
@@ -47,7 +48,7 @@ Parser::~Parser ( )
 bool Parser::parseCommandLine ( int iArgs, char *pArguments[] )
 {
   bool bImportDVDSlideshow = false;
-  int iChar = NULL;
+  int iChar = 0;
 
   // The default log file name
   m_qsLogFileName = QDir::tempPath ( ) + "/qrender/log.txt";
@@ -61,6 +62,8 @@ bool Parser::parseCommandLine ( int iArgs, char *pArguments[] )
     { "port",    required_argument, 0, 'p' },
     { "log",     required_argument, 0, 'l' },
     { "tty",     no_argument,       0, 't' },
+    { "zone",    required_argument, 0, 'z' },
+    { "path",    required_argument, 0, 'a' },
     { 0, 0, 0, 0 } };
 
   while ( true ) {
@@ -92,6 +95,12 @@ bool Parser::parseCommandLine ( int iArgs, char *pArguments[] )
       case 't':
         m_bTTY = true;
       break;
+      case 'z':
+        m_iRegionalZone = atoi ( optarg );
+      break;
+      case 'a':
+        m_qsPath = QString ( optarg );
+      break;
       case 'f':
         printFilter ( );
         return true;
@@ -129,6 +138,16 @@ int Parser::getLogLevel ( )
   return m_iLogLevel;
 }
 
+int Parser::getRegionalZone ( )
+{
+  return m_iRegionalZone;
+}
+
+QString Parser::getPath ( )
+{
+  return m_qsPath;
+}
+
 QString Parser::getLogfileName ( )
 {
   return m_qsLogFileName;
@@ -178,7 +197,7 @@ bool Parser::createSlideshow ( )
   if ( ! xmlSlide.readXml ( m_qsInputName, false ) )
     return true;  // Error happend.
 
-  Slideshow slide;
+  Slideshow slide   ( this );
   slide.initMe      ( &xmlSlide, m_qsTempPath );
   slide.setFileName ( m_qsOutputName );
   if  (  slide.exec ( ) )  {
