@@ -33,11 +33,13 @@
 #include "utils.h"
 #include "shared.h"
 #include "render.h"
+#include "server.h"
 #include "slideshow.h"
 
 // Note: Maybe later on I can import dvd-slideshow config files
 #include "../qdvdauthor/xml_slideshow.h"
 
+extern Render::Server *g_pServer;
 
 namespace Render
 {
@@ -65,13 +67,14 @@ Render::Render ( int iSocketDescriptor, QObject *pParent )
   m_logger.setLogInfo ( 3, qsLogFile    );
   m_logger.setLogObjectInfo ( true );
 //printf ( "QRender::QRender <%p> thread<%X>\n", this, pthread_self ( ) );
+  m_pTcpSocket = new QTcpSocket; 
 
-  if ( ! m_tcpSocket.setSocketDescriptor ( m_iSocketDescriptor ) )  {
-      emit ( error ( m_tcpSocket.error ( ) ) );
+  if ( ! m_pTcpSocket->setSocketDescriptor ( m_iSocketDescriptor ) )  {
+      emit ( error ( m_pTcpSocket->error ( ) ) );
       return;
   }
 
-  connect ( &m_tcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
+  connect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
   connect ( this,         SIGNAL ( finished  ( ) ), this, SLOT ( slotExiting    ( ) ) );
 }
 
@@ -79,9 +82,24 @@ Render::~Render ( )
 {
   if ( m_pSlideshow )
     delete m_pSlideshow;
+  if ( m_pTcpSocket )
+    delete m_pTcpSocket;
+  m_pTcpSocket = NULL;
   logger ( ).iLOG ( "Render::~Render <%p>\n", this );
 }
 
+QTcpSocket *Render::switchSockets ( QTcpSocket *pTakeMe )
+{
+  if ( pTakeMe && m_pTcpSocket )  {
+    disconnect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
+    QTcpSocket *pOldSocket = m_pTcpSocket;
+    m_pTcpSocket = pTakeMe;
+    connect ( m_pTcpSocket, SIGNAL ( readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
+    return pOldSocket;
+  }
+  return pTakeMe;
+}
+
 void Render::run ( )
 {
   // Kick off the pinger ...
@@ -108,7 +126,7 @@ void Render::run ( )
 
 void Render::slotReadSocket ( )
 {
-  qint64 iBytesAvail = m_tcpSocket.bytesAvailable ( );
+  qint64 iBytesAvail = m_pTcpSocket->bytesAvailable ( );
 //printf ( "iBytesAvail<0x%016llX>\n", iBytesAvail );
   if  (  iBytesAvail <= 0 )
     return;
@@ -119,7 +137,7 @@ void Render::slotReadSocket ( )
       if ( iBytesAvail   < 10 )
         return;
       // Okay we have yet to see what message we just received
-      QDataStream ds ( &m_tcpSocket );
+      QDataStream ds ( m_pTcpSocket );
       ds >> m_iMessageID;
       ds >> m_iMessageLen;
       iBytesAvail -= 10;
@@ -146,6 +164,14 @@ void Render::slotReadSocket ( )
       exit ( CLIENT_GO_TO_WORK );  // will leave exec and continue in background thread ( in function run )
 //      createSlideshow ( );
     break;
+    case CLIENT_I_LOST_CONTACT:
+      // A new connection was established and this Render-object may not be the 
+      // original one, which is still rendering the slideshow in the background.
+      // Need to re-connect the two, in order to continue with the progress display
+      // in QDVDAuthor.
+      if ( receivedSearchWarrant ( ) )
+        exit ( );
+    break;
     case CLIENT_GOT_A_PIECE:
       sendNextPacket ( );
     break;
@@ -164,18 +190,18 @@ void Render::slotReadSocket ( )
     }      // end switch statement
     m_iMessageID  = 0;
     m_iMessageLen = 0;
-    iBytesAvail = m_tcpSocket.bytesAvailable ( );
+    iBytesAvail = m_pTcpSocket->bytesAvailable ( );
   }
 }
 
 void Render::myExit ( int iExitCode )
 {
-  m_tcpSocket.flush   ( );
-  m_tcpSocket.disconnectFromHost ( );
+  m_pTcpSocket->flush   ( );
+  m_pTcpSocket->disconnectFromHost ( );
   qApp->processEvents ( );
 
-  if ( m_tcpSocket.state ( ) != QAbstractSocket::UnconnectedState )
-       m_tcpSocket.waitForDisconnected ( 5000 );  // wait for up to 5 seconds to be disconnected
+  if ( m_pTcpSocket->state ( ) != QAbstractSocket::UnconnectedState )
+       m_pTcpSocket->waitForDisconnected ( 5000 );  // wait for up to 5 seconds to be disconnected
   qApp->processEvents ( );
 
   QThread::exit ( iExitCode );
@@ -190,9 +216,9 @@ bool Render::killClient ( )
 
 void Render::sendProgress ( float fProgress )
 {
-  logger ( ).dLOG ( " <%f>\n", fProgress );
+  logger ( ).dLOG ( "Progress <%f>\n", fProgress );
   status ( ).log  ( "PROGRESS:%f\n", fProgress );
-  if ( m_tcpSocket.state ( ) != QAbstractSocket::ConnectedState )
+  if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
     return;
 
   QByteArray block;
@@ -202,8 +228,8 @@ void Render::sendProgress ( float fProgress )
           Message<double>::create  ( (double)fProgress );
 
   // Send progress message
-  m_tcpSocket.write ( block );
-  m_tcpSocket.flush ( );
+  m_pTcpSocket->write ( block );
+  m_pTcpSocket->flush ( );
 }
 
 bool Render::isLocalServer ( )
@@ -223,11 +249,11 @@ Logger &Render::status ( )
 
 void Render::sendMessage ( quint16 iMessageID, QString qsMessage )
 {
-  if ( m_tcpSocket.state ( ) != QAbstractSocket::ConnectedState )
+  if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
     return;
 
-  m_tcpSocket.write  ( Message<quint16>::create ( iMessageID ) );
-  m_tcpSocket.write  ( Message<quint64>::create ( (quint64)qsMessage.length ( ) ) );
+  m_pTcpSocket->write  ( Message<quint16>::create ( iMessageID ) );
+  m_pTcpSocket->write  ( Message<quint64>::create ( (quint64)qsMessage.length ( ) ) );
 
 /*
 quint64 iLen = (quint64)qsMessage.length ( );
@@ -235,10 +261,10 @@ char *cLen = (char *)&iLen;
 printf ( "%s::%d > len<%llu> [%02x %02x %02x %02x]\n", __FILE__, __LINE__, iLen, cLen[0], cLen[1], cLen[2], cLen[3] );
 */
 
-  QDataStream stream ( &m_tcpSocket );
+  QDataStream stream ( m_pTcpSocket );
   stream << qsMessage;
 
-  m_tcpSocket.flush ( );
+  m_pTcpSocket->flush ( );
 }
 
 void Render::sendVersionAndHost ( )
@@ -246,7 +272,7 @@ void Render::sendVersionAndHost ( )
   QString qsClientHost;
   char cHostName[1024];
   quint16 iMessageID = SERVER_ITS_ME_AND_I_AM_AT;
-  QDataStream stream   ( &m_tcpSocket    );
+  QDataStream stream   ( m_pTcpSocket    );
   // At this point the socket shoould still have the hostname of the client intus.
   stream >> qsClientHost;
 
@@ -266,7 +292,7 @@ void Render::sendVersionAndHost ( )
   // And finally notify the client about our location and age.
   stream << iMessageID << (quint64)( qsHostName.length ( ) + qsVersion.length ( ) );
   stream << qsHostName << qsVersion;
-  m_tcpSocket.flush ( );
+  m_pTcpSocket->flush ( );
 }
 
 void Render::sendServerState ( bool bSameSlideshow )
@@ -283,7 +309,7 @@ void Render::sendServerState ( bool bSameSlideshow )
   // And finally notify the client about our location and age.
   sendMessage ( SERVER_MY_STATUS_SIRE, qsState );
 
-  m_tcpSocket.flush  ( );
+  m_pTcpSocket->flush  ( );
 }
 
 bool Render::sendFile ( QString qsFileName )
@@ -291,7 +317,7 @@ bool Render::sendFile ( QString qsFileName )
   if ( m_pFile )
     return false;
 
-  if ( m_tcpSocket.state ( ) != QAbstractSocket::ConnectedState )
+  if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
     return false;
 
   m_pFile = new QFile ( qsFileName );
@@ -307,13 +333,13 @@ bool Render::sendFile ( QString qsFileName )
   status ( ).log  ( "SIZE:%lld\n", m_pFile->size ( ) );
   // This will kick off the sendPacket protocol until the whole file is transmittet.
   QByteArray cString = qsFileName.toUtf8 ( );
-  m_tcpSocket.write  ( Message<quint16>::create ( SERVER_TAKE_A_FILE ) );
-  m_tcpSocket.write  ( Message<quint64>::create ( (quint64)m_pFile->size ( ) ) );
+  m_pTcpSocket->write  ( Message<quint16>::create ( SERVER_TAKE_A_FILE ) );
+  m_pTcpSocket->write  ( Message<quint64>::create ( (quint64)m_pFile->size ( ) ) );
 
-  QDataStream stream ( &m_tcpSocket );
+  QDataStream stream ( m_pTcpSocket );
   stream << qsFileName;
 
-  m_tcpSocket.flush  ( );
+  m_pTcpSocket->flush  ( );
 
   return true;
 }
@@ -326,13 +352,13 @@ void Render::sendNextPacket ( )
 
   qint64 iLen  = m_pFile->read ( data, BLOCK_LEN );
   if (   iLen != -1 )  {
-    m_tcpSocket.write (  data, iLen );
+    m_pTcpSocket->write (  data, iLen );
     qint64 iPos   = m_pFile->pos  ( );
     qint64 iSize  = m_pFile->size ( );
 
     if ( iPos >= iSize  ) {
       m_pFile->close    ( );
-      m_tcpSocket.flush ( );
+      m_pTcpSocket->flush ( );
       logger ( ).iLOG ( " Finished <%s> WAKE ALL\n", (const char *)m_pFile->fileName ( ).toAscii ( ) );
       status ( ).log  ( "VIDEO DONE\n" );
       delete m_pFile;
@@ -350,7 +376,7 @@ void Render::sendNextPacket ( )
 
 void Render::slotExiting ( )
 {
-  logger ( ).dLOG ( "\n" );
+  logger ( ).dLOG ( "Exiting\n" );
   emit   ( signalIAmDone ( this ) );
   QThread::deleteLater   ( );
 }
@@ -358,13 +384,13 @@ void Render::slotExiting ( )
 void Render::timerEvent ( QTimerEvent *pEvent )
 {
   if ( pEvent->timerId ( ) == m_iTimerID )  {
-    if ( m_tcpSocket.state ( ) != QAbstractSocket::ConnectedState )
+    if ( m_pTcpSocket->state ( ) != QAbstractSocket::ConnectedState )
       return;
 
     logger ( ).iLOG ( " PING \n");
     // Every 20 seconds we'll send out a short ping.
-    m_tcpSocket.write  ( Message<quint16>::create ( SERVER_I_AM_ALIVE ) );
-    m_tcpSocket.flush  ( );
+    m_pTcpSocket->write  ( Message<quint16>::create ( SERVER_I_AM_ALIVE ) );
+    m_pTcpSocket->flush  ( );
   }
 }
 
@@ -373,7 +399,7 @@ quint64 Render::fileFromSocket ( )
   if ( ! m_pFile )  {
     Utils theUtils;
     QString qsFileName;
-    QDataStream ds ( &m_tcpSocket );
+    QDataStream ds ( m_pTcpSocket );
     ds >> qsFileName;
     // printf ( "Render::fileFromSocket <%s>\n", (const char *)qsFileName.toAscii ( ) );
     // Store under e.g. /tmp/qrender/MySlide/MySlide.xml
@@ -396,7 +422,7 @@ quint64 Render::fileFromSocket ( )
     logger ( ).iLOG ( "Render::fileFromSocket new <%s> size<%lld> msgLen<%lld>\n", (const char *)m_pFile->fileName ( ).toUtf8 ( ), m_pFile->size  ( ), m_iMessageLen );
   }
 
-  qint64 iBytesAvailable = m_tcpSocket.bytesAvailable ( );
+  qint64 iBytesAvailable = m_pTcpSocket->bytesAvailable ( );
   quint64 iFileSize = (quint64)m_pFile->size ( );
   quint64 iDelta    = 0LL;
   if ( iFileSize + iBytesAvailable > m_iMessageLen )  {
@@ -406,12 +432,12 @@ quint64 Render::fileFromSocket ( )
   }
 
   QByteArray data ( iBytesAvailable, 0 );
-  qint64 iActualRead = m_tcpSocket.read ( data.data ( ), iBytesAvailable );
+  qint64 iActualRead = m_pTcpSocket->read ( data.data ( ), iBytesAvailable );
   m_pFile->write  ( data.data ( ), iActualRead );
 
   // Let the Client know that I am ready for the next image.
-  m_tcpSocket.write ( Message<quint16>::create ( SERVER_GOT_A_PIECE ) ); 
-  m_tcpSocket.write ( Message<quint64>::create ( (quint64)m_pFile->size ( ) ) );
+  m_pTcpSocket->write ( Message<quint16>::create ( SERVER_GOT_A_PIECE ) ); 
+  m_pTcpSocket->write ( Message<quint64>::create ( (quint64)m_pFile->size ( ) ) );
 
 //printf ( "Render::fileFromSocket <%s> size<%lld> msgLen<%lld>\n", (const char *)m_pFile->fileName ( ).toUtf8 ( ), m_pFile->size  ( ), m_iMessageLen );
   if ( m_pFile->size  ( )  >=  (qint64)m_iMessageLen )  {
@@ -430,7 +456,7 @@ quint64 Render::fileFromSocket ( )
        m_iMessageID  = 0;
        m_iMessageLen = 0;
   }
-  m_tcpSocket.flush ( );
+  m_pTcpSocket->flush ( );
 //printf ( "Render::fileFromSocket Avail<%lld> read<%lld> delta<%lld>\n", iBytesAvailable, iActualRead, iDelta );
   return ( iBytesAvailable - iActualRead + iDelta );
 }
@@ -443,7 +469,7 @@ void Render::receivedReconnect ( )
 //  qint64  iBytesAvail = m_tcpSocket.bytesAvailable ( );
   quint16 iLength;
 
-  QDataStream ds ( &m_tcpSocket );
+  QDataStream ds ( m_pTcpSocket );
   ds >> iLength;
   ds >> qsName;
 
@@ -455,7 +481,7 @@ void Render::receivedReconnect ( )
 void Render::receivedXMLName ( )
 {
   QString qsFileName, qsTempPath;
-  QDataStream ds ( &m_tcpSocket );
+  QDataStream ds ( m_pTcpSocket );
   ds >> qsFileName >> qsTempPath;
 
   m_qsClientTempPath  = qsTempPath;
@@ -465,6 +491,24 @@ void Render::receivedXMLName ( )
   status ( ).log  ( "GOT XML\n" );
 }
 
+bool Render::receivedSearchWarrant ( )
+{
+  QString qsFileName, qsTempPath;
+  QDataStream ds ( m_pTcpSocket );
+  ds >> qsFileName;
+
+  quint64 iHash  = createXMLHash ( qsFileName );
+  Render *pOther = g_pServer->findSlideshowThread ( iHash, this );
+  if ( pOther )  {
+    disconnect ( m_pTcpSocket,   SIGNAL  (readyRead ( ) ), this, SLOT ( slotReadSocket ( ) ) );
+    m_pTcpSocket = pOther->switchSockets ( m_pTcpSocket );
+  }
+  logger ( ).iLOG ( "Searching Server Soul for <%s> Server has %srunning thread for it\n", (const char *)qsFileName.toUtf8 ( ), pOther ? "a " : "no " );
+  logger ( ).iLOG ( "Server <%016p> Render<%016p> thread<%lu>\n", g_pServer, this, pthread_self ( ) );
+  status ( ).log  ( "Searching For running Slideshow\n" );
+  return ( pOther != NULL );
+}
+
 QString Render::getHashName ( QString &qsFileName )
 {
   // If server and client are on the same box, then we can simply use the original file
@@ -480,6 +524,11 @@ QString Render::getHashName ( QString &qsFileName )
   unsigned long long iHashValue = theUtils.SDBMHash ( qsFileName );
   qsHash.sprintf ( "%016llX", iHashValue );
   qsHashFileName = m_qsTempPath + qsHash + "." + qsExt;
+  fileInfo.setFile ( qsHashFileName );
+  if ( ! fileInfo.exists ( ) )  {
+    QString qsFile = qsFileName;
+    return  qsFile;
+  }
   return qsHashFileName;
 }
 
@@ -512,6 +561,11 @@ quint64 Render::createXMLHash ( QString qsFileName )
   return iXMLHash;
 }
 
+quint64 Render::hash ( )
+{
+  return m_iXMLHash; 
+}
+
 bool Render::loadSlideshowXML ( QString qsFileName )
 {
   bool bReturn = true;
@@ -526,7 +580,7 @@ bool Render::loadSlideshowXML ( QString qsFileName )
     }
   }
 
-logger ( ).iLOG ( "Create Slideshow object(Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), m_iXMLHash );
+  logger ( ).iLOG ( "Create Slideshow object(Hash=<0x%016llX>)\n", (const char *)qsFileName.toAscii ( ), m_iXMLHash );
   m_pSlideshow = new CXmlSlideshow;
   m_pSlideshow->readXml ( qsFileName, false );
 
