@@ -30,12 +30,13 @@ public:
     Server ( QObject *p=NULL );
 
     void setLogInfo ( int, QString );
+    Render *findSlideshowThread ( quint64, Render * );
 
 protected:
     void incomingConnection(int socketDescriptor);
 
 protected slots:
-    virtual void slotRenderExited ( Render * );
+    virtual void slotRenderExited ( ::Render::Render * );
 
 private:
     QList<Render *> m_listOfRenderTasks;
