@@ -1,13 +1,14 @@
 /****************************************************************************
-** Class Utils implementation ...
+** Class Slideshow implementation ...
 **
 **   Created : Wed Jun 17 07:53:05 2008
 **        by : Varol Okan
 ** Copyright : (c) Varol Okan
 **   License : GPL v 2.0
 **
-** Here we have some misc functions which are needed by a few classes 
-** but can not really be assigned to any of those classes.
+** This class takes care of actually rendering the slideshow.
+** It will take the inut data collected in XmlSlideshow
+** and use ffmpeg to generate the slideshow accordingly.
 **
 ****************************************************************************/
 
@@ -83,7 +84,7 @@ void Slideshow::displayProgress ( float fProgress )
 
 void Slideshow::log ( QString qsLogMessage, int iLogLevel )
 {
- if ( m_pParent )  {
+  if ( m_pParent )  {
     if ( m_pParent->logger ( ).logLevel ( ) <= iLogLevel )
          m_pParent->logger ( ).LOG ( (Logger::type)iLogLevel, (const char *)qsLogMessage.toUtf8 ( ) );
   }
@@ -100,6 +101,36 @@ QString Slideshow::getHashName ( QString qsInput )
   return qsInput;
 }
 
+float Slideshow::getFilterDuration ( CXmlSlideshow::img_struct *pXmlImage )
+{
+  if ( ! pXmlImage )
+    return (float)m_pSlideshow->filter_delay;
+
+  float fDuration  = 0.0f;
+  if  ( pXmlImage->pTransition ) // transitions duration will overwrite global slideshow filter duration
+        fDuration  = (float)pXmlImage->pTransition->fDuration;
+  if  ( fDuration <= 0.0f )
+        fDuration  = (float)m_pSlideshow->filter_delay;
+  if  ( fDuration <= 0.0f )
+        fDuration  = 3.0f;
+  fDuration *= 1000.0f; // in mSeconds please.
+  return fDuration;
+}
+
+float Slideshow::getDuration ( CXmlSlideshow::img_struct *pXmlImage )
+{
+  if ( ! pXmlImage )
+    return (float)m_pSlideshow->delay;
+
+  float fDuration = pXmlImage->fDuration;
+  if (  fDuration < 0.0f )
+        fDuration = (float)m_pSlideshow->delay;
+  if (  fDuration < 0.0f )
+        fDuration = 5.0f;
+  fDuration *= 1000.0f; // in mSeconds please.
+  return fDuration;
+}
+
 void Slideshow::prescaleImage ( QImage &theImage )
 {
   float fAspect = 720.0/480.0 / ( 16.0/9.0 );
@@ -117,6 +148,9 @@ void Slideshow::prescaleImage ( QImage &theImage )
   theImage      = theImage.scaled ( iWidth, iHeight, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
 }
 
+// Main function to generate the slideshow.
+// This function will iterate through the images and videos and generate the appropriate
+// transitions, and KenBurns effects ( images only )
 bool Slideshow::exec ( )
 {
   if ( ! m_pSlideshow )
@@ -144,6 +178,7 @@ bool Slideshow::exec ( )
   if ( enFormat == Encoder::Encoder::vfPAL )
     fFPS = 25.0;
 
+  displayProgress ( 0.0001f );
   CXmlSlideshow::img_struct  *pXmlStart = createStartEnd (  true );
   CXmlSlideshow::img_struct  *pXmlEnd   = createStartEnd ( false );
   CXmlSlideshow::img_struct  *pXmlCurrent, *pXmlPrevious;
@@ -159,12 +194,12 @@ bool Slideshow::exec ( )
     theEncoder.setVideoParam ( 6000, Encoder::Encoder::arAspect16to9 );
   theEncoder.initStream      ( m_qsFileName, enFormat, Encoder::Encoder::afAC3, 1000 );
 
-  pXmlPrevious     = pXmlStart;
-  uint t, iCount   = m_pSlideshow->count ( );
-  float fProgress  = 0.0f;
-  float fCount2    = 2.0f * iCount + 2.0f;
-  int iProgress    = 0;
-  int iStart       = 0;
+  pXmlPrevious    = pXmlStart;
+  uint t, iCount  = m_pSlideshow->count ( );
+  float fProgress = 0.0f;
+  float fCount2   = 2.0f * iCount + 2.0f;
+  int iProgress   = 0;
+  int iStart      = 0;
 
   if ( ! m_pSlideshow->intro_page )  {
     // The user chose to skip the intro page with the slideshow title
@@ -173,9 +208,9 @@ bool Slideshow::exec ( )
     fCount2      -= 2.0f;
   }
   if ( ! m_pSlideshow->fade_out )
-    fCount2      -= 2.0f;
+    fCount2      -= 1.0f;
 
-  for  ( t=iStart; t<iCount + (int)m_pSlideshow->fade_out; t++ )  {
+  for  ( t=iStart; t<iCount; t++ )  {
     if ( m_pParent && m_pParent->killClient ( ) )  {
       // The user terminated this slideshow generation
       theEncoder.endStream ( );
@@ -188,6 +223,8 @@ bool Slideshow::exec ( )
     else
       pTimeObject = (CXmlSlideshow::time_object *)pXmlEnd;
     // The frame is to be displayed for a bit ...
+    pXmlCurrent = (CXmlSlideshow::img_struct *)pTimeObject;
+
     if ( pXmlPrevious->node_name == "img" )
       createFromImage ( pXmlPrevious, &theEncoder, fFPS );
     else if ( pXmlPrevious->node_name == "vid" )
@@ -196,9 +233,7 @@ bool Slideshow::exec ( )
       continue;
 
     pXmlCurrent = (CXmlSlideshow::img_struct *)pTimeObject;
-    fProgress = 100.0f * ( (float)iProgress++ / fCount2 );
-    if ( fProgress == 0.0 )
-         fProgress  = 0.0001;
+    fProgress = 100.0f * ( ((float)++iProgress) / fCount2 );
     displayProgress ( fProgress );
     if ( ( pXmlPrevious->node_name == "img" ) && 
          ( pXmlCurrent ->node_name == "img" ) )
@@ -213,17 +248,20 @@ bool Slideshow::exec ( )
               ( pXmlCurrent ->node_name == "vid" ) )
       createVVTransition ( (CXmlSlideshow::vid_struct *)pXmlPrevious, (CXmlSlideshow::vid_struct *)pXmlCurrent, &theEncoder, fFPS );
 
-    fProgress = 100.0f * ( (float)iProgress++ / fCount2 );
+    fProgress = 100.0f * ( (float)++iProgress / fCount2 );
     displayProgress ( fProgress );
 
     pXmlPrevious = pXmlCurrent;
   }
 
   // The frame is to be displayed for a bit ...
-  createFromImage  ( pXmlPrevious, &theEncoder, fFPS );
+  if ( pXmlPrevious->node_name == "img" )
+    createFromImage ( pXmlPrevious, &theEncoder, fFPS );
+  else if ( pXmlPrevious->node_name == "vid" )
+    createFromVid   ( (CXmlSlideshow::vid_struct *)pXmlPrevious, &theEncoder, fFPS );
 
   if ( m_pSlideshow->fade_out )  {
-    fProgress = 100.0f * ( (float)iProgress++ / fCount2 );
+    fProgress = 100.0f * ( (float)++iProgress / fCount2 );
     displayProgress ( fProgress );
     if ( pXmlPrevious->node_name == "img" )
       createIITransition ( pXmlPrevious, pXmlEnd, &theEncoder, fFPS );
@@ -285,8 +323,8 @@ CXmlSlideshow::img_struct *Slideshow::createStartEnd ( bool bStart )
   QFont theFont       ( "Helvetica [Cronyx]", 24, QFont::Bold );
   QImage canvas       (    m_size, QImage::Format_ARGB32_Premultiplied );
   QPainter thePainter (   &canvas );
-  thePainter.setPen   ( QColor ( "#AFAF15" ) ); // Yellow
-  thePainter.setBrush ( QColor ( "#000000" ) );   // Qt::blue );
+  thePainter.setPen   ( QColor ( "#AFAF15" ) );  // Yellow
+  thePainter.setBrush ( QColor ( "#000000" ) );  // Qt::blue );
   thePainter.drawRect ( 0,0,iX,iY );
   thePainter.setFont  (   theFont );
 
@@ -308,6 +346,8 @@ CXmlSlideshow::img_struct *Slideshow::createStartEnd ( bool bStart )
   pXml->src    = qsFileName;
   pXml->width  = iX;
   pXml->height = iY;
+  if ( m_pSlideshow && m_pSlideshow->kenBurns ( ) )
+    pXml->effect[0].randomKenBurns ( 0.5f, iX, iY, true );
   return pXml;
 }
 
@@ -316,39 +356,71 @@ void Slideshow::createFromImage ( CXmlSlideshow::img_struct *pXmlImage, Encoder:
   if ( ! pXmlImage )
     return;
 
+  bool   bKenBurns = ( pXmlImage->effect[0].name == EFFECT_TYPE_KENBURNS );
+  if ( ( bKenBurns ) && ( m_pSlideshow->kenBurns ( ) ) )
+    return createKBFromImage ( pXmlImage, pEncoder, fFPS );
+
   QFileInfo fileInfo ( pXmlImage->src );
   QString qsLog = QString ( "Creating from Image %1\n" ).arg ( fileInfo.fileName ( ) );
   log ( qsLog, Logger::logInformation );
 
-  QPainter thePainter;
+  Utils theUtils;
   QString  qsFileName = getHashName ( pXmlImage->src );
-  QImage   canvas   ( m_size, QImage::Format_ARGB32_Premultiplied );
   QImage   imgStart ( qsFileName );
 
   if ( pXmlImage->pMatrix )
        imgStart = imgStart.transformed ( *pXmlImage->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStart );
-  imgStart = imgStart.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
-
-  int iX, iY;
-  iX = (int)( ( m_size.width  ( ) - imgStart.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStart.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStart, 0, 0 );
-  thePainter.end ( );
-
-  float fDuration = pXmlImage->fDuration;
-  if (  fDuration < 0.0f )
-        fDuration = (float)m_pSlideshow->delay;
-  if (  fDuration < 0.0f )
-        fDuration = 5.0f;
-  fDuration *= 1000.0f; // in mSeconds please.
+  theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
+  float fDuration = getDuration ( pXmlImage );
 
   // And at the end we will add this to the VOB compliant video TS
   int iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
-  pEncoder->addImage ( &canvas, iNumberOfImages );
+  pEncoder->addImage ( &imgStart, iNumberOfImages );
+}
+
+void Slideshow::createKBFromImage ( CXmlSlideshow::img_struct *pXmlImage, Encoder::FFmpeg *pEncoder, double fFPS )
+{
+  // Called to create the KenBurns effect. The start frame is 0, the end frame is
+  if ( ! pXmlImage )
+    return;
+
+  int iFrame;
+  fFPS = fFPS / 1000.0f;
+
+  // Note: a bit more complex as we have to account for the duration of the filter before and after
+  int iStartFrame  = (int)(   getFilterDuration ( pXmlImage ) * fFPS ); // Assumes previous filter length is the same as current filter length
+  int iEndFrame    = (int)(   getDuration ( pXmlImage ) * fFPS ) + iStartFrame;
+  int iTotalFrames = (int)( ( getDuration ( pXmlImage ) + getFilterDuration ( pXmlImage ) * 2.0 ) * fFPS ); // The effect totals both start and end filter length
+
+  if ( ( pXmlImage == m_pSlideshow->getTimeObject ( 0 ) ) && ! m_pSlideshow->intro_page )
+    iStartFrame = 0;
+
+  QFileInfo fileInfo ( pXmlImage->src );
+  QString qsLog = QString ( "Creating KenBurns from Image %1\n" ).arg ( fileInfo.fileName ( ) );
+  log ( qsLog, Logger::logInformation );
+
+  KenBurnsFilter filter;
+  QString qsFileName = getHashName ( pXmlImage->src );
+  Utils   theUtils;
+  QImage  origImage ( qsFileName );
+  if ( pXmlImage->pMatrix )
+       origImage = origImage.transformed ( *pXmlImage->pMatrix, Qt::SmoothTransformation );
+
+  // Make sure we have some kenBurns data avail
+  pXmlImage->effect[0].randomKenBurns ( 0.5f, origImage.width ( ), origImage.height ( ), false );
+  for ( iFrame=iStartFrame; iFrame<iEndFrame; iFrame++ )  {
+    QImage imgStart;
+    filter.exec ( origImage, &pXmlImage->effect[0], imgStart, iFrame, iTotalFrames );
+
+    theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
+    theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
+    // And at the end we will add this to the VOB compliant video TS
+    pEncoder->addImage ( &imgStart, 1 );
+
+    if ( m_pParent && m_pParent->killClient ( ) )
+      return;
+  }
 }
 
 void Slideshow::createFromVid ( CXmlSlideshow::vid_struct *pXmlVideo, Encoder::FFmpeg *pEncoder, double ) // fFPS )
@@ -368,7 +440,7 @@ void Slideshow::createFromVid ( CXmlSlideshow::vid_struct *pXmlVideo, Encoder::F
     iColor = theColor.rgba ( );
 
   // I do not think we'll be able to support Matrix operations. ( pXmlVideo->pMatrix )
-  pEncoder->addVid ( qsFileName, m_size.width ( ), m_size.height ( ), m_pSlideshow->aspect, (int)iColor );
+  pEncoder->addVid ( qsFileName, m_size.width ( ), m_size.height ( ), m_pSlideshow->aspect, (int)iColor, pXmlVideo->rotate );
 }
 
 // Image to Image Transition
@@ -378,56 +450,43 @@ void Slideshow::createIITransition ( CXmlSlideshow::img_struct *pStart, CXmlSlid
     return;
 
   log ( "Creating II Transition\n", Logger::logInformation );
+  QString qsFileName = getHashName ( pStart->src );
+  Utils   theUtils;
+  QImage  imgStart ( qsFileName );
 
-  QPainter thePainter;
-  QString  qsFileName = getHashName ( pStart->src );
-  QImage   canvas   ( m_size, QImage::Format_ARGB32_Premultiplied );
-  QImage   imgStart ( qsFileName );
-
+  // Generate random KenBurns but only if not already set.
+  pStart->effect[0].randomKenBurns ( 0.5f, imgStart.width ( ), imgStart.height ( ), false );
   if ( pStart->pMatrix )
-       imgStart = imgStart.transformed  ( *pStart->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStart );
-  imgStart = imgStart.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
-
-  int iX, iY;
-  iX = (int)( ( m_size.width  ( ) - imgStart.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStart.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStart, 0, 0 );
-  thePainter.end ( );
-  imgStart = canvas;
+       imgStart = imgStart.transformed ( *pStart->pMatrix, Qt::SmoothTransformation );
+  theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
   qsFileName = getHashName ( pStop->src );
   QImage imgStop ( qsFileName );
 
+  // Generate random KenBurns but only if not already set.
+  pStop->effect[0].randomKenBurns ( 0.5f, imgStop.width ( ), imgStop.height ( ), false );
   if ( pStop->pMatrix )
        imgStop  = imgStop.transformed ( *pStop->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStop );
-  imgStop = imgStop.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  theUtils.prescaleImage ( imgStop, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStop, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
-  iX = (int)( ( m_size.width  ( ) - imgStop.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStop.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStop, 0, 0 );
-  thePainter.end   ( );
-  imgStop = canvas;
-
-  float fDuration = (float)m_pSlideshow->filter_delay;
-  if  ( fDuration < 0.0f )
-        fDuration = pStop->fDuration;
-  if  ( fDuration < 0.0f )
-        fDuration = 3.0f;
-  fDuration *= 1000.0f; // in mSeconds please.
-
-  int iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
+  fFPS /= 1000.0;
+  float fDuration     = getFilterDuration ( pStop );
+  int iNumberOfImages = (int)( fFPS * fDuration );
   if ( m_pParent && m_pParent->killClient ( ) )
     return;
 
   Filter *pFilter = Filter::create ( m_pSlideshow, pStop->pTransition );
+  bool bStartKenBurns = ( pStart->effect[0].name == EFFECT_TYPE_KENBURNS );
+  bool bStopKenBurns  = ( pStop ->effect[0].name == EFFECT_TYPE_KENBURNS );
+  if ( ( ( bStartKenBurns ) || ( bStopKenBurns ) ) && ( m_pSlideshow->kenBurns ( ) ) )  {
+    int iTotal1 = (int)( ( getDuration ( pStart ) + getFilterDuration ( pStart ) * 2.0 ) * fFPS );
+    int iTotal2 = (int)( ( getDuration ( pStop  ) + getFilterDuration ( pStop  ) * 2.0 ) * fFPS );
+    int iAspect = m_pSlideshow ? m_pSlideshow->aspect : 0;
+    pFilter->setKenBurnsParams ( pStart, pStop, m_background, iAspect, iTotal1, iTotal2 );
+  }
+
   if ( pFilter  )  {
     if ( m_pSlideshow->imgBkgImg ( ) )
        pFilter->exec ( pEncoder, imgStart, imgStop, iNumberOfImages, Filter::VolumeFull, &m_background );
@@ -451,23 +510,16 @@ void Slideshow::createIVTransition ( CXmlSlideshow::img_struct *pStart, CXmlSlid
   // o Transition over
   QPainter thePainter;
   QString  qsFileName = getHashName ( pStart->src );
-  QImage   canvas   ( m_size, QImage::Format_ARGB32_Premultiplied );
   QImage   imgStart ( qsFileName );
+  Utils    theUtils;
 
+  // Generate random KenBurns but only if not already set.
+  pStart->effect[0].randomKenBurns ( 0.5f, imgStart.width ( ), imgStart.height ( ), false );
   if ( pStart->pMatrix )
        imgStart = imgStart.transformed ( *pStart->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStart );
+  theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
   imgStart = imgStart.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
-
-  int iX, iY;
-  iX = (int)( ( m_size.width  ( ) - imgStart.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStart.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStart, 0, 0 );
-  thePainter.end ( );
-  imgStart = canvas;
+  theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
   qsFileName = getHashName ( pStop->src );
   QImage imgStop;
@@ -478,33 +530,32 @@ void Slideshow::createIVTransition ( CXmlSlideshow::img_struct *pStart, CXmlSlid
 
   // We need a image with transparency ...
   imgStop = imgStop.convertToFormat ( QImage::Format_ARGB32 );//_Premultiplied );
-
   if ( pStop->pMatrix )
        imgStop  = imgStop.transformed  ( *pStop->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStop );
+  else if ( pStop->rotate )  {
+    QMatrix matrix;
+    matrix.rotate (  pStop->rotate );
+    imgStop  = imgStop.transformed  ( matrix, Qt::SmoothTransformation ); 
+  }
+
+  theUtils.prescaleImage ( imgStop, m_pSlideshow->aspect );
   imgStop = imgStop.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  theUtils.frameImage ( imgStop, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
-  iX = (int)( ( m_size.width  ( ) - imgStop.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStop.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStop, 0, 0 );
-  thePainter.end   ( );
-  imgStop = canvas;
-
-  float fDuration = (float)m_pSlideshow->filter_delay;
-  if  ( fDuration < 0.0f )
-        fDuration = pStop->fDuration;
-  if  ( fDuration < 0.0f )
-        fDuration = 3.0f;
-  fDuration *= 1000.0f; // in mSeconds please.
-
-  int iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
+  fFPS /= 1000.0f;
+  float fDuration     = getFilterDuration ( pStop );
+  int iNumberOfImages = (int)( fFPS * fDuration );
   if ( m_pParent && m_pParent->killClient ( ) )
     return;
 
-  Filter *pFilter = Filter::create ( m_pSlideshow, pStop->pTransition );
+  Filter *pFilter  = Filter::create ( m_pSlideshow, pStop->pTransition );
+  bool   bKenBurns = (  pStart->effect[0].name == EFFECT_TYPE_KENBURNS );
+  if ( ( bKenBurns ) && ( m_pSlideshow->kenBurns ( ) ) )  {
+    int iTotal1 = (int)( ( getDuration ( pStart ) + getFilterDuration ( pStart ) * 2.0 ) * fFPS );
+    int iAspect = m_pSlideshow ? m_pSlideshow->aspect : 0;
+    pFilter->setKenBurnsParams ( pStart, NULL, m_background, iAspect, iTotal1, 0 );
+  }
+
   if ( pFilter  )  {
     if ( m_pSlideshow->imgBkgImg ( ) )
        pFilter->exec ( pEncoder, imgStart, imgStop, iNumberOfImages, Filter::VolumeFull, &m_background );
@@ -526,14 +577,13 @@ void Slideshow::createVITransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
   // o Get the last frame of the Video
   // o turn up the background music during the duration of the transition
   // o Transition over
-  QPainter thePainter;
-  QString  qsFileName = getHashName ( pStart->src );
-  QImage   canvas   ( m_size, QImage::Format_ARGB32_Premultiplied );
-  QImage   imgStart;
+  QString qsFileName = getHashName ( pStart->src );
+  Utils   theUtils;
+  QImage  imgStart;
 
   if ( pEncoder->initVid   ( qsFileName ) )
        imgStart = pEncoder->getVidFrame ( -1.0 );
-//  // In case something went bad ...
+  // In case something went bad ...
   if ( imgStart.isNull ( ) )
        imgStart = QImage ( qsFileName );
   if ( imgStart.isNull ( ) )
@@ -547,50 +597,41 @@ void Slideshow::createVITransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
 
   if ( pStart->pMatrix )
        imgStart = imgStart.transformed ( *pStart->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStart );
-  imgStart = imgStart.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  else if ( pStart->rotate )  {
+    QMatrix matrix;
+    matrix.rotate ( pStart->rotate );
+    imgStart  = imgStart.transformed  ( matrix, Qt::SmoothTransformation );
+  }
 
-  int iX, iY;
-  iX = (int)( ( m_size.width  ( ) - imgStart.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStart.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStart, 0, 0 );
-  thePainter.end ( );
-  imgStart = canvas;
+  theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
   qsFileName = getHashName ( pStop->src );
   QImage imgStop ( qsFileName );
   if ( imgStop.isNull ( ) )
        imgStop = imgStart;
 
+  // Generate random KenBurns but only if not already set.
+  pStop->effect[0].randomKenBurns ( 0.5f, imgStop.width ( ), imgStop.height ( ), false );
   if ( pStop->pMatrix )
        imgStop  = imgStop.transformed ( *pStop->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStop );
-  imgStop = imgStop.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  theUtils.prescaleImage ( imgStop, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStop, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
-  iX = (int)( ( m_size.width  ( ) - imgStop.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStop.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStop, 0, 0 );
-  thePainter.end   ( );
-  imgStop = canvas;
-
-  float fDuration = (float)m_pSlideshow->filter_delay;
-  if  ( fDuration < 0.0f )
-        fDuration = pStop->fDuration;
-  if  ( fDuration < 0.0f )
-        fDuration = 3.0f;
-  fDuration *= 1000.0f; // in mSeconds please.
-
-  int iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
+  fFPS /= 1000.0f;
+  float fDuration     = getFilterDuration ( pStop );
+  int iNumberOfImages = (int)( fFPS * fDuration );
   if ( m_pParent && m_pParent->killClient ( ) )
     return;
 
-  Filter *pFilter = Filter::create ( m_pSlideshow, pStop->pTransition );
+  Filter *pFilter  = Filter::create ( m_pSlideshow, pStop->pTransition );
+  bool   bKenBurns =   ( pStop->effect[0].name == EFFECT_TYPE_KENBURNS );
+  if ( ( bKenBurns )&& ( m_pSlideshow->kenBurns ( ) ) )  {
+    int iTotal2 = (int)( ( getDuration ( pStop  ) + getFilterDuration ( pStop  ) * 2.0 ) * fFPS );
+    int iAspect = m_pSlideshow ? m_pSlideshow->aspect : 0;
+    pFilter->setKenBurnsParams ( NULL, pStop, m_background, iAspect,  0, iTotal2 );
+  }
+
   if ( pFilter  )  {
     if ( m_pSlideshow->imgBkgImg ( ) )
        pFilter->exec ( pEncoder, imgStart, imgStop, iNumberOfImages, Filter::VolumeFull, &m_background );
@@ -612,11 +653,10 @@ void Slideshow::createVVTransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
   // o Get the last frame of the Video
   // o turn up the background music during the duration of the transition
   // o Transition over
-  QPainter thePainter;
-  QString  qsFileName = getHashName ( pStart->src );
-  QImage   canvas   ( m_size, QImage::Format_ARGB32_Premultiplied );
-  QImage   imgStart;
-//  // In case something went bad ...
+  QString qsFileName = getHashName ( pStart->src );
+  Utils   theUtils;
+  QImage  imgStart;
+  // In case something went bad ...
   if ( pEncoder->initVid ( qsFileName ) )
        imgStart = pEncoder->getVidFrame ( -1.0 );
 
@@ -631,18 +671,14 @@ void Slideshow::createVVTransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
 
   if ( pStart->pMatrix )
        imgStart = imgStart.transformed ( *pStart->pMatrix, Qt::SmoothTransformation );
-  prescaleImage ( imgStart );
-  imgStart = imgStart.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  else if ( pStart->rotate )  {
+    QMatrix matrix;
+    matrix.rotate ( pStart->rotate );
+    imgStart = imgStart.transformed  ( matrix, Qt::SmoothTransformation );
+  }
 
-  int iX, iY;
-  iX = (int)( ( m_size.width  ( ) - imgStart.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStart.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStart, 0, 0 );
-  thePainter.end ( );
-  imgStart = canvas;
+  theUtils.prescaleImage ( imgStart, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStart, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
   qsFileName = getHashName ( pStop->src );
   QImage imgStop;
@@ -650,30 +686,20 @@ void Slideshow::createVVTransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
        imgStop = pEncoder->getVidFrame ( 0.0 );
   if ( imgStop.isNull ( ) )
        imgStop = imgStart;
+  else if ( pStop->rotate )  {
+    QMatrix matrix;
+    matrix.rotate ( pStop->rotate );
+    imgStop = imgStop.transformed  ( matrix, Qt::SmoothTransformation );
+  }
 
   // We need a image with transparency ...
   imgStop = imgStop.convertToFormat ( QImage::Format_ARGB32 );//_Premultiplied );
-  prescaleImage ( imgStop );
-  imgStop = imgStop.scaled ( m_size, Qt::KeepAspectRatio, Qt::SmoothTransformation );
+  theUtils.prescaleImage ( imgStop, m_pSlideshow->aspect );
+  theUtils.frameImage ( imgStop, m_size.width ( ), m_size.height ( ), &m_background, NULL );
 
-  iX = (int)( ( m_size.width  ( ) - imgStop.width  ( ) ) / 2.0 );
-  iY = (int)( ( m_size.height ( ) - imgStop.height ( ) ) / 2.0 );
-
-  canvas = m_background;
-  thePainter.begin ( &canvas );
-  thePainter.drawImage ( iX, iY, imgStop, 0, 0 );
-  thePainter.end   ( );
-  imgStop = canvas;
-
-  float fDuration = (float)m_pSlideshow->filter_delay;
-  if  ( fDuration < 0.0f )
-        fDuration = pStop->fDuration;
-  if  ( fDuration < 0.0f )
-        fDuration = 3.0f;
-  fDuration *= 1000.0f; // in mSeconds please.
-
-  int iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
-  if ( m_pParent && m_pParent->killClient ( ) )
+  float fDuration       = getFilterDuration ( pStop );
+  int   iNumberOfImages = (int)( fFPS * fDuration / 1000.0f );
+  if  ( m_pParent && m_pParent->killClient ( ) )
     return;
 
   Filter *pFilter = Filter::create ( m_pSlideshow, pStop->pTransition );
@@ -687,3 +713,4 @@ void Slideshow::createVVTransition ( CXmlSlideshow::vid_struct *pStart, CXmlSlid
 }
 
 }; // end of namespace Render
+
