@@ -46,12 +46,15 @@ protected:
   void createIVTransition ( CXmlSlideshow::img_struct *, CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
   void createVVTransition ( CXmlSlideshow::vid_struct *, CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
   void createFromImage    ( CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
+  void createKBFromImage  ( CXmlSlideshow::img_struct *, Encoder::FFmpeg *, double );
   void createFromVid      ( CXmlSlideshow::vid_struct *, Encoder::FFmpeg *, double );
 
   void displayProgress    ( float   );
   QString getHashName     ( QString );
 
   void log ( QString, int l=1 );  // 1==Logger::logDebug
+  float getDuration       ( CXmlSlideshow::img_struct * );
+  float getFilterDuration ( CXmlSlideshow::img_struct * );
 
 private:
   Render        *m_pParent;
