@@ -14,12 +14,17 @@
 
 #include <QString>
 
+class QImage;
+
 class Utils
 {
 public:
    Utils ( );
   ~Utils ( );
 
+
+  void frameImage    ( QImage &, int, int, QImage *, unsigned int * );
+  void prescaleImage ( QImage &, int );
   void writeZoneCode ( unsigned char, QString );
   bool recMkdir      ( const    QString & );
   unsigned long long SDBMHash ( QString & );
